/* XPM */
/* $XConsortium: IcMxbdy.m.pm /main/3 1995/07/18 17:13:51 drk $ */
static char * IcMxbdy_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 10 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray1     m white c #dededededede",
"X    s iconGray3     m white c #adadadadadad",
"o    s iconGray7     m black c #424242424242",
"O	s iconColor2	m white	c white",
"+    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray6     m black c #636363636363",
"#	s iconColor5	m black	c blue",
"$    s iconGray4     m white c #949494949494",
"%    s iconGray5     m black c #737373737373",
/* pixels */
"  ............................  ",
" .XXXXXXXXXXXXXXXXXXXXXXXXXXXX. ",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo",
".XOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo",
".XO..........................oXo",
".XO....+++++..........@.@.##.oXo",
".XO.@.@.$$$$$$%++++....@.@##.oXo",
".XO......@o@o@o@$$oo++....##.oXo",
".XO.......$$$$%@o$%oo+.......oXo",
".XO.......+O@$$@o$$%oo+......oXo",
".XO.......+OOX$%@o$%oo@+.....oXo",
".XO......+OO+XX$@@$$%ooo+....oXo",
".XO.....+OO++XXXXXX$%ooo@+...oXo",
".XO.....OOOOO+oo%%%oooXXXX+..oXo",
".XO.....++++OOoo%X$@ooX+.....oXo",
".XO.........OOX%$XXXoo%......oXo",
".XO.........OO.+++XXoo$......oXo",
".XooooooooooOO+++XXXooooooooooXo",
".XXXXXXXXXX.O.++XXX$ooXXXXXXXXXo",
".XXXXXXXXX+O..+X@@oooXXXXXXXXXXo",
".XXXXXXXXX.O.++X$oXXXXXXXXXXXXXo",
".XXXXXXXOOOO++X$o$XXXXXXXXXXXXXo",
".XXXXXXX%ooo++$$oXXXXXXXXXXXXXXo",
".XXXXXXXXXXXoo$$o$XXXXXXXXXXXXXo",
".XXXXXXXXXXXXXooooXXXXXXXXXXXXXo",
" oXXXXXXXXXXXXXXo$XXXXXXXXXXXXo ",
"  oooooooooooooooooooooooooooo  "};
