/* XPM */
/* $XConsortium: Dtblink.l.pm /main/3 1995/07/18 16:31:55 drk $ */
static char * Dtblink_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 11 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray8     m black c #212121212121",
"O	s iconColor1	m black	c black",
"+    s iconGray6     m black c #636363636363",
"@    s iconGray4     m white c #949494949494",
"#    s iconGray5     m black c #737373737373",
"$    s iconGray3     m white c #adadadadadad",
"%    s iconGray7     m black c #424242424242",
"&	s iconColor5	m black	c blue",
/* pixels */
"                                   .............",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.............",
" XXXXXXXXXXXXXOOOOOOXXXXXXXXXXXXXXO.............",
" XXXXXXXXXXX+O++++++O@XXXXXXXXXXXXO.............",
" XXXXXXXXXX@+O#@@@@#O+@XXXXXXXXXXXO.............",
" XXXXXXXXX@@O+XXXXXX+OOXXXXXXXXXXXO.............",
" XXXXXXXXX$+O@XXXXXX@OO$XXXXXXXXXXO.............",
" XXXXXXXXX++OXXXXXXXXOO+XXXXXXXXXXO.............",
" XXXXXXXXX++OXXXXXXXXOO+XXXXXXXXXXO.............",
" XXXXXXXXX++OXXXXXXXXOO+XXXXXXXXXXO.............",
" XXXXXXXXX++OXXXXXXXXOO+XXXXXXXXXXO.............",
" XXXXXXXXX++OXXXXXXXXOO+XXXXXXXXXXO.............",
" XXXXXXXXX$++XXXXXXXX%o@XXXXXXXXXXO.............",
" XXXXXXXXX$@+XX#+++#X+%XXXXXXXXXXXO.............",
" XXXXXXXXXXXOOOOOOOOOOXXXXXXXXXXXXO.............",
" XXXXXXXXXXX#OOOXXXOO#XXXXXXXXXXXXO.............",
" XXXXXXXXXX##OOO+++OO%@XXXXXXXXXXXO.............",
" XXX&XXXXXX#OOXXOOOXOO+XXXXXXX&XXXO.............",
" XXXX&XXXX@++XXXXXXXX+o@XXXXX&XXXXO.............",
" XXXXX&XXX++@XXXXXXXX@%+XXXX&XXXXXO.............",
" XXXXXX&XX++XXXXXXXXXXO+XXX&XXXXXXO.............",
" XXXXXXX&XXXXXXXXXXXXXXXXX&XXXXXXXO.............",
" XXXXXXX&XXXXXXXXXXXXXXXXX&XXXXXXXO.............",
" X&&&&&XXXXXXXXXXXXXXXXXXXXX&&&&&XO.............",
" XXXXXXX&XXXXXXXXXXXXXXXXX&XXXXXXXO.............",
" XXXXXXX&XXXXXXXXXXXXXXXXX&XXXXXXXO.............",
" XXXXXX&XXXXXXXXXXXXXXXXXXX&XXXXXXO.............",
" XXXXX&XXX+OXXXXXXXXXX++XXXX&XXXXXO.............",
" XXXX&XXXX+%@XXXXXXXX@++XXXXX&XXXXO.............",
" XXX&XXXXX@o+XXXXXXXX++@XXXXXX&XXXO.............",
" XXXXXXXXXX+OOXOOOXXOO#XXXXXXXXXXXO.............",
" XXXXXXXXXX@%OO+++OOO##XXXXXXXXXXXO.............",
" XXXXXXXXXXX#OOXXXOOO#XXXXXXXXXXXXO.............",
" XXXXXXXXXXXOOOOOOOOOOXXXXXXXXXXXXO.............",
" XXXXXXXXXX%+X#+++#XX++$XXXXXXXXXXO.............",
" XXXXXXXXX@o%XXXXXXXX+o#XXXXXXXXXXO.............",
" XXXXXXXXX+OOXXXXXXXXOo+XXXXXXXXXXO.............",
" XXXXXXXXX+OOXXXXXXXXO++XXXXXXXXXXO.............",
" XXXXXXXXX+OOXXXXXXXXO++XXXXXXXXXXO.............",
" XXXXXXXXX+OOXXXXXXXXO++XXXXXXXXXXO.............",
" XXXXXXXXX+OOXXXXXXXXO++XXXXXXXXXXO.............",
" XXXXXXXXX$OO@XXXXXX@O+$XXXXXXXXXXO.............",
" XXXXXXXXXXOO+XXXXXX+O@@XXXXXXXXXXO.............",
" XXXXXXXXXX@+O#@@@@#O+@XXXXXXXXXXXO.............",
" XXXXXXXXXXX@O++++++O+XXXXXXXXXXXXO.............",
" XXXXXXXXXXXXXOOOOOOXXXXXXXXXXXXXXO.............",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXO.............",
" oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO............."};
