/* XPM */
/* $XConsortium: pencil.pm /main/2 1996/07/23 13:00:33 drk $ */
static char * IEtPencl [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 9 1 0 0",
/* colors */
" 	s iconGray2	m white	c #c8c8c8c8c8c8",
".	s iconGray4	m white	c #969696969696",
"X	s iconGray3	m white	c #afafafafafaf",
"o	s iconColor6	m white	c yellow",
"O	s iconColor2	m white	c white",
"+	s iconGray5	m black	c #7d7d7d7d7d7d",
"@	s iconColor1	m black	c black",
"#	s iconGray1	m white	c #e1e1e1e1e1e1",
"$	s iconGray7	m black	c #4b4b4b4b4b4b",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXoOo..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXoOoO..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXoOoOo..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXoOoOo+..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXoOoOo+o..",
"  XXXXXXXXXXXXXXXXXXXXXXXXoOoOo+o+..",
"  XX@@@@@XXXXXXXXXXXXXXXXoOoOo+o+o..",
"  XXXXXXX@@@XXXXXXXXXXXXoOoOo+o+o+..",
"  XXXXXXXXXX@XXXXXXXXXXoOoOo+o+o+X..",
"  XXXXXXXXXXX@XXXXXXXXoOoOo+o+o+XX..",
"  XXXXXXXXXXXX@XXXXXXoOoOo+o+o+XXX..",
"  XXXXXXXXXXXXX@XXXXoOoOo+o+o+XXXX..",
"  XXXXXXXXXXXXX@XXXoOoOo+o+o+XXXXX..",
"  XXXXXXXXXXXXX@XXX#OOo+o+o+XXXXXX..",
"  XXXXXXXXXXXX@XXXXOO#+o+o+XXXXXXX..",
"  XXXXXXXXXX@@XXXXOO#+++o+XXXXXXXX..",
"  XXXXXXX@@@XXXXXXO#+++o+XXXXXXXXX..",
"  XXXXXX@XXXXXXXXO#+++++XXXXXXXXXX..",
"  XXXXX@XXXXXXXXX#+++++XXXXXXXXXXX..",
"  XXXXX@XXXXXXXX$+++++XXXXXXXXXXXX..",
"  XXXXXX@XXXXXX$$$++XXXXXXXXXXXXXX..",
"  XXXXXXX@XXXXX$$+XXXXXXXXXXXXXXXX..",
"  XXXXXXXX@@XX$$XXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXX@$$XXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
