/* XPM */
static char *rosegarden_m[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c #343D16",
".  c #353D1A",
"X  c #323722",
"o  c #343923",
"O  c #3B4E02",
"+  c #3E4D0B",
"@  c #374017",
"#  c #3D4816",
"$  c #3C441E",
"%  c #435A01",
"&  c #4B5C0B",
"*  c #425303",
"=  c #555D03",
"-  c #414E13",
";  c #485718",
":  c #53531A",
">  c #635803",
",  c #4E6900",
"<  c #5B6602",
"1  c #5A6804",
"2  c #52660E",
"3  c #5B7204",
"4  c #5C720C",
"5  c #4D6310",
"6  c #636C03",
"7  c #6A610A",
"8  c #766704",
"9  c #627703",
"0  c #6F7905",
"q  c #657F02",
"w  c #7C730D",
"e  c #757806",
"r  c #7A641C",
"t  c #414125",
"y  c #6B6129",
"u  c #7E6629",
"i  c #D70C01",
"p  c #D31001",
"a  c #E01301",
"s  c #CD2401",
"d  c #DB2304",
"f  c #D62302",
"g  c #D1380D",
"h  c #DB340E",
"j  c #C63810",
"k  c #E52502",
"l  c #E12F02",
"z  c #EA3901",
"x  c #E93603",
"c  c #9A6B0E",
"v  c #817805",
"b  c #8F7F05",
"n  c #90700C",
"m  c #927A04",
"M  c #947213",
"N  c #B57D07",
"B  c #986124",
"V  c #8C7A2D",
"C  c #B66929",
"Z  c #B8692D",
"A  c #C14216",
"S  c #EC4A04",
"D  c #EF4E08",
"F  c #E54307",
"G  c #F14505",
"H  c #ED5F07",
"J  c #E4520C",
"K  c #E65905",
"L  c #F35F0F",
"P  c #E14E10",
"I  c #E75A15",
"U  c #EB6C0C",
"Y  c #EB660E",
"T  c #E46D1C",
"R  c #E66614",
"E  c #F26315",
"W  c #F46812",
"Q  c #F3681B",
"!  c #E67619",
"~  c #ED7E1B",
"^  c #EB7217",
"/  c #F47D11",
"(  c #D45E25",
")  c #E65920",
"_  c #E05B36",
"`  c #CE6421",
"'  c #C46A21",
"]  c #C86F24",
"[  c #D66123",
"{  c #DE6D22",
"}  c #DD7729",
"|  c #DC7E28",
" . c #D66136",
".. c #C07038",
"X. c #E2782E",
"o. c #6D830A",
"O. c #668108",
"+. c #788909",
"@. c #748C08",
"#. c #7F9D0B",
"$. c #99870F",
"%. c #929005",
"&. c #8E9613",
"*. c #A58302",
"=. c #B08E06",
"-. c #A2970E",
";. c #A98C12",
":. c #B4881C",
">. c #B58B17",
",. c #A39111",
"<. c #8BAA0E",
"1. c #95AB0E",
"2. c #A4A314",
"3. c #B6A412",
"4. c #B89F2D",
"5. c #B5972D",
"6. c #DB940C",
"7. c #CB8C12",
"8. c #F78D0C",
"9. c #FA920A",
"0. c #EC8313",
"q. c #EE8719",
"w. c #E7871D",
"e. c #F4851D",
"r. c #F18C19",
"t. c #FC851A",
"y. c #E2961C",
"u. c #F49B1D",
"i. c #F7941C",
"p. c #D0AF0B",
"a. c #D5A30A",
"s. c #CDB413",
"d. c #C7B91E",
"f. c #D7B817",
"g. c #FCB70D",
"h. c #FABF0E",
"j. c #E8A112",
"k. c #EEA911",
"l. c #FBAA14",
"z. c #F7A41D",
"x. c #F7AA1F",
"c. c #F9AE1A",
"v. c #F7A619",
"b. c #EABB16",
"n. c #FBB313",
"m. c #FAB41C",
"M. c #FDB91E",
"N. c #F4B71D",
"B. c #D5882D",
"V. c #FA8A28",
"C. c #EC9825",
"Z. c #F39220",
"A. c #FD9E23",
"S. c #EF9A39",
"D. c #F59030",
"F. c #CEB823",
"G. c #D4B92A",
"H. c #FFA32A",
"J. c #F7A928",
"K. c #EABE20",
"L. c #F7B320",
"P. c #FEB424",
"I. c #FDBB26",
"U. c #FDBC2C",
"Y. c #F9A031",
"T. c #F3A43A",
"R. c #F9BC37",
"E. c #CAC418",
"W. c #F0C502",
"Q. c #FDCE0D",
"!. c #FBC407",
"~. c #E9C31C",
"^. c #F6C110",
"/. c #FDCD13",
"(. c #FECB1D",
"). c #FDD71E",
"_. c #FDDA14",
"`. c #F6E80A",
"'. c #FEEF0C",
"]. c #FCE705",
"[. c #FEEB11",
"{. c #FEE214",
"}. c #FEF91E",
"|. c #FEFA16",
" X c #DEC723",
".X c #F4C726",
"XX c #FDC326",
"oX c #FDCC26",
"OX c #F9C32B",
"+X c #FDCB29",
"@X c #EAD327",
"#X c #FBD32D",
"$X c #FBDB2B",
"%X c #F6D223",
"&X c #E9C437",
"*X c #FBCE32",
"=X c #FAD332",
"-X c #F6DE33",
";X c #F7D23F",
":X c #FBD53A",
">X c #FBDA3B",
",X c #FEE224",
"<X c #FEEB25",
"1X c #F0E02B",
"2X c #FEED2F",
"3X c #FEE32C",
"4X c #FEF422",
"5X c #FFFC2E",
"6X c #FFEA35",
"7X c #FDE03F",
"8X c #FFF535",
"9X c #FEFA32",
"0X c #FEF23B",
"qX c #BD9A51",
"wX c #F39D45",
"eX c #E49C55",
"rX c #F09950",
"tX c #F49D59",
"yX c #D1A545",
"uX c #FCB544",
"iX c #E6A95E",
"pX c #E3A353",
"aX c #E7B25D",
"sX c #F7B653",
"dX c #F2A76B",
"fX c #EEBF60",
"gX c #F6BF68",
"hX c #ECC741",
"jX c #F8C740",
"kX c #FBCE41",
"lX c #FBD541",
"zX c #FCDA44",
"xX c #FBD54D",
"cX c #FCDA4B",
"vX c #FEC353",
"bX c #FDD85E",
"nX c #FAD659",
"mX c #FFF740",
"MX c #E2C26E",
"NX c #F6C968",
"BX c #FBCE6B",
"VX c #FADC65",
"CX c #F7D56B",
"ZX c #F8D975",
"AX c #FAD27A",
"SX c #FCDF78",
"DX c #F5C282",
"FX c #F7D988",
"GX c #F6D897",
"HX c #F9D992",
"JX c #F9E289",
"KX c #FBE395",
"LX c #FBE696",
"PX c #FCE9A2",
"IX c #F9E2A3",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX^ T T } UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXZ C ` ! U T S.T.B.UX| ` UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX' w.~ U K r.xXR.J.Z.~ R A UXpXeXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX' 0.U K H i.>XI.x.u.e.R j ..sXiXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX] ^ S F S r.=XOXL.u.e.E g X.vXaXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXY z x l q.#X.XL.z./ L ) rXAXwXP ( UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXJ k k f 0.#X+Xm.z.D.tXDXHXBXQ D [ UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXF a d s 0.#X*X*XNXFXIXLXbXY.G I UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXc P p d s r.xXCXFXKXPXKXxX+XW E { UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUX8 n T p h  .NXHXKXPXKXVXU.m.J.V.Z.UXUXUXUXUXB UXUXUX",
"UXUXUXUXUXUX> M C._ dXGXHXKXJXVX;Xm.9.A.uXP.u.UXUXUXUX:.UXUXUXUX",
"UXUXUXUXUXUXr qXAXGXKXSXnX&Xs..Xc.8.t.A.P.m.u.UXUXUXUX>.UXUXUXUX",
"UXUXUXUXUXUXMXZXVXbXlXOXL.p.s.oXl.i.H.P.M.m.y.UXUXUX>.UXUXUXUXUX",
"UXUXUXUXUXfXnXkX=X:X=XOXK.s.%XoXn.z.I.I.M.c.UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXyXxXlX>X:X*X.Xs.@X,X).h.l.I.XXI.k.UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXu hXcXzXlX*Xf. X3X,X,X/.g.I.+XI.j.UXUXUX,.UXUXUXUXUXUX",
"UXUXUXUXUXUX5.zXcXxX&XF.-X6X2X<X_.!.XXoXm.6.UXUX,.UXUXUXUXUXUXUX",
"UXUXUXUXUXUXV ;XzX>XF.2.-X0X8X2X{.Q.+XoXm.7.UX$.$.UXUXUXUXUXUXUX",
"UXUXUXUXUXUXy &X>X=X3.+.@XmX8X4X[.Q.+XoXk.UX7 e UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXt 4.zX$X-.9 F.8X9X}.[.Q.oX(.6.w 6 w UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXy G.~.w % &.1X5X}.'.!.oXh.N < 0 UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX: w = O 3 d.4X|.].!./.a.7 < UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXX @ - O * o.E.`.W.!.b.m < 0 UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXo   + * % 3 %.*.=.b 6 UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXX @ 2 o.O.9 6 = UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXo ; @.<.1.@.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUX# ; O.#.q UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXt 5 , UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUX. 5 % UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUX. 2 & UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUX  4 & UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
