/* XPM */
/* $XConsortium: DtMmsg.m.pm /main/3 1995/07/18 16:22:34 drk $ */
static char * DtMmsg_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray5     m black c #737373737373",
"o    s iconGray1     m white c #dededededede",
"O	s iconColor4	m white	c green",
"+    s iconGray7     m black c #424242424242",
"@    s iconGray3     m white c #adadadadadad",
"#    s iconGray4     m white c #949494949494",
"$    s iconGray2     m white c #bdbdbdbdbdbd",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"................................",
".XXoXXXoooooooooooooooXXoXooOOo+",
".oooooooooooooooooooooooXoXoOOo+",
".XoXXXooooooooooooooooXXoXooOOo+",
".oooooooooooooooooooooooooooooo+",
".oooooooooooooooooooooooooooooo+",
".ooooooooooo@oooooooooooooooooo+",
".ooooooooooX#o###o##XXooooooooo+",
".oooooooooooo@oooooooo@oooooooo+",
".ooooooooooX#Xo##o##o###ooooooo+",
".oooooooooooooo@oo@oo@ooooooooo+",
".oooooooooo@#@#@@oo#ooooooooooo+",
".ooooooooooooooo$oooooooooooooo+",
".oooooooooooooooooooooooooooooo+",
".oooooooooooooooooooooooooooooo+",
".+++++++++++++++++++++++++++++++"};
