/* XPM */
/* $XConsortium: Dtsectprev.m.pm /main/2 1996/07/23 12:21:57 drk $ */
static char * Dtsectprev2_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 7 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconGray7	m black	c #424242424242",
"O	s iconGray6	m black	c #636363636363",
"+	s bottomShadowColor	m black	c #636363636363",
"@	s iconGray3	m white	c #adadadadadad",
/* pixels */
"    ..................          ",
"    .XXXXXXXXXXXXXXXX.o         ",
"    .XXXXXXXXXXXXXXXX.Xo        ",
"    .XXXXXXXXXXXXXXXX.XXo       ",
"    .XXXXXXXXXXXXXXXX.XXXo      ",
"    .XXXXXXXXXXXXXXXX.XXXXo     ",
"    .XXXXXXXXXXXXXXXX.XXXXXo    ",
"    .XXXXXXXXXXXXXXXXoooooooo   ",
"    .XXXXXXXXXXXXXXXXXOOOOOOo   ",
"    .XXXXXXXXXXX+XXXXXXXXXXXo+  ",
"    .XXXXXXXXXX+@.XXXXXXXXXXo+  ",
"    .XXXXXXXXX+@@@.XXXXXXXXXo+  ",
"    .XXXXXXXX+@@@@@.XXXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXX+@@@@@@@@@.XXXXXXo+  ",
"    .XXXXX+@@@@@@@@@@@.XXXXXo+  ",
"    .XXXX+@@@@@@@@@@@@@.XXXXo+  ",
"    .XXX+++++@@@@@@@.....XXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX+@@@@@@@.XXXXXXXo+  ",
"    .XXXXXXX.........XXXXXXXo+  ",
"    .XXXXXXXXXXXXXXXXXXXXXXXo+  ",
"    .XXXXXXXXXXXXXXXXXXXXXXXo+  ",
"    .XXXXXXXXXXXXXXXXXXXXXXXo+  ",
"    .XXXXXXXXXXXXXXXXXXXXXXXo+  ",
"    .oooooooooooooooooooooooo+  ",
"      ++++++++++++++++++++++++  "};
