/* XPM */
/* $XConsortium: smallhelp.pm /main/2 1996/07/23 12:32:56 drk $ */
/* Designed by the User Interaction Design Group, Hewlett-Packard */
/* Copyright (c) 1993 Hewlett-Packard */
static char *help32[]={
/* width height ncolors cpp [x_hot y_hot] */
"32 32 22 1 0 0",
/* colors */
"  c none m none s none",
"$    s topShadowColor m white c #bdbdbdbdbdbd",
"&    s background    m black c #949494949494",
"(    s selectColor m white c #737373737373",
"*    s bottomShadowColor m black c #636363636363",
", s white      c white     m white",
". s iconColor1 c black     m black",
"B s iconColor2 c white     m white",
"4 s iconColor3 c red       m black",
"6 s iconColor4 c green     m white",
"8 s iconColor5 c blue      m black",
"2 s iconColor6 c yellow    m white",
": s iconColor7 c cyan      m white",
"0 s iconColor8 c magenta   m black",
"<    s iconGray1     m white c #dededededede",
">    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"D    s iconGray4     m white c #949494949494",
"F    s iconGray5     m black c #737373737373",
"H    s iconGray6     m black c #636363636363",
"J    s iconGray7     m black c #424242424242",
"L    s iconGray8     m black c #212121212121",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"       ******         *******   ",
"       *@@@J******    *@@@FL$   ",
"   ****L@FDHLDDDDH****LDDDHL$   ",
"   *>>@L:DF4LDFFFHL8JHLDDFJL$   ",
"   *>@FLDFDHLDFFFHLJF8LDDFFL$   ",
"   *>DFL:DF4HBBBBBLJJHLDJFFL$   ",
"   *>@FLDFDHBBBBBBB8F8LDDDFL$   ",
"   *>@FL:DF4BBFFFBBJJHLDJFFL$   ",
"   *>DFLDFDHBBFFFBB8F8LFFFFL$   ",
"   *>@FL:DF4LDFFBBBJJHLFHFFL$   ",
"   *>DFLDFDHLDFBBBL8F8LFDFFL$   ",
"   *>DFL:DF4LDBBBHLJJHLFHFFL$   ",
"   *>DFLDFDHLDBBFHL8F8LFFFFL$   ",
"   *>@FL:DF4LDFFFHLJJHLFDDFL$   ",
"   *>@FLDFDHLDBBFHL8F8LFDFFL$   ",
"   *>@FL:DF4LDBBFHLJJHLFDFFL$   ",
"   *>@FLDFDHLDHFJHL8F8LFJFFL$   ",
"   *>@FL:DF4LDFJJHLJJHLFDFFL$   ",
"   *>@FLDFDHLDFFFHL8F8LFDFFL$   ",
"   *>@FL:DF4LDFFFHLJJHLFDFFL$   ",
"   *@LLLLLLLLLLLLLLLLLLLLLLL$   ",
"   *$$$$$$$$$$$$$$$$$$$$$$$$$   ",
"                                ",
"                                ",
"                                ",
"                                "
};
