/* XPM */
/* $XConsortium: Dthvol.t.pm /main/3 1995/07/18 16:40:47 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dthvol_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 6 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray5     m black c #737373737373",
"O	s iconColor1	m black	c black",
"+	s iconColor6	m white	c yellow",
/* pixels */
"            ....",
" XoXXXXXXXXO....",
" XoXXXXXXXXOO...",
" XoXOXOOOOXOO...",
" XoXX++++XXOO...",
" XoX++++++XOO...",
" XoX++XX++XOO...",
" XoXooX++oXOO...",
" XoXXX++XXXOO...",
" XoXXX++XXXOO...",
" XoXXXXXXXXOO...",
" XoXXX++XXXOO...",
" XoXXo++ooXOO...",
" XoXXXXXXXXOO...",
" OOOOOOOOOOOO...",
". OOOOOOOOOOO..."};
