/* XPM */
/* $XConsortium: FpliteY.t.pm /main/3 1995/07/18 16:59:19 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Fliteon [] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 5 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X	s iconColor2	m white	c white",
"o    s topShadowColor m white c #bdbdbdbdbdbd",
"O	s iconColor6	m white	c yellow",
/* pixels */
"                ",
"                ",
"                ",
"                ",
"                ",
"................",
".XXXXXXXXXXXXXXo",
".XOXOXOXOXOXOXOo",
".XOOOOOOOOOOOOOo",
".ooooooooooooooo",
"                ",
"                ",
"                ",
"                ",
"                ",
"                "};
