/* XPM */
/* $XConsortium: DtABbrw.m.pm /main/2 1996/07/23 11:53:32 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtABbrw_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #c8c8c8c8c8c8",
"o	s iconColor4	m white	c green",
"O	s iconColor1	m black	c black",
"+	s iconGray4	m white	c #969696969696",
"@	s iconGray5	m black	c #7d7d7d7d7d7d",
"#	s iconGray1	m white	c #e1e1e1e1e1e1",
"$	s iconColor5	m black	c blue",
"%	s iconGray3	m white	c #afafafafafaf",
"&	s iconColor7	m white	c cyan",
"*	s iconGray6	m black	c #646464646464",
/* pixels */
"                                ",
"                                ",
".....................           ",
".XXoXXXXXXXXXXXXXXXXO           ",
".XXoo+XX+++++@@XXXXXO           ",
".XXo.o++.###X#X@XXXXO           ",
".XXoo.+.##$+$+XX@@XXO           ",
".XXo.+.#+$%$%$%$XX@XO           ",
".XXoo+.+$%&&&&&&$X@XO           ",
".XXo+..$%&&&&&.&&XX*O           ",
".XXo+.$%&&&&&.&.&&X*O           ",
".XXo+.+$&&&&.&.&.&X*O           ",
".XXo+.$%&&&.&.&.&&X*O           ",
".XXo+.+$&&.&...&.&X*O           ",
".XXo+##%&&&...&.&XX*O           ",
".XXo.+#$%&.&.&.&&X*XO           ",
".XXoo+##$%&.&.&&XX*XO           ",
".XXo.o++X#%&%&XX**+XO           ",
".XXoo.o+@XXXXXX*o.O+O           ",
".XXo.oo+X******o.O#OO           ",
".XXoo.o+XXXXXXXXO#OOO           ",
".XXo.ooooooooooooOO+OO          ",
".XXoo.o.o.o.o.o.o.OO+OO         ",
".XXo.o.o.o.o.o.o.o.OO+OO        ",
".XXoooooooooooooooooOO+OO       ",
".XXX++++++++++++++++OOO+OO      ",
".XXXXXXXXXXXXXXXXXXXO OO+OO     ",
".XXXXXXXXXXXXXXXXXXXO  OO+OO    ",
".XXXXXXXXXXXXXXXXXXXO   OO+OO   ",
".OOOOOOOOOOOOOOOOOOOO    OO+OO  ",
"                          OOO   ",
"                           O    "};
