/* XPM */
/* $XConsortium: Dtdetach.m.pm /main/2 1996/07/23 12:08:35 drk $ */
static char * Dtdetach1_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconColor5	m black	c blue",
"o	s iconGray4	m white	c #949494949494",
"O	s iconGray3	m white	c #adadadadadad",
"+	s iconGray6	m black	c #636363636363",
"@	s iconGray5	m black	c #737373737373",
"#	s bottomShadowColor	m black	c #636363636363",
/* pixels */
"           .XXX                 ",
"           .XXX                 ",
"           .XXX                 ",
"           .XXX...              ",
"           .XXXoOO.             ",
"          .XXXoOOOO.            ",
"         ..XXXoOOOOO.           ",
"       ..XXXXoOOOOOOO.          ",
"      .XXXXXXoOOOOOOO+          ",
"      .XXXXXoOOO++++++..        ",
"        .XXoOOO+      .O+       ",
"        .XXoOO+       .OO+      ",
"       .XXoOO+        .OOO+     ",
"      .XXXoO+        .OOOOO+    ",
"      .XXoO+        .OOOOOO+    ",
"     .XXXo@        .OOOOOOo+    ",
"     .XXo@        .OOOOOooX+    ",
"    .XXXo@       .OOOOOoXXXXXX# ",
"    .XXoO@      .OOOOooXXXXXXX# ",
"   .XXoOO@     .OOOooXXXXX##### ",
"   .XXoOOO@   .OOOoXXXXX###     ",
"  .XXoOOOoO@ .OOooXXXX###       ",
"  .XXoOOoOOO.OOoXXX#XX#         ",
" .XXoOOoOOOOOooXX##.XX#         ",
" .XXoO@OOOOooXX##  .XX#         ",
" .X.@@OOOOoXXX#    .###         ",
"  .@.@OOooXX##                  ",
"  .@.@ooXXX#                    ",
"  .O@.XXX##                     ",
"   ..XX##                       ",
"     ##                         ",
"                                "};
