/* XPM */
/* $XConsortium: Dtinf.m.pm /main/3 1995/07/18 16:41:40 drk $ */
static char * Dtinf_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray4     m white c #949494949494",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXOOOOOXXXXXXXXXo.......",
" XXXXXXXXOOOOOOOXXXXXXXXo.......",
" XXXXXXXOOXXXXXOOXXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXXOOXXXXXOOXXXXXXXo.......",
" XXXXXXXOOXXXXXOOXXXXXXXo.......",
" XXXXXXXXOOXXXOOXXXXXXXXo.......",
" XXXXXXXXXOOXOOXXXXXXXXXo.......",
" XXXXXXXXXXOOOXXXXXXXXXXo.......",
" XXXXXXXXXXOOOXXXXXXXXXXo.......",
" XXXXXXXXXOOXOOXXXXXXXXXo.......",
" XXXXXXXXOOXXXOOXXXXXXXXo.......",
" XXXXXXXOOXXXXXOOXXXXXXXo.......",
" XXXXXXXOOXXXXXOOXXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXOOXXXXXXXOOXXXXXXo.......",
" XXXXXXXOOXXXXXOOXXXXXXXo.......",
" XXXXXXXXOOOOOOOXXXXXXXXo.......",
" XXXXXXXXXOOOOOXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
