/* XPM */
/* $XConsortium: Dtdetach.l.pm /main/1 1996/07/11 14:22:50 rcs $ */
/*
 * (c) Copyright 1996 Digital Equipment Corporation.
 * (c) Copyright 1996 Hewlett-Packard Company.
 * (c) Copyright 1996 International Business Machines Corp.
 * (c) Copyright 1996 Sun Microsystems, Inc.
 * (c) Copyright 1996 Novell, Inc. 
 * (c) Copyright 1996 FUJITSU LIMITED.
 * (c) Copyright 1996 Hitachi.
 */
static char * Dtdetach_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 8 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconColor5	m black	c blue",
"o	s iconGray5	m black	c #737373737373",
"O	s iconGray3	m white	c #adadadadadad",
"+	s iconGray4	m white	c #949494949494",
"@	s iconGray6	m black	c #636363636363",
"#	s bottomShadowColor	m black	c #636363636363",
/* pixels */
"                                                ",
"                 ......                         ",
"                 .XXXXX                         ",
"                 .XXXXX                         ",
"                 .XXXXX                         ",
"                 .XXXXX....                     ",
"                 .XXXXXoOOO.                    ",
"                 .XXXXo+OOOO.                   ",
"                .XXXXXoOOOOOO.                  ",
"                .XXXXo+OOOOOOO.                 ",
"              ..XXXXXoOOOOOOOOO.                ",
"           ...XXXXXXoOOOOOOOOOOO.               ",
"          .XXXXXXXXXoOOOOOOOOOOO@               ",
"          .XXXXXXXXoOOOOOOOOOOOO@               ",
"          .XXXXXXXXoOOOOO@@@@@@@@...            ",
"            ..XXXXoOOOOO@        .OO@           ",
"            .XXXXXoOOOO@         .OOO@          ",
"            .XXXXoOOOO@          .OOOO@         ",
"           .XXXXoOOOO@           .OOOOO@        ",
"           .XXXXoOOO@            .OOOOOO@       ",
"          .XXXXoOOO@            .OOOOOOOO@      ",
"          .XXXXoOO@            .OOOOOOOOO@      ",
"         .XXXXoOO@            .OOOOOOOOOO@      ",
"        .XXXXXoO@            .OOOOOOOOO+o@      ",
"        .XXXXoO@            .OOOOOOO++ooX@      ",
"       .XXXXXO@            .OOOOOOOOooXXX@      ",
"       .XXXXoOo           .OOOOOOOooXXXXXXXXX#  ",
"      .XXXXoOOo          .OOOOOO+oXXXXXXXXXXX#  ",
"      .XXXXoOOo         .OOOOOOooXXXXXXXXXXXX#  ",
"     .XXXXoOOOo        .OOOOOooXXXXXXXX#######  ",
"     .XXXXoOOOOo      .OOOO+oXXXXXXX###         ",
"    .XXXXoOOOOOoo    .OOOOooXXXXXXXX#           ",
"    .XXXXoOOOOoOOo  .OOOooXXXXXXX###            ",
"   .XXXXoOOOOoOOOOo.OOooXXXXX#XXX#              ",
"   .XXXXoOOOoOOOOOOOOoXXXXXX##XXX#              ",
"  .XXXXoOOOoOOOOOOOooXXXXX###.XXX#              ",
"  .XXX@OOOoOOOOOOooXXXXXX#   .XXX#              ",
"  .XX@oOOoOOOOOOoXXXXXX##    .XXX#              ",
"  .XX@oOoOOOOOooXXXXX##      .####              ",
"   @@++oOOOOooXXXXXX#                           ",
"   .@o++oOooXXXXXX##                            ",
"   ..o++ooXXXXXXX#                              ",
"    .OoO.XXXXXX##                               ",
"     .oo.XXXX##                                 ",
"      ..XXXX##                                  ",
"        #X##                                    ",
"        ##                                      ",
"                                                "};
