/* XPM */
/* $XConsortium: IEtCircl.pm /main/3 1995/07/18 17:21:49 drk $ */
static char * IEtCircl [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 4 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor1	m black	c black",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXoooooooXXXXXXXXXXXX..",
"  XXXXXXXXXXoooXXXXXXXoooXXXXXXXXX..",
"  XXXXXXXXXoXXXXXXXXXXXXXoXXXXXXXX..",
"  XXXXXXXXoXXXXXXXXXXXXXXXoXXXXXXX..",
"  XXXXXXXoXXXXXXXXXXXXXXXXXoXXXXXX..",
"  XXXXXXoXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXXoXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXXoXXXXXXXXXXXXXXXXXoXXXXXX..",
"  XXXXXXXXoXXXXXXXXXXXXXXXoXXXXXXX..",
"  XXXXXXXXXoXXXXXXXXXXXXXoXXXXXXXX..",
"  XXXXXXXXXXoooXXXXXXXoooXXXXXXXXX..",
"  XXXXXXXXXXXXXoooooooXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
