/* XPM */
static char *sound_juicer_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #494949",
".  c #6F6F6F",
"X  c #7C7C7D",
"o  c #B25C1D",
"O  c #AF571C",
"+  c #AE5A22",
"@  c #B35F24",
"#  c #B2622A",
"$  c #B56325",
"%  c #B56D38",
"&  c #BD753B",
"*  c #CF760C",
"=  c #C87926",
"-  c #C37635",
";  c #B87747",
":  c #AF7A54",
">  c #917B6C",
",  c #A87E69",
"<  c #B37E64",
"1  c #DF8705",
"2  c #D78317",
"3  c #E28A0A",
"4  c #E38E12",
"5  c #E79319",
"6  c #D78727",
"7  c #CC8336",
"8  c #EE9C25",
"9  c #E89F39",
"0  c #F3A22C",
"q  c #EBA138",
"w  c #FCA63B",
"e  c #FCAD3D",
"r  c #FAA436",
"t  c #FCB03F",
"y  c #EFA02B",
"u  c #8A837C",
"i  c #988579",
"p  c #A5816E",
"a  c #AC826C",
"s  c #B68769",
"d  c #BA9674",
"f  c #BEA17A",
"g  c #C8885B",
"h  c #DA8C5C",
"j  c #DE9556",
"k  c #E2925E",
"l  c #E08855",
"z  c #FCAD43",
"x  c #FDAD4B",
"c  c #F9A944",
"v  c #FCB144",
"b  c #FCB34C",
"n  c #E6AB5B",
"m  c #FCAD53",
"M  c #F4AF54",
"N  c #FBB453",
"B  c #FCB955",
"V  c #FAB55B",
"C  c #FBB95B",
"Z  c #F4B359",
"A  c #ECAC51",
"S  c #CC8C63",
"D  c #C68863",
"F  c #D38D61",
"G  c #DB9262",
"H  c #D49265",
"J  c #CD926A",
"K  c #E79E69",
"L  c #E39863",
"P  c #DAAD7D",
"I  c #D8A67D",
"U  c #DFB17D",
"Y  c #DCA466",
"T  c #ECA46C",
"R  c #E9AA68",
"E  c #ECB46A",
"W  c #E8B16A",
"Q  c #F4B564",
"!  c #FCBB64",
"~  c #F5BB6D",
"^  c #FABE6A",
"/  c #F9B864",
"(  c #E6AB71",
")  c #F1AC71",
"_  c #EDBB74",
"`  c #E8B77A",
"'  c #F5BE72",
"]  c #FABE73",
"[  c #F6BD7D",
"{  c #F3B477",
"}  c #FDC26C",
"|  c #FDC065",
" . c #FCC475",
".. c #F5C27B",
"X. c #FCC67A",
"o. c #838383",
"O. c #8A8683",
"+. c #8B8B8B",
"@. c #878888",
"#. c #978B81",
"$. c #9C918D",
"%. c #949495",
"&. c #979899",
"*. c #AC998E",
"=. c #BAA586",
"-. c #ACA49C",
";. c #B5A298",
":. c #BBB99C",
">. c #A7A8A6",
",. c #BCBCA4",
"<. c #B6BAAE",
"1. c #BBBDAC",
"2. c #B5B5A6",
"3. c #A7A8B4",
"4. c #A6A8BB",
"5. c #AAACBD",
"6. c #A6A7B9",
"7. c #B5AFB5",
"8. c #AFB3B6",
"9. c #B2B4B4",
"0. c #BBBEB3",
"q. c #BBB5BD",
"w. c #B5BBBB",
"e. c #BABDBC",
"r. c #B4B7B6",
"t. c #C09B82",
"y. c #D9AF89",
"u. c #DBB48D",
"i. c #C5A998",
"p. c #C5B49A",
"a. c #D7B799",
"s. c #CDA586",
"d. c #E8BE89",
"f. c #F6BD80",
"g. c #E5BE93",
"h. c #C1BEA3",
"j. c #C7B3A9",
"k. c #D5BCA5",
"l. c #C9BCB3",
"z. c #D3BFB8",
"x. c #C3AFA6",
"c. c #BEC0AA",
"v. c #BFC0A6",
"b. c #BEC1B3",
"n. c #BBC1BC",
"m. c #EEC182",
"M. c #ECC28B",
"N. c #F3C383",
"B. c #FAC583",
"V. c #FDCB83",
"C. c #FBCC8B",
"Z. c #F5C58A",
"A. c #FDD18D",
"S. c #EBC599",
"D. c #F3CA93",
"F. c #F3CD9E",
"G. c #F9CA96",
"H. c #FED394",
"J. c #FCD59B",
"K. c #F6D19B",
"L. c #C1C1A3",
"P. c #C1C2AA",
"I. c #DEC3A9",
"U. c #C3C5B8",
"Y. c #D3C4BB",
"T. c #DBC6BB",
"R. c #EACDAB",
"E. c #E6C8A4",
"W. c #F2CEA5",
"Q. c #FDDAA4",
"!. c #FDDDAB",
"~. c #F7D6AB",
"^. c #E7CCB4",
"/. c #E7D2BA",
"(. c #FCDEB4",
"). c #F7DBB9",
"_. c #EBD1AD",
"`. c #FEE1AD",
"'. c #FDE2BB",
"]. c #FEE6B7",
"[. c #ABABC0",
"{. c #B6BEC4",
"}. c #BCBDC3",
"|. c #BBBCCB",
" X c #B3B6C7",
".X c #B6B6CA",
"XX c #C0BFD1",
"oX c #BCC2C4",
"OX c #BBC3CC",
"+X c #B7C1CE",
"@X c #BCC4D1",
"#X c #BEC8D0",
"$X c #C2C5C5",
"%X c #C9CACB",
"&X c #D6C9C4",
"*X c #DAD2CB",
"=X c #C2C5D2",
"-X c #C4CAD4",
";X c #CBCCD5",
":X c #CCCADB",
">X c #C9C6D7",
",X c #D2CDD8",
"<X c #CDD2D5",
"1X c #CDD3DA",
"2X c #D1D3D7",
"3X c #D4D5DA",
"4X c #D5D9DB",
"5X c #DBDCDB",
"6X c #DCD7D4",
"7X c #E1CEC2",
"8X c #E8D9C8",
"9X c #E2DAD5",
"0X c #E3DEDD",
"qX c #E6D9D4",
"wX c #F3DBC2",
"eX c #DEE0DC",
"rX c #FDE5C2",
"tX c #FEEBCC",
"yX c #FAE6C9",
"uX c #E1E1DF",
"iX c #EFE4D3",
"pX c #FDEDD4",
"aX c #FCEFDB",
"sX c #F3E6D9",
"dX c #FFF1D7",
"fX c #CBCCE1",
"gX c #CFD2E1",
"hX c #D4D5E3",
"jX c #DADDE6",
"kX c #D6DBEB",
"lX c #DADBEC",
"zX c #D3D5EA",
"xX c #DADDF1",
"cX c #D7D9F0",
"vX c #D0CFE1",
"bX c #E5DFE4",
"nX c #DDE1E9",
"mX c #DEE0F3",
"MX c #E4E4E3",
"NX c #EBEAE6",
"BX c #E3E4ED",
"VX c #EDEBEA",
"CX c #E9E5E5",
"ZX c #F5EDE5",
"AX c #F8F0E7",
"SX c #E3E5F4",
"DX c #E7E8F5",
"FX c #EBEBF6",
"GX c #EEEDF8",
"HX c #F2F1F5",
"JX c #FAF6F2",
"KX c #FFFAF3",
"LX c #F5F4F9",
"PX c #FDFBF9",
"IX c #F0EFF4",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJ G k G L L k h G F UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXH L ) [ C.J.!.'.yXdX'.G.[ ) k F UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXH T B.H.H.J.tXKXtX`.J.V.`.KXaX!.H.f.T G UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXH ) K.'.rXtXrXKX!.x t e w v e t } '.!.H.H.B.K S UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXG G.tX!.V.} B pX'.t w e w w B e e t v X.H.H.H.~.u.D UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXF K ).!.B e t e e H.dXw e e e e V e e t t v | A.V.~.ZX&X< UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXD T yXV.t e e e e t b KXx t e e e x e w t e e | v e v  .iX9Xa < UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXK rX!.e e e e r w e v dX .e e e e e w t t e t ! e e t e v (.CXa UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXL `.tXv e b m e w w w t J.H.t e e w e e v w v V t e e t t z e K.*X, UXUXUXUXUXUXUXUX",
"UXUXUXUXUXh C.tXX.e w e b e w w w e B Q.v v z v z v b x V ! z v b z b b N C pXl.p UXUXUXUXUXUXUX",
"UXUXUXUXD ) `.dXb t w w e e e e w w e J.b b x N x N N Z D.N M ! N V V / | } K.JX*.UXUXUXUXUXUXUX",
"UXUXUXUXh H.tX].w w e e e w w e e z c  .B B b B m Q Q [ Z.Q ~ ' Q ] ' ]  .N.N.iX9Xi UXUXUXUXUXUX",
"UXUXUXF { `.].tXB w w w e x z z x N c ! ! ! Z E R W { R.f.f.M.N.m.M.N...m.D.F.8XVX-.> UXUXUXUXUX",
"UXUXUXl Q.`.} B A.X.b b z w N N b C m !  .} E ( I ( k.S.g.S.E.M.F.S.W.M.M.R._.8XCX0Xi UXUXUXUXUX",
"UXUXUXT `.} e w w B B.} m x x C N ! ] } m.` y.s.i.y.7Xa.I.k.^.R.^.S.I.^.^./.8X8XuXVX$.UXUXUXUXUX",
"UXUXh [ A.t e e e w z B X.! m C } V  .{ M.).a.j.j.*X&Xz.z.Y.T.7XT.&X*X*X6X6X5X0XMXNXl.O.UXUXUXUX",
"UXUXl H.B t e e e e e e z ! V.! m ^ ` P p.Y.i #.-.NX,Xz.&X>X}.q.>X,X,X3X2X5X5X0XuXMX5XO.UXUXUXUX",
"UXUXk A.t e e e e e e e e z B X.K.y.y.d u UXUXUXUX&.-.vXXX[.7.[.=X>X;X2X2X3X5X5XuXuXVX@.UXUXUXUX",
"UXUXT  .e e e w e e e e t v B Z f.sX6Xu UXUXUXUXUXUXo.3.XX[.[.[..X>X>X;X2X2X4X5XuXuXNX%.UXUXUXUX",
"UXg ) } t t e e e e t t v v M E P i.-.UXUXUXUXUXUXUXUX+.>X6.6.[.[.=X-X;X<X2X3X5X5XeXMX>.UXUXUXUX",
"UXh {  .e e e t t t e e v M W U a.p.i UXUXUXUXUXUXUXUX@.}..X6.4.[.+X=X-X;X<X<X4X5X5XMX9.UXUXUXUX",
"UXS { V.e e e e e e e t M Z _ M.E.:.u UXUXUXUXUXUXUXUXo.7..X6.6.[.|.@X-X-X;X<X1X4X5XMXe.UXUXUXUX",
"UXD { A.e t e e e e e v Z W ` y.l.9X9.UXUXUXUXUXUXUXUX@.$Xq.3.3.6.|.@X@X=X;X<X<X4X4XMX3.UXUXUXUX",
"UXg { J.C t w e e e e M E W u.l.%X:X@.UXUXUXUXUXUXUXUX> 6X<.>.3.8.|.+X@X#X=X-X<X<X1XMX>.UXUXUXUX",
"UXUX) H.A.t t e e e b ..F.I.j.7.[.XX>.o.UXUXUXUXUXo + 2.6X2.2.>.8.OXoX+X@X-X-X<X<X4XMX%.UXUXUXUX",
"UXUXK H.J.} b b  .C.D.M.d.k.j.w.XX:XhX%.@.UXUXUXo O : CXU.,.2.>.9.oX|.oX+X@X-X%X<X<XMX@.UXUXUXUX",
"UXUXG A.J.].J.^ N / ~ d.E.I.z.>XfX>X:XlXw.%.> o * % k.*XU.P.,.2.n.n.oXoXOX+X#X-X-X1X4Xo.UXUXUXUX",
"UXUXJ M.].'.v z B ~ [ M.S.^.6XfXfXfX:X>X%Xp.o 6 1 - d v.P.L.v.v.c.n.oXoXoX#X#X@X#XgXw.o.UXUXUXUX",
"UXUXUXI aXpXe v / [ f.F.R.qX5XzXfX:X:X:X8.$ j 9 1 2 % :.,.v.v.P.c.b.n.oXoXoXOX@X-X1X%.UXUXUXUXUX",
"UXUXUXs VXJXv N / B.Z.W.^.qXlXcXzXvX,X>Xs & D.5 1 2 @ =.:.L.L.v.c.c.b.oXoXoX+X@X-X<Xo.UXUXUXUXUX",
"UXUXUXp x.PX! N ~ ] G.W.8X0XmXcXkXlXhX}.o W ..1 3 4 7 ; L.h.L.v.v.c.b.n.n.oX+X+X<X>.o.UXUXUXUXUX",
"UXUXUXUXp VXQ.! } Z.W._.8XbXmXcXcXlXlXD = _ 5 3 4 5 9 % f L.:.,.v.1.0.n.e.{.+X@X@Xo.UXUXUXUXUXUX",
"UXUXUXUX, ;.JX .B.] ~.W.sXbXmXmXkXkXjX& 6 n 3 4 5 5 9 n # P.,.,.<.c.0.n.{.{.{.-X&.UXUXUXUXUXUXUX",
"UXUXUXUXUXp &X'.B.H.~.wXCXDXSXmXxXmXgX$ * ` 5 5 5 8 y E ; =.b.<.<.<.0.r.w.{.#X8.o.UXUXUXUXUXUXUX",
"UXUXUXUXUXUXi MXyX~.).sXCXDXDXmXmXxX1X+ n )...8 8 0 y ' Y : b.c.<.<.<.w.w.OX{.o.UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX#.VXAXyXsXIXGXDXSXmXkXgX+ _ aXyXZ 0 0 0 } ..$ b.b.1.<.r.w.n.oX@.UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX$.CXJXIXGXGXGXSXSXkXgX$ n AXpXm.0 e 0 ..D.# n.b.b.<.8.n.{.@.UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXO.0XLXLXGXGXFXSXkXkX& 7 K.).| 0 t e V.M.% n.b.w.w.n.8.o.UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUX@.%XLXLXIXGXDXnXkXj.@ A Z y 0 e B G.D d U.n.$XoX>.o.UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXO.+.3XLXGXDXnXlXkXD @ 6 9 c A W g : U.%X<X9.@.o.UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUX@.&.,XVXFXSXnXjXj.; # + $ ; =.<X%X9.+.o.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXX o.&.oX2X1XjXjXjX4X-XoX8.%.u X UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  . X X o.o.o.o.o.X . UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
