/* XPM */
/* $XConsortium: editor.pm /main/2 1996/07/23 12:48:17 drk $ */
static char * Fpenpad [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 15 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s bottomShadowColor	m black	c #646464646464",
"X	s iconColor2	m white	c white",
"o	s topShadowColor	m white	c #c8c8c8c8c8c8",
"O	s iconGray1	m white	c #e1e1e1e1e1e1",
"+	s iconGray8	m black	c #323232323232",
"@	s iconColor1	m black	c black",
"#	s iconGray6	m black	c #646464646464",
"$	s iconGray5	m black	c #7d7d7d7d7d7d",
"%	s iconGray7	m black	c #4b4b4b4b4b4b",
"&	s iconGray3	m white	c #afafafafafaf",
"*	s iconGray2	m white	c #c8c8c8c8c8c8",
"=	s iconColor6	m white	c yellow",
"-	s iconGray4	m white	c #969696969696",
";	s selectColor	m white	c #7d7d7d7d7d7d",
/* pixels */
"                                ",
"  .......................       ",
"  .XXXXXXXXXXXXXXXXXXXXXo       ",
"  .XOOOOOOOOOOOOOOOOOOO+o       ",
"  .XOOOOOOOOOOOOOOOOOOO+o       ",
"  .XOO@@#O@O#@#OOOOOOOO+o       ",
"  .XOOOOOOOOOOOOOOOOOOO+o       ",
"  .XOOOOOOOOOOOOOOOOOOO+o       ",
"  .XOO#@O#O+O@#@O#@OOOO+o       ",
"  .XOOOOOOOOOOOOOOOOOOO+o       ",
"  .XOOOOOOOOOOOOOOOOOOO+o       ",
"  .XOO@#@O@$@$OOOOOOOOO+o       ",
"  .XOOOOOOOO%@$&OOOOOOO+o       ",
"  .XOOOOOOOO%&XX&*OOOOO+o       ",
"  .XOOOOOOOOO%XO=&*OOOO+o       ",
"  .XOOOOOOOOO%#&O=&*OOO+o       ",
"  .XOOOOOOOOOO%#&O=&*OO+o       ",
"  .XOOOOOOOOOO&%#&O=&*O+o       ",
"  .XOOOOOOOOOO&&%#&O=&*+o       ",
"  .XOOOOOOOOOO*&&%#&O=&*o       ",
"  .XOOOOOOOOOOO*&&%#&O=&*       ",
"  .XOOOOOOOOOOOO*&&%#&O=&*      ",
"  .XOOOOOOOOOOOOO*&&%#&O=&*     ",
"  .XOOOOOOOOOOOOOO*&&%#&O=&*    ",
"  .XOOOOOOOOOOOOOOO*&&%#&O=&*   ",
"  .XOOOOOOOOOOOOOOOO*&&%#&O%%*  ",
"  .XOOOOOOOOOOOOOOOOO*&+%%#OO-% ",
"  .XOOOOOOOOOOOOOOOOOO*+ %%-O-% ",
"  .X++++++++++++++++++++ ;%--%%;",
"  .oooooooooooooooooooooo;;%%%;;",
"                          ;;;;; ",
"                           ;;;  "};
