/* XPM */
/* $XConsortium: mdticon.pm /main/4 1996/10/29 15:56:33 drk $ */
static char * mdticon_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"125 188 18 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	c #C2C2D9D9D3D3",
"X	c #3C3C56565050",
"o	c #7676A9A99C9C",
"O	s iconColor1	m black	c black",
"+	c #51515151FBFB",
"@	c #959595959595",
"#	s iconGray5	m black	c #737373737373",
"$	c #DFDFDFDFDFDF",
"%	s iconColor6	m white	c yellow",
"&	c #AEAEAEAEAEAE",
"*	s iconGray6	m black	c #636363636363",
"=	c #BEBEBEBEBEBE",
"-	s iconGray8	m black	c #212121212121",
";	s iconGray7	m black	c #424242424242",
":	s iconColor7	m white	c cyan",
">	c #FAFA13134040",
",	s iconColor8	m black	c magenta",
/* pixels */
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"         .......................................X                                                                            ",
"         ......................................XX                                                                            ",
"         ..ooooooooooooooooooooooooooooooooooooXX                                                                            ",
"         ..ooooooooooooooooooooooooooooooooooooXX                                                                            ",
"         ..ooo                             OoooXX                                                                            ",
"         ..ooo +@+@+@+@+@+@+@+@+@+@+@+@+@+@OoooXX                                                                            ",
"         ..ooo @+@+@+@+@+@+@+@+@+@+@+@+@+@+OoooXX                                                                            ",
"         ..oo      +@+@+@+@+@+@+@+@+@+@     OooXX                                                                            ",
"         ..oo @@@@@ +@+@+@+@+@+@+@+@+@ @@@@@OooXX                                                                            ",
"         ..oo @@@@@@ +@+@+@+@+@+@+@+@ @@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@          #@#   @@@@@@@OooXX                                                                            ",
"         ..oo @@@@ $@@@@@@@@@@#% &#@@@@@@@@@OooXX                                                                            ",
"         ..oo @@@@O $@@@@@@@@#$*% &#@@@@@@@@OooXX                                                                            ",
"         ..oo @@@O=O $@@@@@@*-*@*% &#@@@@@@@OooXX                                                                            ",
"         ..oo @@@*O=O $@@@@@@#-*@*% &#@@@@@@OooXX                                                                            ",
"         ..oo @@@@*O=OO@@@@@@@#-*@*% &#@@@@@OooXX                                                                            ",
"         ..oo @@@@@*O@; @@@@@@@#-*@*% &#@@@@OooXX                                                                            ",
"         ..oo @@@@@@@O@; @@@@@@*$;*&*% &#@@@OooXX                                                                            ",
"         ..oo @@@@@@@@O@; @@@@*$=;-*&*% $#@@OooXX                                                                            ",
"         ..oo @@@@@@@@@O@; @@*$=###;*@*%O@@@OooXX                                                                            ",
"         ..oo @@@@@@@@@@O@;+:$=###@@;*$O#@@@OooXX                                                                            ",
"         ..oo @@@@@@@@@@@O+:+*+-@@@@@-O@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@@@@#+:&#+-;@@@@@@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@@@@+:+#+-;*@@@@@@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@@@+:&#+-;-**-@@@@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@@+:+#+-;-#>%$-@@@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@+:&#+-#*->%>%$-@@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@@+:+#+-#@@-;>%>%$-@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@+:&#+-#@@@@-;>%>%$-@@@@@@OooXX                                                                            ",
"         ..oo @@@@+:+#+-#@@@@@@-;>%>%$-@@@@@OooXX                                                                            ",
"         ..oo @@@++&#+-#@@@@@@@@-;>%>%-*@@@@OooXX                                                                            ",
"         ..oo @@@++++-#@@@@@@@@@@-;>%>-*@@@@OooXX                                                                            ",
"         ..oo @@@----#@@@@@@@@@@@@-;--@@@@@@OooXX                                                                            ",
"         ..oo @@@@;@@@@@@@@@@@@@@@@##@@@@@@@OooXX                                                                            ",
"         ..oo @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@OooXXoooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo      ",
"         ..ooOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOooX.......................................................................      ",
"         ..oooooooooooooooooooooooooooooooooooo.......................................................................X      ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX      ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX      ",
"         ..oooooooooooooooooooo  oooooo ooooooooooooooooooooooooooooooooooooooo  ooooooooooooooooooooooooooooooooooooXX      ",
"         ..oo    ooooooooooooooo oooooo ooooooooooooooooooooo  o   ooooooooooooo ooooooooooooooooooooooooooooooooooooXX      ",
"         ..ooo oo ooo  oooo   oo o  oo    ooo  oo o  oooooooo ooo ooo  ooo o   o o  oo    ooo  oo  o  ooo  o oo  ooooXX      ",
"         ..ooo oo oo oo oo ooooo o oooo oooo oo oo oo o     o o o oo oo ooo oooo o ooooo ooo oo oo oo oo oo oo oo oooXX      ",
"         ..ooo oo oo   oooo  ooo  ooooo oooo oo oo oo ooooooo o o oo   oooo oooo  ooooo oooo   ooo oo oo oo oo   ooooXX      ",
"         ..ooo oo oo oo ooooo oo o oooo oo o oo oo oo oooooooo o ooo oo ooo oooo o ooo oo oo oo oo oo oo oo oo oo oooXX      ",
"         ..oo    oooo  ooo   oo  o  oooo  ooo  ooo   ooooooooo o oooo  ooo    o  o  oo    ooo  oooo  o oo   ooo  ooooXX      ",
"         ..ooooooooooooooooooooooooooooooooooooooo oooooooooooooooooooooooooooooooooooooooooooooooooooooooo oooooooooXX      ",
"         ..oooooooooooooooooooooooooooooooooooooo    ooooooooooooooooooooooooooooooooooooooooooooooooooo   ooooooooooXX      ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX      ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX      ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX      ",
"            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX      ",
"                                                                                                                             ",
"                                                                                                                             ",
"         .......................................X                                                                            ",
"         ......................................XX                                                                            ",
"         ..ooooooooooooooooooooooooooooooooooooXX                                                                            ",
"         ..ooooooooooooooooooooooooooooooooooooXX                                                                            ",
"         ..oooo                     =**@&  ooooXX                                                                            ",
"         ..ooo o&o&o::&&:::::&&o&o$**@$***& oooXX                                                                            ",
"         ..oo o&o&o&--:::&&&:&&&o$**@$$$o&o&OooXX                                                                            ",
"         ..oo &o&o&o-#-&&o&o&::::-*-$$;##o&oOooXX                                                                            ",
"         ..oo o&o&o&** *#&o&o&o:---@ $$$-&o&OooXX                                                                            ",
"         ..oo &o&o&o&**  *&o&o&OOO&=$$$--o&oOooXX                                                                            ",
"         ..oo o&o&o&o*- *%%&o&o&o&$$@@=-o&o&OooXX                                                                            ",
"         ..oo &o&o&=&*-*%$% $$$$$+*@*--o&o&oOooXX                                                                            ",
"         ..oo o&o&o&o&*#%%$% ===$+$$-&o&o&o&OooXX                                                                            ",
"         ..oo &o&o&o&o&*#%%$% @=$+$=*o&o&o&oOooXX                                                                            ",
"         ..oo o&o&o&o&o$*#%%$% +++$+*&o&o&o&OooXX                                                                            ",
"         ..oo &o&o&o&o$$@*#%%$% #*+*-*&o&o&oOooXX                                                                            ",
"         ..oo o&o&o&oo$@-&*#%%$% +*-**o&o&o&OooXX                                                                            ",
"         ..oo &o&o&o;$;-&o&*#%%$% #*@@*o&o$@$ooXX                                                                            ",
"         ..oo o&o&o-$$-&o&o**#%%$% -*@$$$$*@$ooXX                                                                            ",
"         ..oo &o&o-$$-&o&$>+**#%%$% -*@&&@-*OooXX                                                                            ",
"         ..oo o&o&o--&o&$>=****#%%$% ----*o&OooXX                                                                            ",
"         ..oo &o&o&o&o&o>*>=*-**#%%$% &o&o&oOooXX                                                                            ",
"         ..oo o&o&o&o&o&*>*>=*o&*#%%$% &o&o&OooXX                                                                            ",
"         ..oo &o&o&o&o&$*->*>-$$&*#%%$% &o&oOooXX                                                                            ",
"         ..oo o&o&o&o&$=*-->-$=$$&*#%%$% &o&OooXX                                                                            ",
"         ..oo &o&o&o&$$=@---*@$$$$&*#%%$% &oOooXX                                                                            ",
"         ..oo o&o&o&$$$=*-o-*-*=$$o&*#%%;,;;OooXX                                                                            ",
"         ..oo &o&o&$@$=@-o&o&*$=@-&o&*#;,$,$;ooXX                                                                            ",
"         ..oo o&o&$$$@--o&o&o$$=-&o&o&*->,$,;ooXX                                                                            ",
"         ..oo &o&$$$=-&o&o&&$$=-&o&o&o&*->,;;ooXX                                                                            ",
"         ..oo o&$$$=-&o&o&*$$&-&o&o&o&o&*;;;OooXX                                                                            ",
"         ..oo &$*$&-&o&o&$$$**&o&o&o&o&o&o&oOooXX                                                                            ",
"         ..oo $$@**&o&o&o*$$$oo&o&o&o&o&o&o&OooXX                                                                            ",
"         ..oo -$$&&o&o&o&o*$$$$*&o&o&o&o&o&oOooXX                                                                            ",
"         ..ooo--$$o&o&o&o&o---*&o&o&o&o&o&oOoooXXoooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo            ",
"         ..oooo--@$OOOOOOOOOOOOOOOOOOOOOOOOooooX.................................................................            ",
"         ..oooooooooooooooooooooooooooooooooooo.................................................................X            ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX            ",
"         ..oo                                                                                                ooXX            ",
"         ..oo      OO      O      O                                        O           OO    OO              ooXX            ",
"         ..oo OOO   O      O                                               O            O     O              ooXX            ",
"         ..oo  O O  O OO  OOOO   OO    OO  O OO          OO   O OOO  OOO  OOOO   OO     O     O    OO  O OO  ooXX            ",
"         ..oo O  O  O O    O      O   O  O  O  O        O  O   O    O      O    O  O    O     O   O  O  O  O ooXX            ",
"         ..oo OOOO  OO     O      O   O  O  O  O        OOO    O     OO    O    OOO     O     O   OOO   O  O ooXX            ",
"         ..oo O  O  O O    O  O   O   O  O  O  O        O  O   O       O   O  O O  O    O     O   O  O  O  O ooXX            ",
"         ..ooOO  OOOO OO    OO  OOOOO  OO  OOO OO        OO   OOOO  OOO     OO   OO   OOOOO OOOOO  OO  OOO OOooXX            ",
"         ..oo                                                                                                ooXX            ",
"         ..oo                                                                                                ooXX            ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX            ",
"         ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX            ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX            ",
"         XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX            ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"         .......................................X                                                                            ",
"         ......................................XX                                                                            ",
"         ..ooooooooooooooooooooooooooooooooooooXX                                                                            ",
"         ..ooooooooooooooooooooooooooooooooooooXX                                                                            ",
"         ..oo                         oooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ===OO=O;;==;;=;;=OO====OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ===OO==OO;O;;=OO=;OO===OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==OO=O;;=O;=O=OO;OO====OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==OOO=OO;==O;;OO=OO;;==OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==O;;=;OO=O;;O==;;=O===OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==O;;OO;O=;OO=OO;;OOO==OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==OO=O;=;;OO=;;;;=OO===OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ===OO=;;=OOO=O==;=;O===OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==O;;;=O;;=OOO==;;;O===OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==;=;;O;;=;;=O;;O=O====OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo ==OO=;O=OO=============OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXX                                                                            ",
"         ..oo =======================OoooooooooXXoooo                                                                        ",
"         ..oo OOOOOOOOOOOOOOOOOOOOOOOOoooooooooX.....                                                                        ",
"         ..oooooooooooooooooooooooooooooooooooo.....X                                                                        ",
"         ..ooooooooooooooooooooooooooooooooooooooooXX                                                                        ",
"         ..ooooooooooooooooooooooooooooooooooooooooXX                                                                        ",
"         ..oooooooooooooo  ooooooooooooooooooooooooXX                                                                        ",
"         ..ooooooooooooooo ooooooooooooooooooooooooXX                                                                        ",
"         ..ooo  ooooo  ooo   oo  oo  oo  ooo o   ooXX                                                                        ",
"         ..ooooo ooo oo oo oo oo ooo o oo ooo oooooXX                                                                        ",
"         ..ooo   ooo ooooo oo ooo o oo   oooo oooooXX                                                                        ",
"         ..oo oo ooo oo oo oo ooo o oo oo ooo oooooXX                                                                        ",
"         ..ooo  o ooo  oo   o  ooo oooo  ooo    oooXX                                                                        ",
"         ..ooooooooooooooooooooooooooooooooooooooooXX                                                                        ",
"         ..ooooooooooooooooooooooooooooooooooooooooXX                                                                        ",
"         ..ooooooooooooooooooooooooooooooooooooooooXX                                                                        ",
"         ..ooooooooooooooooooooooooooooooooooooooooXX                                                                        ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX                                                                        ",
"         XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX                                                                        ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             ",
"                                                                                                                             "};
