/* XPM */
static char *shotwell_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 244 2 ",
"   c #000D15",
".  c #001017",
"X  c #01131A",
"o  c #151515",
"O  c #011720",
"+  c #011A23",
"@  c #01212E",
"#  c #022532",
"$  c #022836",
"%  c #2B2C2B",
"&  c #333432",
"*  c #3A3B39",
"=  c #4A0F0E",
"-  c #4B100F",
";  c #4C1110",
":  c #561311",
">  c #551B1A",
",  c #6F1917",
"<  c #741A17",
"1  c #374516",
"2  c #3B4B16",
"3  c #3D4D1A",
"4  c #4A5C20",
"5  c #4A572E",
"6  c #4B5731",
"7  c #4E6323",
"8  c #556B26",
"9  c #597028",
"0  c #576637",
"q  c #5F713B",
"w  c #687B3E",
"e  c #013144",
"r  c #03364A",
"t  c #03394D",
"y  c #033C52",
"u  c #04445C",
"i  c #324C56",
"p  c #3F555D",
"a  c #054A64",
"s  c #044E6A",
"d  c #05526F",
"f  c #055B7B",
"g  c #434542",
"h  c #484A47",
"j  c #765553",
"k  c #795553",
"l  c #7D5B59",
"z  c #415760",
"x  c #415861",
"c  c #676866",
"v  c #6C6C6A",
"b  c #93211D",
"n  c #9B231F",
"m  c #9D2420",
"M  c #93322E",
"N  c #953330",
"B  c #A52622",
"V  c #AF2924",
"C  c #B62B26",
"Z  c #B92C27",
"A  c #C12C27",
"S  c #C52E29",
"D  c #C82E29",
"F  c #C9302B",
"G  c #A05F5B",
"H  c #A4605C",
"J  c #AB625E",
"K  c #B0635F",
"L  c #996F6E",
"P  c #9F7675",
"I  c #A16965",
"U  c #B66460",
"Y  c #BD6662",
"T  c #B37D7B",
"R  c #C06763",
"E  c #67812E",
"W  c #6A852E",
"Q  c #6D8634",
"!  c #6F8836",
"~  c #708B32",
"^  c #759133",
"/  c #799635",
"(  c #7D9A36",
")  c #77913B",
"_  c #728742",
"`  c #7B9343",
"'  c #819F37",
"]  c #80A036",
"[  c #84A33A",
"{  c #8BAC3D",
"}  c #8FB03E",
"|  c #91B33F",
" . c #819B46",
".. c #80964F",
"X. c #819948",
"o. c #819651",
"O. c #869B57",
"+. c #83955B",
"@. c #86A048",
"#. c #89A449",
"$. c #8DA94B",
"%. c #92AE4D",
"&. c #93B343",
"*. c #95B24E",
"=. c #99B750",
"-. c #9DBC52",
";. c #8A9B64",
":. c #81827F",
">. c #8DA061",
",. c #8FA168",
"<. c #90A267",
"1. c #94A668",
"2. c #96A86C",
"3. c #9AAD6C",
"4. c #9AB163",
"5. c #A0B56F",
"6. c #055F80",
"7. c #066284",
"8. c #06678B",
"9. c #066D92",
"0. c #067199",
"q. c #0778A3",
"w. c #077FAB",
"e. c #036CB2",
"r. c #0E6BB0",
"t. c #126EB2",
"y. c #0475B7",
"u. c #057DBD",
"i. c #6A7D83",
"p. c #0280AE",
"a. c #0884B1",
"s. c #0889BA",
"d. c #1F8DBD",
"f. c #4B98B4",
"g. c #5BACBC",
"h. c #73A2B4",
"j. c #78B5B9",
"k. c #0685C2",
"l. c #0C87C1",
"z. c #078CC7",
"x. c #088FC1",
"c. c #068CC8",
"v. c #1188C0",
"b. c #0892C5",
"n. c #0394CD",
"m. c #0894CC",
"M. c #0999CF",
"N. c #1A92C3",
"B. c #129DCE",
"V. c #1C9FCC",
"C. c #0499D0",
"Z. c #099BD1",
"A. c #2A96C0",
"S. c #1DA0CD",
"D. c #2CA3C9",
"F. c #4A96C7",
"G. c #4B9CCB",
"H. c #5497C8",
"J. c #4CA2CF",
"K. c #4CA7D3",
"L. c #4DACD7",
"P. c #4EB6DE",
"I. c #4FB8DF",
"U. c #7CB3D7",
"Y. c #7CB7DA",
"T. c #7DBBDC",
"R. c #7DC0DF",
"E. c #7EC5E3",
"W. c #7ECBE7",
"Q. c #9BA684",
"!. c #A4AC92",
"~. c #A8B195",
"^. c #B4BF9C",
"/. c #8A9CA2",
"(. c #8EB5AF",
"). c #8EBCB5",
"_. c #A5A6A4",
"`. c #ABACA9",
"'. c #A5BCAB",
"]. c #B0B1AE",
"[. c #B7BCAB",
"{. c #B8B9B6",
"}. c #BCBDBB",
"|. c #C28481",
" X c #CA8684",
".X c #C38D8B",
"XX c #D58986",
"oX c #DE8B88",
"OX c #E18C89",
"+X c #D1AFAE",
"@X c #C5B2AF",
"#X c #D2B0AF",
"$X c #B7C29F",
"%X c #A8C3B0",
"&X c #CBC9A7",
"*X c #C3CEA8",
"=X c #C5D1AA",
"-X c #DCD1A8",
";X c #C2C7B6",
":X c #C3C8B7",
">X c #C5C9BE",
",X c #CDD9B2",
"<X c #EEDBB4",
"1X c #FEE2B8",
"2X c #83B3D7",
"3X c #BED6E9",
"4X c #C4C5C3",
"5X c #C6C9C3",
"6X c #C8CBC4",
"7X c #CBCBCB",
"8X c #CCD1C3",
"9X c #D5DDC1",
"0X c #D1D1D1",
"qX c #DAD6D4",
"wX c #D6D8D4",
"eX c #DBDFD2",
"rX c #DDDEDD",
"tX c #E6D2D1",
"yX c #DAE4C4",
"uX c #DEE9C5",
"iX c #D9E0CB",
"pX c #FFECCE",
"aX c #E2E7D9",
"sX c #E6EADC",
"dX c #D7E1E4",
"fX c #D8E2E5",
"gX c #D1E2EF",
"hX c #DEEAF4",
"jX c #E5E5E4",
"kX c #E9E7E6",
"lX c #E7E8E7",
"zX c #EAEAE5",
"xX c #E7E7E8",
"cX c #E6E8E8",
"vX c #EAEBEA",
"bX c #F6EDED",
"nX c #EAEFF0",
"mX c #F7F7F6",
"MX c #FAF4F4",
"NX c #F8F9F5",
"BX c #F7F7F8",
"VX c #F7F8F8",
"CX c #FDFEFD",
"ZX c None",
/* pixels */
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX% & & & & & & & & & & & & & & & & & & & & & & ZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX% _.0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX7XZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX& 6XCXzXsXsXsXsXsXsXsXsXsXsXsXsXzXsXsXsXsXsXsXsXmXjXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX% 7XzX2.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.>.iXjXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXo & 4XaXO.Q ! ! ! ! Q ! ! ! ! ! W W W W W W W W ` 9XvXZXZXZX",
"ZXZX* `.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.0XwX>X:X;X;X:X:X;X:X;X;X:X[.+.~ ~ ~ ~ ~ ~ ~ ` 9XjXZXZXZX",
"ZXZXg rXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXvX;.^ ^ / ^ ) ^ ^  .9XcXZXZXZX",
"ZXZXg rXCXgX3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3XhXCXkX1./ / / / / / /  .yXcXZXZXZX",
"ZXZXg rXCXH.r.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.2XCXzX1.( ( ( ( ( ' ( #.9XcXZXZXZX",
"ZXZXg rXCXF.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.U.CXzX1.] ] ' ' [ ' ' $.yXcXZXZXZX",
"ZXZXg rXCXG.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.e.Y.CXzX3.[ [ { [ [ [ [ %.yXcXZXZXZX",
"ZXZXg rXCXJ.y.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.T.CXzX2.[ { { { { { { *.yXxXZXZXZX",
"ZXZXg rXCXK.k.k.k.k.k.k.k.v.d.l.k.k.k.k.l.l.k.k.k.k.k.k.k.k.k.R.CXzX;.( { } } } &.{ =.yXxXZXZXZX",
"ZXZXg rXCXL.c.c.z.z.z.z.A.'.&X(.N.c.z.z.z.z.z.z.z.z.c.c.c.c.c.E.CXkX;.W [ } | | &.| -.uXxXZXZXZX",
"ZXZXg rXCXP.n.m.M.M.m.m.j.1XpX<Xg.m.m.M.m.m.m.m.m.m.m.m.m.n.n.E.CXvXQ.;.;.5.5.4.&.| -.uXxXZXZXZX",
"ZXZXg rXCXP.C.Z.Z.Z.Z.Z.j.1XpX<Xg.C.Z.Z.Z.Z.Z.M.M.M.M.Z.M.Z.C.W.CXvXwXvXnXvXvX:X .( %.uXxXZXZXZX",
"ZXZXg rXCXP.C.Z.Z.Z.Z.Z.D.%X-X).S.Z.Z.Z.Z.Z.Z.M.Z.Z.Z.Z.Z.Z.C.W.CXvXqXbXbXMXCX8X_ W ) ,XvXZXZXZX",
"ZXZXg rXCXP.C.Z.Z.Z.Z.Z.Z.B.S.B.Z.Z.Z.Z.Z.Z.Z.0.s.Z.Z.Z.Z.Z.C.W.CXkXI N N .XCX8X! E ~ =XxXZXZXZX",
"ZXZXg rXCXP.C.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.f q.Z.Z.Z.Z.Z.n.W.CXkXH b b |.CX8X) w Q *XvXZXZXZX",
"ZXZXg rXCXP.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.s 8.Z.Z.Z.Z.Z.w.h.CXkXG m n  XCX8Xw 8 9 ^.vXZXZXZX",
"ZXZXg rXCXP.C.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.b.M.Z.s.t a Z.Z.Z.Z.m.y i.CXkXJ B B  XCX6Xq 7 8 ^.vXZXZXZX",
"ZXZXg rXCXP.M.Z.Z.Z.Z.Z.Z.Z.Z.B.Z.Z.b.6.a.Z.9.+ y m.Z.Z.Z.m.e i.CXkXK V V XXCX6X0 3 4 ^.vXZXZXZX",
"ZXZXg rXCXP.n.M.M.s.a u a d 7.s.m.z.d $ a x.9.+ r s.x.s.x.b.e i.CXzXU C C XXCX>X6 1 3 ~.vXZXZXZX",
"ZXZXg rXCXf.s 7.6.9.# X X X + t y 6.$ X + 0.9.+ O e t $ t a.e i.CXlXY A A oXCX5X5 1 3 ~.vXZXZXZX",
"ZXZXg rXVXx X O + t @ X X X X O X y @ X O a a + X O $ X @ s @ i.CXkXY D D OXVXwX!.!.~.eXcXZXZXZX",
"ZXZXg rXmXz X X X O O X X X X X X + O X X + O X X X O X X O . i.CXkXY F D OXCXjXnXCXCXCXjXZXZXZX",
"ZXZXg rXmXz . X X X X X X X X X X X X X X O X . X X X X X . X i.CXvXY F D OXCXjXvXCXCXCXjXZXZXZX",
"ZXZXg rXBXz X X X X X X X X X X X X X X X X X X X X X X X X X i.CXkXY F D OXVXjXvXCXCXCXxXZXZXZX",
"ZXZXg rXBXz . X X X X X X X X X X X X X X X X X X X X X X X X i.CXkXH C D OXCXjXkXVXCXVXaXZXZXZX",
"ZXZXg rXBXz . X X X X X X X X X X X X X X X X X X X X X X X X i.CXjXk , A OXCXqX}.7X5X6X}.ZXZXZX",
"ZXZXg rXBXz . X X X X X X X X X X X X X X X X X X X X X X X X i.CXkXj : m oXCXrXZXZXZXZXZXZXZXZX",
"ZXZXg rXVXx X X X X X X X X X X X X X X X X X X X X X X X X X i.VXkXj ; < XXCXfXZXZXZXZXZXZXZXZX",
"ZXZXg rXVXz . . . . . . . . . . . X . . . . . . . . . . . . . i.CXkXj ; : T MXrXZXZXZXZXZXZXZXZX",
"ZXZXg rXVXi.i i i i i i i i i i i i i i i i i i i i i i i i i /.CXkXj ; = L MXrXZXZXZXZXZXZXZXZX",
"ZXZXg rXCXcXfXfXdXdXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXdXnXCXjXj ; = L MXrXZXZXZXZXZXZXZXZX",
"ZXZXg rXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXkXj ; - L MXrXZXZXZXZXZXZXZXZX",
"ZXZXg rXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXjXk ; = L MXrXZXZXZXZXZXZXZXZX",
"ZXZXg rXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXkXl > > P NXrXZXZXZXZXZXZXZXZX",
"ZXZXh aXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXvX@X#X+XtXCXrXZXZXZXZXZXZXZXZX",
"ZXZXZXrXCXVXCXVXCXVXVXCXCXVXCXVXCXVXCXCXVXCXVXCXCXCXVXCXCXVXVXCXCXvXjXCXCXCXCXrXZXZXZXZXZXZXZXZX",
"ZXZXZX}.4X4X5X5X5X5X5X}._.`.wXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXaXrXrXqXlXCXCXCXCXrXZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXc jXVXCXVXCXVXVXCXVXCXVXVXCXVXVXCXCXVXVXCXCXCXCXCXCXrXZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXv vXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXfXZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZX:.jXVXVXVXCXNXVXVXVXVXVXVXVXCXVXVXVXVXVXVXVXVXCXNXMXqXZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZX].{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.`.ZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX",
"ZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZX"
};
