/* XPM */
static char *video[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #10100F",
".  c #181817",
"X  c #1C1D1B",
"o  c #181C21",
"O  c #1B222C",
"+  c #1E2327",
"@  c #1D2A3B",
"#  c #1F2935",
"$  c #252624",
"%  c #252A2E",
"&  c #2A2C2D",
"*  c #242729",
"=  c #212933",
"-  c #2D3133",
";  c #2D343C",
":  c #27313B",
">  c #333534",
",  c #333738",
"<  c #353A3B",
"1  c #393C3D",
"2  c #373835",
"3  c #1E2E41",
"4  c #212F42",
"5  c #223143",
"6  c #23344A",
"7  c #2A394C",
"8  c #353C43",
"9  c #3A3F41",
"0  c #333E4B",
"q  c #273951",
"w  c #3E4243",
"e  c #3C444D",
"r  c #37414C",
"t  c #334153",
"y  c #3A4553",
"u  c #3C4A5B",
"i  c #374A62",
"p  c #3D516B",
"a  c #2E4C73",
"s  c #3B5574",
"d  c #3E5878",
"f  c #414544",
"g  c #484946",
"h  c #42464A",
"j  c #44484A",
"k  c #4A4C4C",
"l  c #454D57",
"z  c #4A4E51",
"x  c #424D5B",
"c  c #4D5254",
"v  c #46515E",
"b  c #4C535C",
"n  c #535555",
"m  c #51565C",
"M  c #545A5D",
"N  c #5A5C5B",
"B  c #585956",
"V  c #61635F",
"C  c #455364",
"Z  c #4A5562",
"A  c #4D5865",
"S  c #42546B",
"D  c #4C5A6C",
"F  c #495769",
"G  c #545B63",
"H  c #5A5E61",
"J  c #535E6B",
"K  c #445A74",
"L  c #4C5C71",
"P  c #425772",
"I  c #505F71",
"U  c #5E6265",
"Y  c #52606F",
"T  c #5B626B",
"R  c #4C627D",
"E  c #566373",
"W  c #5A6673",
"Q  c #5F6973",
"!  c #52647B",
"~  c #596778",
"^  c #5D6C7C",
"/  c #626564",
"(  c #656866",
")  c #62666B",
"_  c #666A6B",
"`  c #6A6D6B",
"'  c #696B67",
"]  c #6F716D",
"[  c #72736F",
"{  c #646B72",
"}  c #6B6F71",
"|  c #626E7C",
" . c #6C7172",
".. c #65707C",
"X. c #6B727B",
"o. c #717572",
"O. c #777975",
"+. c #787A76",
"@. c #74797E",
"#. c #7B7E7B",
"$. c #73777B",
"%. c #7E807C",
"&. c #385A87",
"*. c #3E6293",
"=. c #4B6380",
"-. c #5C6D81",
";. c #556F8F",
":. c #516884",
">. c #5D728C",
",. c #446590",
"<. c #4C6A91",
"1. c #476C9C",
"2. c #446895",
"3. c #4D729F",
"4. c #5A7392",
"5. c #55759E",
"6. c #5C799D",
"7. c #577497",
"8. c #647283",
"9. c #6B7683",
"0. c #61758D",
"q. c #6C7B8D",
"w. c #6D7886",
"e. c #737B84",
"r. c #727D89",
"t. c #607896",
"y. c #6B7D93",
"u. c #627B9B",
"i. c #687F9B",
"p. c #476FA5",
"a. c #4A72A6",
"s. c #4E76AB",
"d. c #5275A2",
"f. c #5678A1",
"g. c #5D7DA4",
"h. c #537AAD",
"j. c #597EAF",
"k. c #537DB1",
"l. c #597FB1",
"z. c #607DA2",
"x. c #7E8283",
"c. c #73808E",
"v. c #7D858C",
"b. c #6F8196",
"n. c #6C819D",
"m. c #728195",
"M. c #7C8793",
"N. c #788799",
"B. c #7E8D9B",
"V. c #768699",
"C. c #5E81A9",
"Z. c #5D83B3",
"A. c #5A84B7",
"S. c #6B84A4",
"D. c #6584AC",
"F. c #6986AC",
"G. c #6D89AD",
"H. c #6781A2",
"J. c #7489A4",
"K. c #7B8DA1",
"L. c #768EAC",
"P. c #798FAA",
"I. c #7187A3",
"U. c #7D91AA",
"Y. c #6286B4",
"T. c #6D8DB5",
"R. c #648AB9",
"E. c #6C8EB9",
"W. c #728EB3",
"Q. c #6F91BC",
"!. c #7691B3",
"~. c #7C95B6",
"^. c #7393BC",
"/. c #7996BD",
"(. c #7D99BC",
"). c #6D93C1",
"_. c #7297C2",
"`. c #7699C3",
"'. c #7C9CC4",
"]. c #7B9EC8",
"[. c #7FA0C7",
"{. c #828685",
"}. c #898C89",
"|. c #878A87",
" X c #8E918E",
".X c #91938E",
"XX c #818E9C",
"oX c #848E97",
"OX c #8E9191",
"+X c #899199",
"@X c #939593",
"#X c #969995",
"$X c #95999C",
"%X c #9B9E9B",
"&X c #9EA19D",
"*X c #A2A49F",
"=X c #8392A2",
"-X c #8B99A8",
";X c #989EA3",
":X c #8097B4",
">X c #8199B7",
",X c #829CBC",
"<X c #899FBA",
"1X c #8AA2BE",
"2X c #90A0B2",
"3X c #92A5BC",
"4X c #96A9BE",
"5X c #A3A5A3",
"6X c #A6A9A4",
"7X c #A9AAA6",
"8X c #A7A9AA",
"9X c #ABADAB",
"0X c #AFB1AC",
"qX c #B1B2AF",
"wX c #B3B5B2",
"eX c #B6B9B4",
"rX c #B9BBB6",
"tX c #BBBDBA",
"yX c #BEC0BC",
"uX c #C1C3BE",
"iX c #819EC2",
"pX c #85A2C6",
"aX c #8CA6C4",
"sX c #83A3C9",
"dX c #8AA6C9",
"fX c #8DAACD",
"gX c #90A8C6",
"hX c #93ABCA",
"jX c #8FACD0",
"kX c #92AED0",
"lX c #94B1D3",
"zX c #9AB5D4",
"xX c #9FBAD9",
"cX c #BEBFC0",
"vX c #A4BEDA",
"bX c #A9C2DE",
"nX c #A5C0DC",
"mX c #ADC6E2",
"MX c #C4C5C2",
"NX c #C6C8C5",
"BX c #C9CBC7",
"VX c #CCCDCA",
"CX c #CFD0CD",
"ZX c #D0D2CE",
"AX c #D4D5D3",
"SX c #D7D8D4",
"DX c #D9DAD7",
"FX c #DCDDDB",
"GX c #DFE0DD",
"HX c #E0E1DF",
"JX c #E3E3E2",
"KX c #EAEBEA",
"LX c #E8E9E7",
"PX c #F1F2F1",
"IX c #F8F9F8",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXMXVXVXBXNXMXeXwX9XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXqXtXNXCXDXGXJXJXFXAXZXNXuXNXBXBXNXMXcXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUX&X0XtXNXVXAXVXZXUXUXUXUXUXeXeXuXZXAXAXFXGXHXGXDXBXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX@X5XqXyXuXMXCXAXCXUXUXUXUXUX- #XyXOXUXUXUXUXUXAXAXGXJXAXtXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUX#X5XqXrXUXUXUXuXMXDXGXMX{.c j ( eXeXg < 1 UXUXUXUXUXwXAXJXAXcXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX.X5X9XeXUXUXUXUXUX, / 6XCXVXeX0XrXuXNX|.%.}.&XcXJXJXJXDXAXBXAXZXrXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX&X7X9XUXUXUXUXUX . .%.|.wXyXyXyX0XyXAXHXLXJXHXSXMXMXMXwXUXUXqXZXNXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX@X7XqXwXtXMXCXDXGXGXDXDXZXBXuXNXBXAXDXHXKXJX;XN w - N |.UXUXUXUXBXNX0XUXUXUXUXUX",
"UXUXUXUXUXUXUXUX#XqXrXuXVXVXZXVXeX&X}.%.` V ( yXAXBX5XeXJXIXPXVX Xc V 5X8X5XUX8XMXMX6XUXUXUXUXUX",
"UXUXUXUXUXUXUXUX#XwXNXyX%X.X%.B % O % - < f O.VXDX%.- w U 5XFXPXLXZX9X%X*XeX7XyXuXyX|.UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX7XBXSXwX[ $ UXo o % < w N rXDXNXw , w w , z #XCXHXGXCXrXrXyXuXuX&XUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX|.eXDXJXtX.XUXO O = - 8 @XDXHX@X- 1 k c j 9 e A @.7XCXAXZXMXuX&XN UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX[ @XwXBXAXNXwXv.M e 8 { ZXJXDXU ; e v Z u y C J Q %XVXCXNXyX X_ ( UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX+.}.#X6XwXtXrXyXyXeX6XcXFXJXBXX.) { e.oX+X;XwXNXCXCXBXyX5Xo._ o.V UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUX+.#X&X#.n |.qXyXuXCXAXFXJXLXKXLXJXJXHXGXFXDXAXCXNXeX$X%.UXB o.} c UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXB &X6X*X` UXUXUXOX7XyXCXFXJXJXJXJXDXSXCXNXtXqX$Xx.@._ G M _ } ( < UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUX` 0XrXqX#XUXUXUX1 g M ) X.@.e.e.e...Q J C i u x A T {  . . .( N UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXX ` 9X0X%X}.+.V 2 > & - ; : = @ @ @ 3 6 q t p D E 8.c.M.oXv.$.{  .$.UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXg %..X{.[ / ' V c 1 < ; # @ 3 4 q t u C I ^ 8.c.B.=XXX=XK.c.8.E T X.UXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXX g ` +.O.O.#.#.[ B g 9 e 0 0 y x C J ^ 9.c.M.XXXXN.V.b.0.>.:.p u UXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX> k N V ' [ %.+.( m c b m m c Z Q 9.c.XXK.N.q.y.>.! =.K s i UXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  . $ & 2 2 & X * < < 1 k V _ X.X.| ^ -.! K P L F t UXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXz c m G G l x A J ~ I C p E F u UXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXr.UX9.UX......E UXZ b UXm UXH / UXH H UXG UXv x UXA C ~ I D R m.I.t.UXUX",
"UXUXUXUXUX{.x.@.e.X.{ UXZ UXC UXL L I D UXZ C ! J -.9.X.y.q.y.i.0.u.4.:.5.g.F.G.F.;.z.,X,XH.UXUX",
"UXUX_ UX( UX) { -.0.0.7.R <.5.F.D.F.G.t.F.D.D.T./.iXaXU.dXsXiX].`.^.Y.6.A.R._.^.Q.7.F.1X>XH.UXUX",
"UXUXn / r.=XK.1XpX'.Q.R.<.a.j.Q.E.^.^.H.W.T.E.^.'.dXfXU.sXsX].'.`.).D.f.A.R.Q._.Q.6.E.aX>XH.UXUX",
"UXUXr.gXvXvX3XfXsX`.E.Y.<.1.h.W.^.^.^.S.W.E.Q./.iXfXjXU.sXsX].'._.).D.h.A.Y.Q.^.Q.6.^.hX(.n.UXUX",
"UXUX3XmXbXvX<XpXiX).R.l.,.2.s.^./././.I.!.^.^.'.sXfXjXU.pXsX].`._.).g.d.k.Y.Q.^.Q.u./.hX(.0.UXUX",
"UXUX3XmXnXxX,X(.'.E.Z.Z.,.*.a.^./././.J.!.`./.iXdXkXfXP.sXsX].`._.).h.3.k.Z.Q.^.E.u./.aXy.e UXUX",
"UXUX2XmXnXzX,X!.^.E.Z.h.*.&.a./.iXiXiXL.:XiX'.sXjXlXkXP.sXsX].`._.).f.3.s.Z.E.T.F.0.y.r.M UXUXUX",
"UXUX-XbXxXlX,XG.Q.Y.j.s.*.&.p./.,X,XiXP.:X,X/.,X1X1X>Xy.!.S.H.u.;.7.K d s ! 8...| T { ) UXUXUXUX",
"UXUXXXvXzXjX(.S.E.Z.d.1.&.a &.n.J.V.y.w.9.W J UXU H m b UXl h e y UXr 7 t x J J m UXUXUXUXUXUXUX",
"UXUXUXzXlXdX~.4.;.=.p i q 6 t E UXX.UX{ T c z j c h h h 8 8 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXhXaXn.! v u y t 7 4 @ 5 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXJ.| l y y 0 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXm j y 8 UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXh e UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
