/*
 * CDE - Common Desktop Environment
 *
 * Copyright (c) 1993-2012, The Open Group. All rights reserved.
 *
 * These libraries and programs are free software; you can
 * redistribute them and/or modify them under the terms of the GNU
 * Lesser General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * These libraries and programs are distributed in the hope that
 * they will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with these libraries and programs; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */
/*   $XConsortium: Mrm.h /main/1 1996/04/05 14:41:44 mgreess $ */
/*                                                                      
 *		     Common Desktop Environment				
 *									
 * (c) Copyright 1996 Hewlett-Packard Company                           
 * (c) Copyright 1993, 1994, 1995 Hewlett-Packard Company
 * (c) Copyright 1993, 1994, 1995 International Business Machines Corp.
 * (c) Copyright 1993, 1994, 1995 Sun Microsystems, Inc.
 * (c) Copyright 1993, 1994, 1995 Novell, Inc.
 * (c) Copyright 1995 Digital Equipment Corp.
 * (c) Copyright 1995 Fujitsu Limited
 * (c) Copyright 1995 Hitachi, Ltd.
 *                                                                 
 *
 *                   RESTRICTED RIGHTS LEGEND                              
 *
 * Use, duplication, or disclosure by the U.S. Government is subject to
 * restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
 * Technical Data and Computer Software clause in DFARS 252.227-7013.  Rights
 * for non-DOD U.S. Government Departments and Agencies are as set forth in
 * FAR 52.227-19(c)(1,2).
 * 
 * Hewlett-Packard Company, 3000 Hanover Street, Palo Alto, CA 94304 U.S.A.
 * International Business Machines Corp., Route 100, Somers, NY 10589 U.S.A. 
 * Sun Microsystems, Inc., 2550 Garcia Avenue, Mountain View, CA 94043 U.S.A.
 * Novell, Inc., 190 River Road, Summit, NJ 07901 U.S.A.
 * Digital Equipment Corp., 111 Powdermill Road, Maynard, MA 01754, U.S.A.
 * Fujitsu Limited, 1015, Kamikodanaka Nakahara-Ku, Kawasaki 211, Japan
 * Hitachi, Ltd., 6, Kanda Surugadai 4-Chome, Chiyoda-ku, Tokyo 101, Japan
 */
#ifndef MRM_H
#define MRM_H

/* DtMrmInit.c */
extern void DtMrmInitialize(void);

#endif /* MRM_H */
/* DON'T ADD STUFF AFTER THIS #endif */
