/* XPM */
/* $XConsortium: Dtmanpg.t.pm /main/3 1995/07/18 16:44:34 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtmanpg_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray4     m white c #949494949494",
"+    s iconGray7     m black c #424242424242",
"@    s iconGray5     m black c #737373737373",
/* pixels */
"            ....",
" XXXXXXXXXXo....",
" XXXXXXXXXXo....",
" X   XXOOoXo....",
" XoOooXXXXXo....",
" XXXXXXXXXXo....",
" XXXXXXXXXXo....",
" X++oo+X+XXo....",
" XXOXOXOXOXo....",
" X@++oO++oXo....",
" XXXXXXXXXXo....",
" X   OXOXXXo....",
" XXXXXXXXXXo....",
" X   XXXXXXo....",
" XXXXXXXXXXo....",
" ooooooooooo...."};
