/* XPM */
/* $XConsortium: Dtexec.m.pm /main/3 1995/07/18 16:37:20 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * execute [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 7 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray1     m white c #dededededede",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor6	m white	c yellow",
"O	s iconColor2	m white	c white",
"+    s iconGray7     m black c #424242424242",
"@    s iconGray5     m black c #737373737373",
/* pixels */
"  ............................  ",
" . X X X X X X X X X X XoX X X. ",
". X X X X X X X X X X oO+ X X X+",
".X X X X X X X X X X oO+ X X X +",
". X X X X X X X X X oO+ X X X X+",
".X X X X X X X X XXoO+ X X X X +",
". X X X X X X X XXoO+ X X X X X+",
".X X X X X X X XOoO+ X X X X X +",
". X X X X X X XOoO+ X X X X X X+",
".X X X X X X XOoO+ X X X X X X +",
". X X X X X XOoOoOoOoOooX X X X+",
".X X X X X oOoOoOoOoOoo+ X X X +",
". X X X X X X X X oOoO+ X X X X+",
".X X X X X X X X oOoO+ X X X X +",
". X X X X X X X oOoO+ X X X X X+",
".X X X X X X X oOoO+ X X X X X +",
". X X X X X X oOoO+ X X X X X X+",
".X X X X X X oOoO+ X X X X X X +",
". X X X X X oOoO+ X X X X X X X+",
".X X X X X oOoO+ X X X X X X X +",
". X X X X oOoOoOoOoOooX X X X X+",
".X X X X oOoOoOoOoOo@+ X X X X +",
". X X X X X X XOoOo+X X X X X X+",
".X X X X X X XOoOo+X X X X X X +",
". X X X X X XOoO@+X X X X X X X+",
".X X X X X XOoO+ X X X X X X X +",
". X X X X XOoO+ X X X X X X X X+",
".X X X X XOo@+ X X X X X X X X +",
". X X X XOo+X X X X X X X X X X+",
".X X X XOo+X X X X X X X X X X +",
" .X X Xo@+X X X X X X X X X X + ",
"  ++++++++++++++++++++++++++++  "};
