/* XPM */
/* $XConsortium: mminicon.pm /main/4 1996/10/29 15:56:56 drk $ */
static char * mminicon_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"65 260 20 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	c #C2C2D9D9D3D3",
"X	c #3C3C56565050",
"o	c #7676A9A99C9C",
"O	s iconGray7	m black	c #424242424242",
"+	c #51515151FBFB",
"@	c #BEBEBEBEBEBE",
"#	c #AEAEAEAEAEAE",
"$	c #FAFA13134040",
"%	s iconColor8	m black	c magenta",
"&	c #3B3BFAFA3434",
"*	s iconColor7	m white	c cyan",
"=	c #DFDFDFDFDFDF",
"-	s iconGray8	m black	c #212121212121",
";	s iconGray6	m black	c #636363636363",
":	s iconColor6	m white	c yellow",
">	c #646490908585",
",	c #959595959595",
"<	s iconColor1	m black	c black",
"1	s iconGray5	m black	c #737373737373",
/* pixels */
"                                                                 ",
"                                                                 ",
"                                                                 ",
"   ............................................................  ",
"   ...........................................................X  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooXX  ",
"   ..ooX...................................................ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooo  OooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooo  ++ OoooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooo  +++++  OoooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooo  +++++   @@OooooooooooooooX.ooXX  ",
"   ..ooX.oooooooooooooooooooo +++++   @@@@OooooooooooooooX.ooXX  ",
"   ..ooX.oooooooooooooooooooo +++   @@@@@@@OoooooooooooooX.ooXX  ",
"   ..ooX.oooooooooooooooooooo +   @@@@@@@@@OoooooooooooooX.ooXX  ",
"   ..ooX.oooooooooooooooooooo   @@@@@@@@@@@@OooooooooooooX.ooXX  ",
"   ..ooX.oooooooooooooooooo   @@@@@@@@@@@@@@OooooooooooooX.ooXX  ",
"   ..ooX.oooXXXXXXXXXXXXX   @@@@@@@@@@@@@@@@@OoooooooooooX.ooXX  ",
"   ..ooX.oooXXXXXXXXXXX   @@@@@@@@@@@@@@@@@@@OoooooooooooX.ooXX  ",
"   ..ooX.oooXXXXXXXXX   @@@@@@@@@@@@@@@@@@@@@@OooooooooooX.ooXX  ",
"   ..ooX.oooXXXX                              OooooooooooX.ooXX  ",
"   ..ooX.oooX#X $$$$$$$ %%%%%%% &&&&&&& ******@OoooooooooX.ooXX  ",
"   ..ooX.oooX# $$$$$$$ %%%%%%% &&&&&&& ********OoooooooooX.ooXX  ",
"   ..ooX.oooX#=====================================ooooooX.ooXX  ",
"   ..ooX.oooX#=###################################-ooooooX.ooXX  ",
"   ..ooX.oooX;=###################################-ooooooX.ooXX  ",
"   ..ooX.oooX;=###################################-ooooooX.ooXX  ",
"   ..ooX.oooX;=##########               ##########-ooooooX.ooXX  ",
"   ..ooX.oooX;=########## :$:$:$:$:$:$: ;#########->oooooX.ooXX  ",
"   ..ooX.oooX;=########## $:$:$:$:$:$:$ ;#########->>ooooX.ooXX  ",
"   ..ooX.oooX#=########## :$:$:$:$:$:$: ;#########->>>oooX.ooXX  ",
"   ..ooX.oooX#=########## ------------- ;#########-X>>>ooX.ooXX  ",
"   ..ooX.oooX#=########## ------------- ;#########-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=########## -;;;;;;;;;;;; ;#########-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=########## ,,,,,,,,,,,,, ;#########-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=##########               ;#########-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=###########;;;;;;;;;;;;;;;#########-XX>>ooX.ooXX  ",
"   ..ooX.oooX;=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX;=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX;=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX;=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX;=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooX#=###################################-XX>>ooX.ooXX  ",
"   ..ooX.ooo.#=###################################-XX>>ooX.ooXX  ",
"   ..ooX.oooo#=###################################-XX>>ooX.ooXX  ",
"   ..ooX.ooooo=###################################-XX>>ooX.ooXX  ",
"   ..ooX.ooooo=###################################-XX>>ooX.ooXX  ",
"   ..ooX.ooooo=###################################-XX>>ooX.ooXX  ",
"   ..ooX.ooooo=------------------------------------XX>>ooX.ooXX  ",
"   ..ooX.ooooooooo>>>XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX>>ooX.ooXX  ",
"   ..ooX.oooooooooo>>>XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX>>ooX.ooXX  ",
"   ..ooX.ooooooooooo>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>ooX.ooXX  ",
"   ..ooX.oooooooooooo>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>ooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.ooXX  ",
"   ..ooX...................................................ooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"   ...........................................................X  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..oooooooooooooooooooo  oooooo oooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooo oooooooo oo ooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooooooooooo ooooooooooooooooooooooooXX  ",
"   ..oooooooooooooooooo   oo o  o o   o      ooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo  ooo oo ooooooo ooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo oooo oo oooooo oooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo oooo oo ooooo ooooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo oooo oo oooo oooooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo oooo oo ooo ooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo oooo oo oo oooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooo ooo oooo ooo        ooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"   ............................................................  ",
"   ...........................................................X  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooXX  ",
"   ..ooX...................................................ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.oooooo<XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooooooX.ooXX  ",
"   ..ooX.oooooo<=================================O.ooooooX.ooXX  ",
"   ..ooX.oooooo<=###############################=O.ooooooX.ooXX  ",
"   ..ooX.oooooo<=#########################=        =@ooooX.ooXX  ",
"   ..ooX.oooooo<=##=====================  @@@@@% %@@   ooX.ooXX  ",
"   ..ooX.oooooo<=##=##########O=######  @@@@@@% %%O@@@@ >X.ooXX  ",
"   ..ooX.oooooo<=##=##########O=##### @@@::::@ % %O@@@@<>X.ooXX  ",
"   ..ooX.oooooo<=##=##########O=#### @@@::::$@@OOO@@@@@<>X.ooXX  ",
"   ..ooX.oooooo<O##=##======##O=### @@@@::::$@@@@@@@@@<>>X.ooXX  ",
"   ..ooX.o       O#=##=OOOOO##O=## @@@@@@:$$@@,<<<@@@<>>oX.ooXX  ",
"   ..ooX.oOOOOOO@ O=##########O=## @@$$@@@@@@@<11@@@<>>ooX.ooXX  ",
"   ..ooX.oo>>>>>@@O=##########O=## @$$$<@@  @@<==@@@1===oX.ooXX  ",
"   ..ooX.ooooooX11O=##########O=## @$$$<@ +++@@@@@@@@@@O>X.ooXX  ",
"   ..ooX.oooooo< @O=OOOOOOOOOOO=OO @@<<@@+++++@&+&+&@@@O>X.ooXX  ",
"   ..ooX.ooooooX111O@@@@@@@@@@@@@@;@@@@@@++++<@+&+&@@@O<>X.ooXX  ",
"   ..ooX.oooooo @@@O,,,,,,,,,,,,,,,;-@@@@@+++<@&+&O@@,<>>X.ooXX  ",
"   ..ooX.ooo============,,,,,,,,,,,,--<@@@@@@@@++O@@-<>>oX.ooXX  ",
"   ..ooX.oo=@@@@@@@@@@@@,,,,,,,,,,,,,,<<<#@@@@@@@@1->>>ooX.ooXX  ",
"   ..ooX.o=@===,===,===,#O,,,,,,,,,,,,,,<<<<<<<<<<<>>ooooX.ooXX  ",
"   ..ooX.o=@=##;=##;=##;#O;,,,,            111111Oo>oooooX.ooXX  ",
"   ..ooX.o=@=##;=##;=##;#O;1,,,  <<<  <<<  <,,,,,O.ooooooX.ooXX  ",
"   ..ooX.o=@=##;=##;=##;#O;1,,, <111  <111 <1,,,,O.ooooooX.ooXX  ",
"   ..ooX.o=@=##;=##;=##;#O;1,,, <11,  <,,, <1,,,,O.ooooooX.ooXX  ",
"   ..ooX.o=@111#111#111@#O;1,,,<<1,,  <,,,<<1,,,,O.ooooooX.ooXX  ",
"   ..ooX.o=@@@@@@@@@@@@@#O;1,,,,11,,  <,,,,11,,,,O.ooooooX.ooXX  ",
"   ..ooX.o=@=@=@=@=@=@=@#O;1,,,,,,,,  <,        .O.ooooooX.ooXX  ",
"   ..ooX.o==============#O-OOOOOOOOO  <O <<  << <O.ooooooX.ooXX  ",
"   ..ooX.o==============#OXo........  <. <.  <. <..ooooooX.ooXX  ",
"   ..ooX.o=@=@=@=@=@=@=@#OX>oooooooo  <><<>  <><<>oooooooX.ooXX  ",
"   ..ooX.o=@@@@@@@@@@@@@#OX>oooooooo  <>o>>  <>o>>oooooooX.ooXX  ",
"   ..ooX.o=#@#@#@#@#@#@#,OX>oooooooo  <>ooo  <>o     ooooX.ooXX  ",
"   ..ooX.o=#############,OX>oooooooo  <>ooo  <>o < < <oooX.ooXX  ",
"   ..ooX.o=,#,#,#,#,#,#,1OX>oooooooo  <>ooo  <>o<< <<<>ooX.ooXX  ",
"   ..ooX.o=,,,,,,,,,,,,,,OX>oooooo      <oo  <>ooo <>>>ooX.ooXX  ",
"   ..ooX.o=,,,,,,,,,,,,1,OX>oooooo<<<<<<<>    <ooo <>ooooX.ooXX  ",
"   ..ooX.o=1,1,1,1,1,1,1,OX>ooooooo>>>>>>><<<<<>o   <ooooX.ooXX  ",
"   ..ooX.o=11111111111111OX>ooooooooooooooo>>>>>oo<<<>oooX.ooXX  ",
"   ..ooX.ooo111111111111-XX>ooooooooooooooooooooooo>>>oooX.ooXX  ",
"   ..ooX.ooooOOOOOOOOOOOXX>>oooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.oooooXXXXXXXXXXX>>ooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.oooooo>>>>>>>>>>>>ooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.ooXX  ",
"   ..ooX...................................................ooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"   ...........................................................X  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooo oooooo ooooooooooooooooooooooooooooo oooooooooooXX  ",
"   ..ooooooo oooooo ooooooooooooooooooooooooooooo oooooooooooXX  ",
"   ..ooooooo oooooo ooooooooooooooooooooooooooooo oooooooooooXX  ",
"   ..ooooooo oooooo oo o  oo  oooo   o ooo    ooo o   oo ooooXX  ",
"   ..ooooooo oooooo oo  oo  oo oo  oo  oo  oo  oo  oo  o ooooXX  ",
"   ..ooooooo oooooo oo ooo ooo oo oooo oo oooo oo oooo o ooooXX  ",
"   ..ooooooo oooooo oo ooo ooo oo oooo oo      oo oooo o ooooXX  ",
"   ..ooooooo oooooo oo ooo ooo oo oooo oo ooooooo oooo o ooooXX  ",
"   ..ooooooo oooooo oo ooo ooo oo oooo oo ooooooo oooo o ooooXX  ",
"   ..oooooooo oooo ooo ooo ooo oo  oo  oo  oo  oo  oo  o ooooXX  ",
"   ..ooooooooo    oooo ooo ooo ooo   o ooo    ooo o   oooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooo ooooooooooooooooooooooXX  ",
"   ..oooooooooooooooooooooooooooo  oo  ooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooo    oooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"   ............................................................  ",
"   ...........................................................X  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooXX  ",
"   ..ooX...................................................ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.oooooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoooooooooooooX.ooXX  ",
"   ..ooX.oooooX                            .oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ===#=#=;====#===;#========-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==-;=-;;=--=;#-;;#;=======-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==#==#==#=====##==========-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==;---==;==-==-#;-==;--===-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==========================-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==;#;#====-=-=1===========-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==-##;#-=-#1#-1===========-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ============O-11#=========-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX =============O<<<##=======-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX =============O<<<###======-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX =============O#<=::@#=====-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX =============O;##=::@#====-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==============;;#==::@#===-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==============OO;#==::@#==-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==============#OO;#==::@#=-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==============##O;;#==::@#-.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ==============@##OO;#==::@#.oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ===============@##OO;#==::@#oooooooooooooX.ooXX  ",
"   ..ooX.oooooX ================@##OO;#==::@#ooooooooooooX.ooXX  ",
"   ..ooX.oooooX =================@##OO;#==::@#oooooooooooX.ooXX  ",
"   ..ooX.oooooX ==================@##OO;#==::@#ooooooooooX.ooXX  ",
"   ..ooX.oooooX ===================@##O;;#==::@#oooooooooX.ooXX  ",
"   ..ooX.oooooX ====================@##OO;#==::@#ooooooooX.ooXX  ",
"   ..ooX.oooooX =====================@##OO;#==,,#@oooooooX.ooXX  ",
"   ..ooX.oooooX ======================@##O;;#,==OO,ooooooX.ooXX  ",
"   ..ooX.oooooX =======================@#-O;;#=O=OO@oooooX.ooXX  ",
"   ..ooX.oooooX ========================@-oOOO;;O==%OooooX.ooXX  ",
"   ..ooX.oooooX =========================-o>>OO;,=%,OooooX.ooXX  ",
"   ..ooX.oooooX --------------------------o>>OOO,%,%OooooX.ooXX  ",
"   ..ooX.oooooX............................>>>OO;,%OOOoooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooo>>>XOOOOX>>ooX.ooXX  ",
"   ..ooX.oooooooooooooooooooooooooooooooooooo>>>OOOO>>>ooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooo>>>>>>>>>ooX.ooXX  ",
"   ..ooX.oooooooooooooooooooooooooooooooooooooo>>>>>>>oooX.ooXX  ",
"   ..ooX.oooooooooooooooooooooooooooooooooooooooo>o>oooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.ooooooooooooooooooooooooooooooooooooooooooooooooX.ooXX  ",
"   ..ooX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.ooXX  ",
"   ..ooX...................................................ooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"   ...........................................................X  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooo oo oooooo oo  ooooo oo      ooo       oo  ooooXX  ",
"   ..oooooooo ooo oooooo oo o oooo oo oooo  oo oooooooo oooooXX  ",
"   ..oooooooo ooo oooooo oo o oooo oo ooooo oo oooooooo oooooXX  ",
"   ..ooooooo oooo oooooo oo oo ooo oo ooooo oo oooooooo oooooXX  ",
"   ..ooooooo oooo oooooo oo oo ooo oo oooo ooo oooooooo oooooXX  ",
"   ..ooooooo oooo oooooo oo ooo oo oo     oooo      ooo oooooXX  ",
"   ..ooooooo oooo oooooo oo ooo oo oo oooo ooo oooooooo oooooXX  ",
"   ..ooooooo oooo oooooo oo oooo o oo ooooo oo oooooooo oooooXX  ",
"   ..ooooooo oooo oooooo oo oooo o oo ooooo oo oooooooo oooooXX  ",
"   ..ooooooo ooooo oooo ooo ooooo  oo oooo  oo oooooooo oooooXX  ",
"   ..ooooooo oooooo    oooo ooooo  oo      ooo       oo oooooXX  ",
"   ..oooooooo oooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..oooooooo oooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooo ooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..ooooooooooooooooooooooooooooooooooooooooooooooooooooooooXX  ",
"   ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 ",
"                                                                 "};
