/* XPM */
/* $XConsortium: DtCMa.pm /main/3 1995/07/18 16:18:32 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * DtCMa_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"98 98 11 1 0 0",
/* colors */
"     s background    m black c #949494949494",
".    s iconGray3     m white c #adadadadadad",
"X    s iconGray1     m white c #dededededede",
"o	s iconColor2	m white	c white",
"O    s iconGray2     m white c #bdbdbdbdbdbd",
"+    s iconGray8     m black c #212121212121",
"@    s iconGray4     m white c #949494949494",
"#    s iconGray5     m black c #737373737373",
"$	s iconColor1	m black	c black",
"%	s iconColor5	m black	c blue",
"&    s iconGray6     m black c #636363636363",
/* pixels */
"                                                                                                  ",
"             ..                                                 ..                                ",
"            .XX.                                               .XX.                               ",
"            .XX.                                               .oo.                               ",
"            .oo.                                               .oo.                               ",
"     XXXXXXX.oo..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.oo.OOOOO++                        ",
"     XX.X.X..oo...X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.oo..O.O.++                        ",
"     X.......oo.................................................oo@.....++                        ",
"     XX..XXX.oo@XXO@@##XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.oo@XXXX.++                        ",
"     X...XOO.XX@OOO@#@OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO.XX@OOO@.++                        ",
"     XX..XOO.XX@OO@#@OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO.XX@OO@.@++                        ",
"     X...XOO+OO+O@#@OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO+OO+O@#@.++                        ",
"     XX..XO++OO++#@OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO++OO++#@@@++                        ",
"     X...XO$$@@$$@OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO$$@@$$@O@@++                        ",
"     XX..XOO$++$OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO$++$OOO@@++                        ",
"     X...XOOO+$OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO$$OOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@@++                        ",
"     X...XOOOO%%%%%.%%.%%%%%%%%%%%%%%%.%%%%%%..%%%.%%%.%%%%%%%%%%OOOOO@@++                        ",
"     XX..XOOOO%%.%%%%%%%%.%.%.%.%%.%%.%.%%.%%.%%.%%%.%.%.%.%.%%.%OOOOO@@++                        ",
"     X...XOOOO%..%%.%%.%%%%.%.%%%%..%%%%%%.%%%%%.%%.%%%%.%%%%.%%%OOOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@@++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOO####################################OOOOOO@@++                        ",
"     X...XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOOOOOOOOOOOOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO##################################################OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO##################################################OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO##################################################OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO##################################################OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO@@++                        ",
"     XX..XOOOO##################################################OOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     XX..XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     X...XOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOO#OOOOOOOOOOOOO@@++                        ",
"     XX..XOOOO###########################################OOOOOOOOOOOOO@@++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@@++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@@++                        ",
"     X...XOOOO%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%oooooooXoXXX++                        ",
"     XX..XOOOO%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%ooooooXoXXX.++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoooooXoXXX..++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOooooXoXOO..&++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoooXoXOO..&#++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOooXoXOO..&##++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoXoXOO..&##.++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXoXOO..&##.O++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoXOO..&##.OO++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXXO..&##.OOO++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXX..&##.OOOO++                        ",
"     XX..XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX..&##.OOOOO++                        ",
"     X...XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..&##.OOOOOO++                        ",
"     XX..@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@$$++                        ",
"     X...@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@$$++                        ",
"     XX....#########################################################$$$$++                        ",
"     X.....#########################################################$$$$++                        ",
"     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++                        ",
"     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++                        ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  ",
"                                                                                                  "};
