/* XPM */
/* $XConsortium: Dthelp.m.pm /main/3 1995/07/18 16:38:42 drk $ */
static char * Dthelp_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray3     m white c #adadadadadad",
"X    s bottomShadowColor m black c #636363636363",
"o    s iconGray8     m black c #212121212121",
"O    s iconGray5     m black c #737373737373",
"+    s iconGray4     m white c #949494949494",
"@    s iconGray6     m black c #636363636363",
"#    s iconGray2     m white c #bdbdbdbdbdbd",
"$	s iconColor8	m black	c magenta",
"%	s iconColor3	m black	c red",
"&	s iconColor5	m black	c blue",
"*    s iconGray7     m black c #424242424242",
"=	s iconColor2	m white	c white",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"                                ",
"        ....X          ....o    ",
"        .O+@o++++@o    +++@o    ",
"    ##.o$+O%o+OOO@o&*@o++O*o    ",
"    #.Oo+O+@o+OOO@o*O&o+@OOo    ",
"    #+Oo+OO%o+OOO@o**@o+@OOo    ",
"    #.Oo+O+@o+OOO@o*O&o++OOo    ",
"    #+Oo$+O%@=====o**@o+*OOo    ",
"    #.Oo+O+@=======&O&o+++Oo    ",
"    #.Oo$+O%==OOO==**@o+*OOo    ",
"    #+Oo+O+@==OOO==&O&oOOOOo    ",
"    #.Oo$+O%o+OO===**@oO@OOo    ",
"    #+Oo+O+@o+O===o&O&oO+OOo    ",
"    #+Oo$+O%o+===@o**@oO@OOo    ",
"    #+Oo+O+@o+==O@o&O&oOOOOo    ",
"    #.Oo$+O%o+OOO@o**@oO++Oo    ",
"    #.Oo+O+@o+==O@o&O&oO+OOo    ",
"    #.Oo$+O%o+==O@o**@oO+OOo    ",
"    #.Oo+O+@o+@O*@o&O&oO*OOo    ",
"    #.Oo$+O%o+O**@o**@oO+OOo    ",
"    #.Oo+O+@o+OOO@o&O&oO+OOo    ",
"    #.Oo$+O%o+OOO@o**@oO+OOo    ",
"    .ooooooooooooooooooooooo    ",
"                                ",
"                                ",
"                                ",
"                                ",
"                                "};
