/* XPM */
/* $XConsortium: Dtuil.m.pm /main/3 1995/07/18 16:53:15 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Novell, Inc.
**********************************************************************/
static char * Dtuil_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
"       s iconColor2    m white c white",
".      s none  m none  c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o      s iconColor1    m black c black",
"O    s iconGray7     m black c #424242424242",
"+    s iconGray1     m white c #dededededede",
"@      s iconColor5    m black c blue",
"#    s iconGray8     m black c #212121212121",
"$    s iconGray3     m white c #adadadadadad",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXooXOXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXOooXXXXXXOXOOoXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoooOXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXOooooXoXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXOOXoXXXXXoXoXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXoooOXXXXXXOXOoXXXoXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXOooXXXXXXOOOXoXXXXXXXo.......",
" XXXXXXXXXXX++++++++++++++++++++",
" XXXXXXXXXXX+@O@O@O@O@O@O@o@O@O#",
" XXXXXXXXXXX+o@ @o@ @o o@ @o@o@#",
" XXOOOXXXXXX+@o o@O o@ @o o@o@O#",
" XXXXXXXXXXX+o@ @o@ @o o@ @o@O@#",
" XXOOOOXXXXX+@o o@o o@ @o o@o@O#",
" XXXXXXXXXXX+o@ @o@ @o o@ @o@o@#",
" XXOOXOXOXXX+@o o@O o@ @o o@o@o#",
" XXXXXXXXXXX+o@     @o o@     @#",
" XXXXXXXXXXX+@O@O@O@O@O@O@O@o@o#",
" XXXXXXXXXXX+oooooooooooo#######",
" XXXXXXXXXXXX$$$$$$$$$$$$.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
