/* XPM */
static char * SDturlweb_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O	s iconGray6	m black	c #636363636363",
"+	s iconGray8	m black	c #212121212121",
"@	s iconGray7	m black	c #424242424242",
"#	s iconColor5	m black	c blue",
"$	s iconGray5	m black	c #737373737373",
"%	s iconGray3	m white	c #adadadadadad",
"&	s iconGray4	m white	c #949494949494",
"*	s iconColor4	m white	c green",
"=	s iconGray1	m white	c #dededededede",
/* pixels */
"       .........................",
"       .XXXXXXXXXXXXXXXXXXXXXXXo",
"       .XXXXXXXXXXXXXXXXXXXXXXXo",
"       .XO+OXX+O+OXX+O+OXX+OXXXo",
"       .XX+X+O+X+X+O+X+X+O+XXXXo",
"       .XX++++OX++++OX++++OXXXXo",
"       .XX+O+OXX+O+OXX+O+OXXXXXo",
"       .XX+X+XXX+X+XXX+X+XXXXXXo",
"       .XXXXXXXXXXXXXXXXXXXXXXXo",
"       .XXXXXXXXXXXXXXXXXXXXXXXo",
"       .XX@X#$###$###XXXXXXXXXXo",
"       .XX#@%&&%XX&&XXXXXXXXXXXo",
"       .XX@#@X$$+$$+$+++$XXXXXXo",
"       .XX#@#@XXXXXXXXXXXXXXXXXo",
"    @#@#@#@#@#@XXXXXXXXXXXXXXXXo",
"  #@#@#@#@#@#@#X$##XXXXXXXXXXXXo",
" #@#@#@#XX@#@#%&&%XXXXXXXXXXXXXo",
" @#@#@#.XX#@#X@+&&XXXXXXXXXXXXXo",
"@#@#@#@.XX@#%&&%XXXXXXXXXXXXXXXo",
"#@#@#@ .XX#XXXXXXXXXX#####*XXXXo",
"@#@#@# .XXXXXXXXXX##*X*X*X****Xo",
"#@#@#@ .XXXXXXXXX#X*X*X*X*X*X*%o",
" #@#@# .XXXXXXXX*X*X*X*X*##X#%*o",
"  #@#@ .XXXXXXX*X*X*=*X*X*X#%*#o",
"   #@# .XXXXXX#X*X*=*=*X*X*%*%#o",
"    #@ .XXXXX##*X*=*=*X*X*%*%*&o",
"     # .XXXXX##X*X*=*X*X*%*#*&*o",
"       .XXXXX##*X*X*X*X###%*&#$o",
"       .XXXX####*X*X*X#########o",
"       .XXXX##*#X*X*X####*#####o",
"       .XXXX######*X######*$###o",
"       .oooooooooooooooooooooooo"};
