/* XPM */
/* $XConsortium: flood.pm /main/5 1996/07/23 13:56:02 drk $ */
static char * IEtFlood [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 13 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o    s iconGray1     m white c #dededededede",
"O	s iconColor1	m black	c black",
"+	s iconColor2	m white	c white",
"@    s iconGray7     m black c #424242424242",
"#    s iconGray8     m black c #212121212121",
"$    s iconGray5     m black c #737373737373",
"%	s iconColor4	m black	c green",
"&	s iconColor3	m black	c red",
"*	s iconColor6	m white	c yellow",
"=	s iconColor5	m black	c blue",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXoooooooooooooXXXXXXXXX..",
"  XXXXXXXXXooOOOOOOOOOOOOoXXXXXXXX..",
"  XXXXXXXXooOOXXXXXXXXXoOOoXXXXXXX..",
"  XXXXXXXooOOXXXXXXXXXXXoOOXXXXXXX..",
"  XXXXXXXoOOXXXXXXXXXXXXXoOXXXXXXX..",
"  XXXXXXXoOXXXXXXXXXXXXXXoOXXXXXXX..",
"  XXXXXXXoOXXXXXoooooooXXoOXXXXXXX..",
"  XXXXXXXoOXXX+++@@@@oooXoOXXXXXXX..",
"  XXXXXXXoOXX+o@@@@@@@oooOOXXXXXXX..",
"  XXXXXXXoOX+oo@@@@@@@@oooOXXXXXXX..",
"  XXXXXXXo#+$ooo@@@@@@@ooOOXXXXXXX..",
"  XXXXXXXoo$$oooo@@@@@@oooOXXXXXXX..",
"  XXXXXXXoo$$$oooo@@@@@oo$OXXXXXXX..",
"  XXXXXXoo$$$$$ooo@o@oooo$O+XXXXXX..",
"  XXXXXXoo%%%%&&&***==ooXXOO+XXXXX..",
"  XXXXXXoo%%&&&&****=oooO+O+O+XXXX..",
"  XXXXXXo%%&&&&****==oooO+O+O++XXX..",
"  XXXXXXo%%&&&****==oo$oOX++O+++XX..",
"  XXXXXXo%&&&****==oo$o$OOOOO++++X..",
"  XXXXXX%%&&****==oo@o$o$OOOoo++++..",
"  XXXXXX%%&&*+===oo@@@o$o$ooooo+++..",
"  XXXXXX%&&***=ooo@o@@@o$o$ooooo++..",
"  XXXXX%%&&**==o@@@@o@@@o$o$ooooo+..",
"  XXXXX%%&&*===o@@@@@o@@@o$o$ooooo..",
"  XXXXX%&&**===@o@@@@@o@@@o$o$oooo..",
"  XXXXX%&&*===oo@o@@@@@o@@@o$o$ooo..",
"  XXXX%%&**===ooo@o@@@@@o@@@o$o$oo..",
"  XXXX%&&**===Xooo@o@@@@@o@@@o$o$o..",
"  XXX%%&&**==XXXooo@o@@@@@o@@@o$o$..",
"  XXX%%&&**==XXXXooo@o@@@@@o@@@o$o..",
"  XXX%&&&**==XXXXXooo@o@@@@@o@@@o$..",
"  ..................................",
" ..................................."};
