/* XPM */
/* $XConsortium: Dteditqry.m.pm /main/3 1996/07/23 12:09:37 drk $ */
static char * Dteditqry_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 12 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconGray5	m black	c #737373737373",
"O	s iconColor1	m black	c black",
"+	s iconGray1	m white	c #dededededede",
"@	s iconGray6	m black	c #636363636363",
"#	s iconColor3	m black	c red",
"$	s iconColor6	m white	c yellow",
"%	s iconGray4	m white	c #949494949494",
"&	s iconColor5	m black	c blue",
"*	s iconGray3	m white	c #adadadadadad",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
" ......................         ",
" .XoXXXXXXXXXXXXXXXXXXO      +  ",
" .XoXXXXXXXXXXXXXXXXXXO@    #.+ ",
" .XoXXXXXXXXXXXXXXXXXXO@O  O##o ",
" .XoXXOOOXOXOOXOOXOXXXO@O $%O##@",
" .XoXXXXXXXXXXXXXXXXXXO@@$.$oO@ ",
" .XoXXXXX&&&&XXXXXXXXXO@$.$o$@  ",
" .XoXXXX&&&&&&XXXXXXXX@$.$o$@   ",
" .XoXXX&&&&&&&&XXXXXXX$.$o$@    ",
" .XoXXX&&&XX&&&XXXXXX$.$o$@     ",
" .XoXXX&&&XX&&&XXXXX$.$o$@      ",
" .XoXXXXXXX&&&XXXXX$.$o$@       ",
" .XoXXXXXX&&&XXXXX$.$o$@O       ",
" .XoXXXXXX&&&XXXX$.$o$@@O       ",
" .XoXXXXXXXXXXXX$.$o$@O@O       ",
" .XoXXXXXX&&&XX$.$o$@XO@O       ",
" .XoXXXXXX&&&X*+$o$@XXO@O       ",
" .XoXXXXXX&&&X@+o$@XXXO@O       ",
" .XoXXXXXXXXXX@+@@XXXXO@O       ",
" .XoXXXXXXXXX@@@@XXXXXO@O       ",
" .XoXXXXXXXX@O@XXXXXXXO@O       ",
" .XoXXXOOOOOOOOOOOXXXXO@O       ",
" .XoXXXXXXXXXXXXXXXXXXO@O       ",
" .XoXXXXXXXXXXXXXXXXXXO@O       ",
" .XoXXXXXXXXXXXXXXXXXXO@O       ",
" .OOOOOOOOOOOOOOOOOOOOO@O       ",
" .OO@@@@@@@@@@@@@@@@@@@@O       ",
"  .OOOOOOOOOOOOOOOOOOOOOO       "};
