/* XPM */
/* $XConsortium: Dtautil.m.pm /main/3 1995/07/18 16:30:20 drk $ */
static char * Dtautil [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 15 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconColor1	m black	c black",
"o	s iconColor5	m black	c blue",
"O    s iconGray4     m white c #949494949494",
"+    s iconGray5     m black c #737373737373",
"@    s iconGray1     m white c #dededededede",
"#	s iconColor6	m white	c yellow",
"$    s iconGray3     m white c #adadadadadad",
"%    s iconGray6     m black c #636363636363",
"&    s iconGray2     m white c #bdbdbdbdbdbd",
"*    s iconGray8     m black c #212121212121",
"=    s iconGray7     m black c #424242424242",
"-	s iconColor7	m white	c cyan",
";	s iconColor3	m black	c red",
/* pixels */
" .............................X ",
" .oOoOoOoOoOoOoOoOoOoOoOoOoOoOX ",
" .OoOoOoOoOoOoOoOoOoOoOoOoOoOoX ",
"......oOoOoOoOoOoOoOoOoOoO.....X",
".OOOOO.oOoOoOoOoOoOoOoOoO.OOOOOX",
".OOOOOO.oOoOoOoOoOoOoOoO.OOOOOOX",
".OOOOOOO..........+O+...OOOOOOOX",
".OOOO.@OOOOOOOOOO+#.$+OOOOOOOOOX",
".OOOOX.@OOOOOOOO+@%#.$+OOOOOOOOX",
".OOOX&X.@OOOOOO%*%O%#.$+OOOOOOOX",
".OOO%X&X.@OOOOOO+*%O%#.$+OOOOOOX",
".OOOO%X&XXOOOOOOO+*%O%#.$+OOOOOX",
".OOOOO%XO=.OOOOOOO+*%O%#.$+OOOOX",
".OOOOOOOXO=.OOOOOO%@=%$%#.$+OOOX",
".OOOOOOOOXO=.OOOO%@&=*%$%#.@+OOX",
".OOOOOOOOOXO=.OO%@&+++=%O%#XOOOX",
".OOOOOOOOOOXO=o-@&+++OO=%@X+OOOX",
".OOOOOOOOOOOXo-o%o*OOOOO*XOOOOOX",
".OOOOOOOOOO+o-$+o*=OOOOOOOOOOOOX",
".OOOOOOOOOOo-o+o*=%OOOOOOOOOOOOX",
".OOOOOOOOOo-$+o*=*%%*OOOOOOOOOOX",
".OOOOOOOOo-o+o*=*+;#@*OOOOOOOOOX",
".OOOOOOOo-$+o*+%*;#;#@*OOOOOOOOX",
".OOOOOOo-o+o*+OO*=;#;#@*OOOOOOOX",
".OOOOOo-$+o*+OOOO*=;#;#@*OOOOOOX",
".OOOOo-o+o*+OOOOOO*=;#;#@*OOOOOX",
".OOOoo$+o*+OOOOOOOO*=;#;#*%OOOOX",
".OOOoooo*+OOOOOOOOOO*=;#;*%OOOOX",
".OOO****+OOOOOOOOOOOO*=**OOOOOOX",
".OOOO=OOOOOOOOOOOOOOOO++OOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
"XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"};
