/* XPM */
/* $XConsortium: Dtbmark.m.pm /main/2 1996/07/23 12:05:22 drk $ */
static char * Dtbmark_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 10 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconGray5	m black	c #737373737373",
"O	s iconColor1	m black	c black",
"+	s iconGray6	m black	c #636363636363",
"@	s iconColor6	m white	c yellow",
"#	s iconColor3	m black	c red",
"$	s iconGray8	m black	c #212121212121",
"%	s iconGray4	m white	c #949494949494",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
" ....................           ",
" .XoXXXXXXXXXXXXXXXXO           ",
" .XoXXXXXXXXXXXXXXXXO+          ",
" .XoXXXXXXXXXXXXXXXXO+O         ",
" .XoXXXXXXXXXXXXXXXXO+O         ",
" .XoXXOOOXOOXOXXOXXXO+O         ",
" .XoXXXXXXXXXXXXXXXXO+O         ",
" .XoXXXXXXXXXXXXXXXXO.......... ",
" .XoXXOXX@@XXOXOOXXXO#####@@##$ ",
" .XoXXXXX@@XXXXXXXXXO#####@@+#$ ",
" .XoXXXXXXXXXXXXXXXXO######@+#$ ",
" .XoXXXXX@@XXXXXXXXXO######@+#$ ",
" .XoXXXX@@@XXXXXXXXXO######@+#$ ",
" .XoXXXXX@@XXXXXXXXXO######@+#$ ",
" .XoXXXXX@@XXXXXXXXXO######@+#$ ",
" .XoXXXXX@@XXXXXXXXXOOOOOOO@+O$ ",
" .XoXXXXX@@@XXXXXXXXO+O    @+   ",
" .XoXXXXXXXXXXXXXXXXO+O    @+   ",
" .XoXXXXXXXXXXXXXXXXO+O    @+   ",
" .XoXXXXOOOOXXXXXXXXO+O    @+   ",
" .XoXXXXXXXXXXXXXXXXO+O   @@+   ",
" .XoXOOOOOXOOOOOXXXXO+O  @%@@+  ",
" .XoXXXXXXXXXXXXXXXXO+O  %@%@%+ ",
" .XoXXXXXXXXXXXXXXXXO+O  @+@+@+ ",
" .XoXXXXXXXXXXXXXXXXO+O  %@%@%+ ",
" .OOOOOOOOOOOOOOOOOOO+O  @+@+@+ ",
" .OO++++++++++++++++++O  %@%@%+ ",
"  .OOOOOOOOOOOOOOOOOOOO   +@+++ "};
