/* XPM */
static char *pychess_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 58 1 ",
"  c #555956",
". c #575A58",
"X c #595D5A",
"o c #5D605D",
"O c #646764",
"+ c #6D6F6B",
"@ c #6D706B",
"# c #71736E",
"$ c #747571",
"% c #767874",
"& c #797B76",
"* c #7B7E79",
"= c #7E807B",
"- c #81837E",
"; c #848681",
": c #868884",
"> c #898B86",
", c #8C8E8A",
"< c #8F918C",
"1 c #92948F",
"2 c #949591",
"3 c #979994",
"4 c #999B96",
"5 c #9C9E99",
"6 c #9EA19C",
"7 c #A1A39F",
"8 c #A4A6A2",
"9 c #A6A8A3",
"0 c #A9ABA7",
"q c #ACAEAA",
"w c #AEB0AC",
"e c #B1B3AF",
"r c #B3B5B1",
"t c #B6B8B4",
"y c #B8BAB6",
"u c #BCBEBA",
"i c #BEC0BD",
"p c #C0C2BE",
"a c #C4C6C2",
"s c #C7C9C5",
"d c #C8CAC6",
"f c #CBCDCA",
"g c #CFD1CE",
"h c #D3D7CF",
"j c #D4D6D2",
"k c #D5D8D1",
"l c #D9DBD6",
"z c #DBDDD9",
"x c #DEE0DB",
"c c #E1E2DE",
"v c #E6E7E3",
"b c #E7E8E4",
"n c #E9EAE6",
"m c #ECEDEA",
"M c #EFF0ED",
"N c #F0F1EF",
"B c #F2F3F1",
"V c None",
/* pixels */
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVV*-7t03:;;-VVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVV-2rlnmbvcclu;%VVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVV&8scNnmckzmNg7*VVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVV*80zNmvvvccmNl2&VVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVV,vmMnvvbbMmbbbz6&VVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVV2nmnbvnbmmckkkvl-VVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVV:cnvbnmbvchhhhxv:%VV-::*VVVVVVVVVVVVVVVVVVV",
"VVVVV=pMbbbvvbchhhhcmi849fzve*VVVVVVVVVVVVVVVVVV",
"VVVVV:sMbvbvbcchhkklxvnnnvxcvq1-VVVVVVVVVVVVVVVV",
"VVVV*iMnbbvvbbxhhhhhhhkllkhkvbxy:VVVVVVVVVVVVVVV",
"VVVV=gMvvvvbbbxhhhhhhhhhhhhhklvl,VVVVVVVVVVVVVVV",
"VVVV%pMbbvvvvvchhkhhhhhhhhhklhvh>VVVVVVVVVVVVVVV",
"VVVVVwmbvvvbvvckhhhhhhhkzhhlncnh>VVVVVVVVVVVVVVV",
"VVVVV7bbvvvvvvchhhhhhhlvmvvnvkg9&VVV>,*VVVVVVVVV",
"VVVVV<vmvvvvvvxkxcvcxhkcmBhq5:==&=,6gl8*VVVVVVVV",
"VVVVV-fMvvvvvbxhcBkfvchhlvl-VV*3phzvbvvi,VVVVVVV",
"VVVVVV8Mnvvvvvckkvx78cchgzv:V=wvMMbxkhvMi-VVVVVV",
"VVVVVV3nnbvbbvxkhhvz59vcxvl-%0nmvvckhhhxc1VVVVVV",
"VVVVVV1cmvvvbbxkhhhvl2wzxl0&<zmvvnckhhhln5VVVVVV",
"VVVVVV4nnvbvvbxkhhhkvg:=;;*VqMbvvvckkhhlmj1VVVVV",
"VVVVVVqNbvvbvvxkhhhhkmu*VVVVrMbvbvckhhhhlms*VVVV",
"VVVVV-fMbvvvbbxkhhhhkxv1VVVVrNbvvvckhhkhhxl;VVVV",
"VVVV:ummvvbvvvxkhkhhhknr*VVV0mbvbbckhhhklnf*VVVV",
"VVV$qNnbvvvvvvchhhhhhhch;VVV,lMbvbxkhhjbmh3VVVVV",
"VVV$tBnbvvvvvbckhhkhhhxx:VVV:jMbvvvkhhlml1VVVVVV",
"VVVVtBMbvvvvbvchhhhhhhzv;VVV,lnnvbckhhhxc<VVVVVV",
"VVVV2anMMmnbvvchhhhxxvbc;VVV*wnMbvvkkxvma:VVVVVV",
"VVVV%-5unBmvvvchhhkxmMs4=VVVV-aNbbckhcmw>VVVVVVV",
"VVVVV#=aMmnvvvchhhhhlmh:VVVV%2vnvvckklb7%VVVVVVV",
"VVVV,9annvvvvbchhhhhhlmp9>%-8lmbbbckhhbg>VVVVVVV",
"VVV1jnMmvvvvvbchkhhhhhxnf<;rnMbvbnckhhlms:VVVVVV",
"VVVqNnbbvvvvvvxhhhhhhhkp2ixmmvvbbbclhhhlna3:VVVV",
"VVV8Nmvvvvvvvbchhhhhhhh9wMmnnvvvvvckhhhhxnny-VVV",
"VV@9Nnnbbbbbbnckkhkkkkk9tMvvvvvbbbckhhhhhkcz1VVV",
"VVV,fcnmnMNNNNNnmnmnnnby5nnnvvvvcbckhhhhhhcc<VVV",
"VVVV*2780wrrrrrrrreeq96,;sMMMnmnmmbxzzzzxcnl,VVV",
"VVVVVVVV.XXooooXXoXX. VVo;5tsgllzxxvxvcvczg5#VVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVO#&******=====*-&+VVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV",
"VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV"
};
