/* XPM */
static char *okular_m[] = {
/* columns rows colors chars-per-pixel */
"32 32 223 2 ",
"   c #1E1E1E",
".  c gray13",
"X  c #232323",
"o  c gray17",
"O  c #2D2D2D",
"+  c #2F2F2F",
"@  c gray20",
"#  c #353535",
"$  c gray23",
"%  c #3C3C3C",
"&  c #3E3E3E",
"*  c #434343",
"=  c gray27",
"-  c gray28",
";  c gray30",
":  c gray31",
">  c #505050",
",  c #515151",
"<  c #585858",
"1  c gray37",
"2  c gray38",
"3  c gray39",
"4  c #646464",
"5  c gray40",
"6  c #686868",
"7  c DimGray",
"8  c #6A6A6A",
"9  c #6C6C6C",
"0  c #6D6D6D",
"q  c #727272",
"w  c #747474",
"e  c #777777",
"r  c gray47",
"t  c gray48",
"y  c #7B7B7B",
"u  c gray49",
"i  c #7E7E7E",
"p  c #2775A7",
"a  c #2379AF",
"s  c #2F7DAE",
"d  c #2880B7",
"f  c #2883BC",
"g  c #2984BD",
"h  c #2A85BF",
"j  c #3587BA",
"k  c #3287BD",
"l  c #3C88B8",
"z  c #568DAF",
"x  c #518DB2",
"c  c #5A97BE",
"v  c #709EBA",
"b  c #2A86C0",
"n  c #2B87C1",
"m  c #2C88C2",
"M  c #2C89C3",
"N  c #2F8AC3",
"B  c #2C8AC4",
"V  c #2D8AC5",
"C  c #2D8BC5",
"Z  c #2E8BC6",
"A  c #2E8CC7",
"S  c #2E8DC8",
"D  c #2F8EC9",
"F  c #2F8ECA",
"G  c #308FCB",
"H  c #3191CD",
"J  c #3291CD",
"K  c #3191CE",
"L  c #3292CE",
"P  c #3292CF",
"I  c #3293CF",
"U  c #3394D0",
"Y  c #3394D1",
"T  c #4599CD",
"R  c #5B9AC1",
"E  c #569ECB",
"W  c #589DC8",
"Q  c #419AD2",
"!  c #659FC2",
"~  c #54A0D0",
"^  c #55A0D0",
"/  c #56A3D3",
"(  c #5AA5D4",
")  c #5BA8D8",
"_  c #68A2C7",
"`  c #71A3C3",
"'  c #73A8C9",
"]  c #71A8CB",
"[  c #75ABCC",
"{  c #79ADCD",
"}  c #64A9D4",
"|  c #69ABD4",
" . c #6CAED8",
".. c #74AFD4",
"X. c #71B0D7",
"o. c gray51",
"O. c #838383",
"+. c #8D8D8D",
"@. c #8E8E8E",
"#. c #929292",
"$. c gray59",
"%. c #9A9A9A",
"&. c #9D9D9D",
"*. c #A5A5A5",
"=. c gray65",
"-. c #A7A7A7",
";. c gray66",
":. c #AAAAAA",
">. c #AEAEAE",
",. c #AFB0B0",
"<. c #A4B1B9",
"1. c #A2B3BD",
"2. c #B1B1B1",
"3. c gray70",
"4. c #B2B4B5",
"5. c #B4B4B4",
"6. c gray71",
"7. c gray72",
"8. c #BCBCBC",
"9. c gray74",
"0. c gray",
"q. c gray75",
"w. c #80B1CF",
"e. c #90B3CA",
"r. c #81B8DA",
"t. c #89BCDB",
"y. c #94BCD5",
"u. c #90BCD8",
"i. c #A7BCCA",
"p. c #A8BECB",
"a. c #96C2DD",
"s. c #94C2DE",
"d. c #96C3DF",
"f. c #9FC6DE",
"g. c #A0C4DA",
"h. c #98C5E0",
"j. c #9BC6E0",
"k. c #A9CBE1",
"l. c #AECEE3",
"z. c #B4CFE0",
"x. c #B0D2E7",
"c. c #B3D3E7",
"v. c #B7D5E7",
"b. c #BDD5E4",
"n. c #BAD7E9",
"m. c #BBD7E9",
"M. c #C0C0C0",
"N. c #C1C1C1",
"B. c #C3C3C3",
"V. c gray77",
"C. c #C5C5C5",
"Z. c #C6C6C6",
"A. c gray78",
"S. c #C8C8C8",
"D. c gray79",
"F. c gray80",
"G. c #CDCDCD",
"H. c #CECECE",
"J. c gray81",
"K. c #C6D0D6",
"L. c #CDD4D9",
"P. c #D0D0D0",
"I. c #D2D2D2",
"U. c LightGray",
"Y. c gray83",
"T. c #D5D5D5",
"R. c gray84",
"E. c #D7D7D7",
"W. c #D7DBDD",
"Q. c #D8D8D8",
"!. c gray85",
"~. c #DADADA",
"^. c gray86",
"/. c #DBDBDC",
"(. c #DDDDDD",
"). c gray87",
"_. c #DFDFDF",
"`. c #C2D7E4",
"'. c #C8DBE8",
"]. c #CCDDE8",
"[. c #D9DDE0",
"{. c #DEE3E6",
"}. c #D0E1EB",
"|. c #D9E2E8",
" X c #D8E6EE",
".X c #DFEBF3",
"XX c gray88",
"oX c #E1E1E1",
"OX c #E2E2E2",
"+X c gray89",
"@X c #E4E4E4",
"#X c gray90",
"$X c #E6E6E6",
"%X c #E7E7E7",
"&X c #E5E7E8",
"*X c gray91",
"=X c #E9E9E9",
"-X c #EAEAEA",
";X c gray92",
":X c #ECECEC",
">X c gray93",
",X c #EEEEEE",
"<X c #EFEFEF",
"1X c #E4ECF2",
"2X c gray94",
"3X c #F1F1F1",
"4X c gray95",
"5X c #F3F3F3",
"6X c #F4F4F4",
"7X c gray96",
"8X c #F6F6F6",
"9X c gray97",
"0X c #F7F8F9",
"qX c #F8F8F8",
"wX c #F9F9F9",
"eX c #F9FAFB",
"rX c gray98",
"tX c #FBFBFB",
"yX c gray99",
"uX c #FDFDFD",
"iX c #FDFDFE",
"pX c #FEFEFE",
"aX c None",
/* pixels */
"aXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaX",
"aXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaX^.#X:X:XaXaXaXaXaXaXaXaX",
"aXaXaXaXaXaXaXaXaXaXaXaXaXaXaXw.u.:X:X;X:X:X:X:X^.aXaXaXaXaXaXaX",
"aXaXaXaXaXaXaXaXaXaXE.(.&X) Y Y b.:X:X:X<X<X5X5X%XaXaXaXaXaXaXaX",
"aXaXaXaXaXU.^.+X_._.#X#Xa.Y I  .:X<X<X5X5X5X6X6X5XaXaXaXaXaXaXaX",
"aXaXaXE.(.(.(.(._.+X#X{.Y L K '.<X5X5X5X5X8X8X9X8XaXaXaXaXaXaXaX",
"aXaXaXU.(.(.(.+XOX#X*Xg.U U / 2X5X5X8X8X9XrXrXrXrXaXaXaXaXaXaXaX",
"aXaXaXaX(.(.(.+X%X*X*X( J J f.5X8X8X8XrXrXrXrXrXrX+XaXaXaXaXaXaX",
"aXaXaXaX+X(.+X+X%X*X|.L D G  X8XqXqXyXyXyXyXyXyXiX:XaXaXaXaXaXaX",
"aXaXaXaX(.+X+X%X*X:Xk.G G T 8XqXqXqXyXyXyXyXiXiXiXrXaXaXaXaXaXaX",
"aXaXaXaXE.+X%X*X:X<Xr.G A X.rXrXyXyXyXiXyXiXiXiXiXiXaXaXaXaXaXaX",
"aXaXaXaXU.%X*X:X:X:X} A A d.rXtXyXyXyXiXiXiXiXrXyXyXaXaXaXaXaXaX",
"aXaXaXaXaX%X*X:X5X<X~ A C x.yXyXyXiXiXiXiXyXrXrXrXrXW.aXaXaXaXaX",
"aXaXaXaXaX:X*X:X<X5X~ C M n.yXiXiXiXiXyXrXrXrXrXrX1X` aXaXaXaXaX",
"aXaXaXaXaX*X:X5X5X8X| B m c.iXiXiXyXyXyXrXrXqXqX8X] R aXaXaXaXaX",
"aXaXaXaXaX(.:X5X5X8Xa.M n a.iXiXyXyXrXqX8XrX8XqXz.a l aXaXaXaXaX",
"aXaXaXaXaXR.<X5X8X9X1XM h E iXiXyXyXqXqXqX9X9X].s p c aXaXaXaXaX",
"aXaXaXaXaXaX<X5X8XqXrXt.h g m.iXyXqXqXqX:X^.p.z x e.^.7.aXaXaXaX",
"aXaXaXaXaXaX5X5X9XrXyXrX..g k l.qXqX6XE.K.g._ ' `.6X*XH.&.2.aXaX",
"aXaXaXaXaXaX;X8X9XrXyXyXiXv.W d j ! v [ { y.i.5.T.U._.R.aXaXaXaX",
"aXaXaXaXaXaX%X8XrXrX9XiXiXiXqXW.1.<.}.L.,.O.u =.+X%X%X^.r aXaXaX",
"aXaXaXaXaXaXB._.(._.*X;X(.A.T.:XT.#.+.u w q t u o.#.%.>.y aXaXaX",
"aXaXaXaXaXaX+XtXtXyXiX<XC.$.t ; # 9 w *.5.7.5.;.+.2 * = $ , 3 aX",
"aXaXaXaXaXaXaXE.7.#.9 : @ < u N.:X%XM.S.H.F.S.N.5.5.N.H.r   . aX",
"aXaXaXaX+X^.7.o.+.5 : 6 &.A.#X%X*X:X%XH.N.q.7.N.E.+X:X5XA.aXaXaX",
"aXq.:.U.+XaXaX:.5 0 q.(.E.F.:XqXrX8X8X5X:X:X:X:X5X:X<X5XU.aXaXaX",
"aXaXaXaXaXaXt 1 &.E.T.F.S.+X8XqXrX8X8X8X8X5X5X:X<X5X<X:XN.aXaXaX",
"aXaXaXaXaX% + 6 F.q.q.U.:XrXrXrXrX8X8X8X5X5X5X5X;XH.aXaXaXaXaXaX",
"aXaXaXaX= % aXaXA.(.:XrXiXiXrXrX8X8X8X8X5X%X^.aXaXaXaXaXaXaXaXaX",
"aXaXaX+ X aXaXaX:XrXiXiXiXiXiX8X*X(.aXaXaXaXaXaXaXaXaXaXaXaXaXaX",
"aXaX+ . aXaXaXaX*XyXqX:X_.aXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaX",
"aXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaX"
};
