/* XPM */
/* $XConsortium: Dtaexex.m.pm /main/2 1996/07/23 12:00:51 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Dtaexe [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s iconGray2	m white	c #c8c8c8c8c8c8",
".	s iconColor3	m black	c red",
"X	s iconGray5	m black	c #7d7d7d7d7d7d",
"o	s iconGray4	m white	c #969696969696",
"O	s iconColor1	m black	c black",
"+	s iconGray3	m white	c #afafafafafaf",
"@	s iconGray7	m black	c #4b4b4b4b4b4b",
"#	s iconGray6	m black	c #646464646464",
/* pixels */
"                                ",
" .X.o.o.o.o.o.o. . . . . . .o.XO",
" o.o. . . .o. . .o.o.o. . . .o.O",
" . . . . . .o. . . .o.o. . . . O",
"  . . . . . . . . . .X.X. . . .O",
" . . . . . . . . . .o.X.o. . . O",
"  . . . . . . . . .o.o.o.o.o. .O",
" .oOOOOOOOOOOXo. . . . . . . . O",
" OOOOOOOOOOOOOOOO . . . . . . .O",
" OOOOOOOOOOOOOOOOOO. . . . . . O",
" OOOX.....XOOOOOOOOOO . . . . .O",
" . . . . .o+XXOOOOOOOOO. . . . O",
"  . oooooooooooo@@OOOO.OOooooooO",
" oooOoOoOoOoOoOoOX@OOOO.oOOOOooO",
" O.O.O.OOOOOOOOOOOOX@OOO.oOOOOOO",
" .O.OOOOOOOOOOOOOOOOO@OOO..OOOOO",
" O.OOOO.OOOOOOOOOOOOOO@OOOOoOOOO",
" .OOO.OOOOOOOOOOOOOOOOOOOOO.XOOO",
" OO.OOOOOO.....OOOOOOOOOOOOOoXOO",
" O.OOOOO..OOOOO..OOOOOOO..OOOoOO",
" .OOOOO.OO.OO.OOO.OOOOO.OOOOO.XO",
" OOOOO.OOOO.OOOOO.OOOO.OO.OOOOoO",
" OOOOO.O.OO.OOOOOO.OO.OOO.OOOO.O",
" OOOO.OOOOO.OOOO.OOOOOOOOO.OOOOO",
" OOOO.O.OOO.O.OOOO.O.O.OOO.OOOOO",
" OOOO.OOOO.OOOOOOOOOOOOOOOO.OOOO",
" ..OO.OOOO.OOOOOOO.O.OOOOOO.OOOO",
" O..O.O.OOOOOOOO.OOOOO.OOOOOOOOO",
" OOOOO.OO.O...OOOO.O.OOOOOOOOOOO",
" OOOOOOOOOOOOOOOO.OOOO.OOOOOO.OO",
" OOOOOOOOOOOOOOOOOOOO.O.#.#.#.OO",
" OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"};
