/* XPM */
/* $XConsortium: DtCMmth.m.pm /main/2 1996/07/23 11:55:31 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * month-view_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray5     m black c #737373737373",
"X    s iconGray3     m white c #adadadadadad",
"o    s iconGray1     m white c #dededededede",
"O    s iconGray4     m white c #949494949494",
"+	s iconColor2	m white	c white",
"@    s iconGray2     m white c #bdbdbdbdbdbd",
"#	s iconColor5	m black	c blue",
"$	s iconColor8	m black	c magenta",
/* pixels */
"    .                    .      ",
"   XoO                  XoO     ",
"+++XoO++++++++++++++++++XoO+++  ",
"++oX@OoOo+o+o+ooooooooooX@OoOO. ",
"+o+X@.Oo+o+o+o+oooooooooX@.OoO. ",
"++o+.+o+##############ooo.oooO. ",
"+o+o+o+o+o+o+ooooooooooooooooO. ",
"++o+o+o+o+oooooooooooooooooooO. ",
"+o+o+o+o+o+ooo$$$oo$$$oo$$$ooO. ",
"++o+o+o+oooooo@+@oo@+@oo@+@ooO. ",
"+o+o+o+o+ooooo$$$oo$$$oo$$$ooO. ",
"++o+o+oooooooooooooooooooooooO. ",
"+o+o+o+ooooooooooooooooooooooO. ",
"++o+$$$oo$$$oo$$$oo$$$oo$$$ooO. ",
"+o+o@+@oo@+@oo@+@oo@+@oo@+@ooO. ",
"++oo$$$oo$$$oo$$$oo$$$oo$$$ooO. ",
"+o+ooooooooooooooooooooooooooO. ",
"+ooooooooooooooooooooooooooooO. ",
"+ooo$$$oo$$$oo$$$oo$$$oo$$$ooO. ",
"+ooo@+@oo@+@oo@+@oo@+@oo@+@o@O. ",
"+ooo$$$oo$$$oo$$$oo$$$oo$$$@oO. ",
"+ooooooooooooooooooooooooo@o@O. ",
"+oooooooooooooooooooooooo@o@oO. ",
"+ooo$$$oo$$$oo$$$oo$$$oo$$$oXO. ",
"+ooo@+@oo@+@oo@+@oo@+@o@@+@X@O. ",
"+ooo$$$oo$$$oo$$$oo$$$@o$$$@XO. ",
"+oooooooooooooooooooo@o@oX@XOO. ",
"+ooooooooooooooooooo@o@oX+++@.. ",
"+ooo$$$oo$$$oo$$$oo@o@oX@++@.X. ",
"+ooo@+@oo@+@oo@+@o@o@oX@X+@.X@. ",
"+ooo$$$oo$$$oo$$$@o@oX@XO@.X@@. ",
"+OOOOOOOOOOOOOOOOOOOOOOOO.X@@@  "};
