/* XPM */
/* $XConsortium: Dtinfoaddi.m.pm /main/2 1996/07/23 12:15:22 drk $ */
static char * Dtinfoaddi_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 12 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray2	m white	c #bdbdbdbdbdbd",
"X	s bottomShadowColor	m black	c #636363636363",
"o	s iconGray6	m black	c #636363636363",
"O	s iconGray5	m black	c #737373737373",
"+	s iconGray4	m white	c #949494949494",
"@	s iconGray3	m white	c #adadadadadad",
"#	s iconColor8	m black	c magenta",
"$	s iconColor3	m black	c red",
"%	s iconGray7	m black	c #424242424242",
"&	s iconColor5	m black	c blue",
"*	s iconGray8	m black	c #212121212121",
/* pixels */
"                                ",
"                                ",
"                                ",
"        ....X .....o   ....o    ",
"        .O+oo+OOOOOo...O++oo    ",
"   @@@@o#+O$o+Oo%OoO%ooO+O%o    ",
"   @@@Oo+O+oo+OOO%o%O&o+oOOo    ",
"   @@@Oo#+O$o+OoOOoO%ooO+O%o    ",
"   @@@Oo+O+oo+OOO%o%O&o+oOOo    ",
"   @@+Oo+OO$o+....OO%oo+oOOo    ",
"   @@@Oo+O+oo+.O.Oo%O&o++OOo    ",
"   @@+Oo#+O$o+..O.oO%oo+%OOo    ",
"   @@@Oo+O+o*+.O.Oo&O&o+++Oo    ",
"   @@@Oo#+O$%+..O.o%%oo+%OOo    ",
"   @@+Oo+......O.O.....OOOOo    ",
"   @@@Oo#.O.O.O.O.O.O.OooOOo    ",
"   @@+Oo+..O.O.O.O.O.O.o+OOo    ",
"   @@+Oo#.O.O.O.O.O.O.OooOOo    ",
"   @@+Oo+ooooo.O.OooooooOOOo    ",
"   @@@Oo#+O$o+O.O.o%%ooO++Oo    ",
"   @@@Oo+O+oo+.O.OoXO&oO+OOo    ",
"   @@@Oo#+O$o+O.O.oX%ooO+OOo    ",
"   @@@Oo+O+oo+.O.Oo&O&oO%OOo    ",
"   @@@Oo#+O$o+ooooo%%ooO+OOo    ",
"   @@@Oo+O+oo+OOOoo&O&oO+OOo    ",
"   @@@Oo#+O$o+OOOoo%%ooO+OOo    ",
"   @@@Oo+O+oo+OOOoo&O&oO+OOo    ",
"   @@@Oo#+O$o+OOOoo%%ooO+OOo    ",
"   ooooooooooooooooooooooooo    ",
"                                ",
"                                ",
"                                "};
