/* XPM */
/* $XConsortium: erase.pm /main/2 1996/07/23 12:37:01 drk $ */
static char * IEtErase [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 8 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X	s iconColor6	m white	c yellow",
"o	s iconColor2	m white	c white",
"O    s iconGray3     m white c #adadadadadad",
"+    s iconGray5     m black c #737373737373",
"@    s iconGray1     m white c #dededededede",
"#	s iconColor3	m black	c red",
/* pixels */
"                                    ",
"                                   .",
"  XoXoXOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  +XoXoXOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  X+XoXoXOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  +X+XoXoXOOOOOOOOOOOOOOOOOOOOOOOO..",
"  X+X+XoXoXOOOOOOOOOOOOOOOOOOOOOOO..",
"  +X+X+XoXoXOOOOOOOOOOOOOOOOOOOOOO..",
"  O+X+X+XoXoXOOOOOOOOOOOOOOOOOOOOO..",
"  OO+X+X+XoXoXOOOOOOOOOOOOOOOOOOOO..",
"  OOO+X+X+XoXoXOOOOOOOOOOOOOOOOOOO..",
"  OOOO+X+X+XoXoXOOOOOOOOOOOOOOOOOO..",
"  OOOOO+X+X+XoXoXOOOOOOOOOOOOOOOOO..",
"  OOOOOO+X+X+Xooo@OOOOOOOOOOOOOOOO..",
"  OOOOOOO+X+X+Oooo@OOOOOOOOOOOOOOO..",
"  OOOOOOOO+X++OOooo@OOOOOOOOOOOOOO..",
"  OOOOOOOOO+.++OOooo@OOOOOOOOOOOOO..",
"  OOOOOOOOOO..++OOoo++OOOOOOOOOOOO..",
"  OOOOOOOOOOO..++OO+#o#OOOOOOOOOOO..",
"  OOOOOOOOOOOO..+++#o#@#OOOOOOOOOO..",
"  OOOOOOOOOOOOO.++#O#@#@#OOOOOOOOO..",
"  OOOOOOOOOOOOOO+#+#+#@#@#OOOOOOOO..",
"  OOOOOOOOOOOOOOO+#+#+#@#@#ooooooo..",
"  OOOOOOOOOOOOOOOO+#+#+#@#oooooooo..",
"  OOOOOOOOOOOOOOOOO+#+#+#ooooooooo..",
"  OOOOOOOOOOOOOOOOOO+#+#oooooooooo..",
"  OOOOOOOOOOOOOOOOOOO+#ooooooooooo..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..",
"  ..................................",
" ..................................."};
