/* XPM */
/* $XConsortium: Dtcalc.l.pm /main/3 1995/07/18 16:32:35 drk $ */
static char * Dtcalc_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s iconGray3     m white c #adadadadadad",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray5     m black c #737373737373",
"O    s iconGray7     m black c #424242424242",
"+    s iconGray8     m black c #212121212121",
"@    s bottomShadowColor m black c #636363636363",
"#    s iconGray6     m black c #636363636363",
"$    s selectColor m white c #737373737373",
"%	s iconColor6	m white	c yellow",
"&	s iconColor3	m black	c red",
"*	s iconColor4	m white	c green",
/* pixels */
"         ..........................             ",
"        ..XXXXXXXXXXXXXXXXXXXXXXXXX.            ",
"       ..Xoooooooooooooooooooooooooo            ",
"       .XooOOOOOOOOOOOOOOOOOOOOOOOoo+@          ",
"       .XooOoo#ooo##oo##ooo##oo#o.oo+@@         ",
"       .XooO#oo#oo#oo#oo#OO#oo#oo.oo+@@         ",
"       .XooOo##o##O##oOOo##o##O##.oo+@@$        ",
"       .XooOo##o##O##oOOo##o##O##.oo+@@$        ",
"       .XooO#oo#oo#oo#oo#OO#oo##o.oo+@@$        ",
"       .XooO.....................ooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xoo...oo...oo...oo..ooo..ooo+@@$        ",
"       .Xoo.ooOo.ooOo.ooOo.oOo.ooOoo+@@$        ",
"       .Xoo.ooOo.ooOo.ooOo.oOo.ooOoo+@@$        ",
"       .XoooOOooooOoooOOoooOoooooOoo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .XooXXXooXXXooXXXoo..oo%%.ooo+@@$        ",
"       .XooXooOoXooOoXooOo.oOo%ooOoo+@@$        ",
"       .XooXooOoXooOoXooOo.oOo.ooOoo+@@$        ",
"       .XoooOOOoooOOooOOOooOoooOOooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .XooXXXooXXXooXXXoo..oo&&.ooo+@@$        ",
"       .XooXooOoXooOoXooOo.oOo&ooOoo+@@$        ",
"       .XooXooOoXooOoXooOo.oOo.ooOoo+@@$        ",
"       .XoooOOOoooOOooOOOooOoooOOooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .XooXXXooXXXooXXXoo..oo**.ooo+@@$        ",
"       .XooXooOoXooOoXooOo.oOo*ooOoo+@@$        ",
"       .XooXooOoXooOoXooOo.oOo.ooOoo+@@$        ",
"       .XoooOOOoooOOooOOOooOoooOOooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .Xooooooooooooooooooooooooooo+@@$        ",
"       .XooXXXooXXXooXXXoo.......ooo+@@$        ",
"       .XooXooOoXooOoXooOo.ooooooOoo+@@$        ",
"       .XooXooOoXooOoXooOo.ooooooOoo+@@$        ",
"       .XoooOOOoooOOooOOOooOOOOOOooo+@@$        ",
"        Xoooooooooooooooooooooooooo++@@$        ",
"         ooooooooooooooooooooooooo+++@@$        ",
"          +++++++++++++++++++++++++++@@$        ",
"           @@@@@@@@@@@@@@@@@@@@@@@@@@@@$        ",
"            @@@@@@@@@@@@@@@@@@@@@@@@@@$$        ",
"             $$$$$$$$$$$$$$$$$$$$$$$$$$         "};
