/* XPM */
static char *rhythmbox_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 234 2 ",
"   c #342F13",
".  c #2E3436",
"X  c #363A36",
"o  c #363B3C",
"O  c #393D3C",
"+  c #433E29",
"@  c #3F423B",
"#  c #605004",
"$  c #695809",
"%  c #705F0B",
"&  c #6A5F1E",
"*  c #6E621F",
"=  c #7C6A12",
"-  c #44422E",
";  c #4E4C2D",
":  c #4B4832",
">  c #41443D",
",  c #555135",
"<  c #57583A",
"1  c #5A5B3D",
"2  c #716622",
"3  c #746926",
"4  c #7D7432",
"5  c #393E40",
"6  c #3D4243",
"7  c #434745",
"8  c #464944",
"9  c #484B43",
"0  c #4A4D4C",
"q  c #4D514D",
"w  c #575341",
"e  c #50524E",
"r  c #4A4F50",
"t  c #4D5253",
"y  c #525553",
"u  c #575956",
"i  c #595A57",
"p  c #5B5D5A",
"a  c #5F615F",
"s  c #626047",
"d  c #60625E",
"f  c #5E6060",
"g  c #626562",
"h  c #656865",
"j  c #6A6D6B",
"k  c #70716E",
"l  c #6C7273",
"z  c #6E767B",
"x  c #737674",
"c  c #777975",
"v  c #797A77",
"b  c #7B7D7A",
"n  c #8C7711",
"m  c #8F7A12",
"M  c #89781F",
"N  c #917B12",
"B  c #827C3B",
"V  c #7F807E",
"C  c #9F8200",
"Z  c #99861D",
"A  c #A58700",
"S  c #A68A06",
"D  c #AB8D03",
"F  c #A98E0D",
"G  c #AF9107",
"H  c #AE900A",
"J  c #B49301",
"K  c #B89600",
"L  c #BC9A01",
"P  c #BC9E0B",
"I  c #B59910",
"U  c #BFA20F",
"Y  c #BFA51C",
"T  c #9E8B23",
"R  c #A4942C",
"E  c #AB9D37",
"W  c #C29F01",
"Q  c #C3A003",
"!  c #C4A40B",
"~  c #CBAA0C",
"^  c #C7A914",
"/  c #C9AC13",
"(  c #CAAF1E",
")  c #CFB016",
"_  c #D1B215",
"`  c #D6B719",
"'  c #D6B91E",
"]  c #D8BA1D",
"[  c #C4AC24",
"{  c #CAB42D",
"}  c #D0B521",
"|  c #D4BA24",
" . c #D9BD24",
".. c #D2BA2A",
"X. c #D9BF2A",
"o. c #DFC327",
"O. c #DCC231",
"+. c #D2C03A",
"@. c #E3C92D",
"#. c #E3CB34",
"$. c #E4CD3B",
"%. c #E9D035",
"&. c #EBD43F",
"*. c #9B8F41",
"=. c #B0A660",
"-. c #DDCB4D",
";. c #DECE5F",
":. c #E3CD42",
">. c #EDD74C",
",. c #F3DE4A",
"<. c #EEDB5F",
"1. c #F2DE51",
"2. c #F4E04C",
"3. c #E9D86C",
"4. c #F6E560",
"5. c #FBEB63",
"6. c #F6E56B",
"7. c #EFE071",
"8. c #767F82",
"9. c #74818D",
"0. c #7B868D",
"q. c #7F888D",
"w. c #6E8297",
"e. c #718599",
"r. c #76899A",
"t. c #7D8D9D",
"y. c #7F93A8",
"u. c #838583",
"i. c #868984",
"p. c #888A85",
"a. c #828789",
"s. c #848A8A",
"d. c #8A8D89",
"f. c #8E918E",
"g. c #838D93",
"h. c #808D98",
"j. c #84939D",
"k. c #979B97",
"l. c #9C9F9D",
"z. c #8697A5",
"x. c #8897A3",
"c. c #8D9BA4",
"v. c #8196AB",
"b. c #909BA2",
"n. c #909EA8",
"m. c #889DB0",
"M. c #839BB8",
"N. c #9EA3A3",
"B. c #94A1AA",
"V. c #9FA7A9",
"C. c #9EA9AC",
"Z. c #8EA2B6",
"A. c #8CA3BC",
"S. c #93A6B6",
"D. c #90A6BD",
"F. c #95A9BE",
"G. c #9EAEBC",
"H. c #A3A6A2",
"J. c #A7AAA7",
"K. c #A8ABA9",
"L. c #AFB3AE",
"P. c #ABB2B6",
"I. c #A3B2BC",
"U. c #ACB9BF",
"Y. c #B3B6B4",
"T. c #B6B8B5",
"R. c #B9BBB6",
"E. c #B6BDBB",
"W. c #BABEBB",
"Q. c #BDC1BB",
"!. c #C2C3BE",
"~. c #96ACC3",
"^. c #9BAFC4",
"/. c #9EB0C2",
"(. c #9DB2C8",
"). c #A4B5C5",
"_. c #A8B6C0",
"`. c #ACBAC3",
"'. c #A3B6CB",
"]. c #ACBCCB",
"[. c #B5BEC3",
"{. c #B1BFCB",
"}. c #AABDD1",
"|. c #B6C1C5",
" X c #B9C1C3",
".X c #B6C2CC",
"XX c #BBC5CB",
"oX c #BEC8CD",
"OX c #B5C3D2",
"+X c #BBC7D0",
"@X c #BECAD3",
"#X c #C3C6C2",
"$X c #C6C9C3",
"%X c #C9CBC6",
"&X c #C4CBCC",
"*X c #CBCDC9",
"=X c #CED1CD",
"-X c #D2D4CE",
";X c #C2CCD3",
":X c #C8CFD2",
">X c #C4CED9",
",X c #C6D0D6",
"<X c #CDD2D4",
"1X c #C6D0D8",
"2X c #CBD3DA",
"3X c #CED8DD",
"4X c #D3D5D1",
"5X c #D6D8D3",
"6X c #D9DAD7",
"7X c #D1D6D9",
"8X c #D4D9DB",
"9X c #DBDEDB",
"0X c #DFE1DD",
"qX c #E1E2DF",
"wX c #D5DDE2",
"eX c #D9DFE3",
"rX c #DCE1E2",
"tX c #DFE4EA",
"yX c #E4E5E2",
"uX c #E7E8E5",
"iX c #E9E9E7",
"pX c #E0E7EC",
"aX c #E4E9EB",
"sX c #ECECEA",
"dX c #EFF0EE",
"fX c #F0F0EF",
"gX c #E7ECF0",
"hX c #EFF3F8",
"jX c #F4F4F4",
"kX c #F7F8F7",
"lX c #F8F8F7",
"zX c #F6F8FA",
"xX c #FBFBFB",
"cX c None",
/* pixels */
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcX4X4X-X4X5X4X4X5X5X4X5X4X5X5X-X4X5X5XcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcX4XwXsXxXxXxXxXxXxXxXxXxXxXxXlXlXxXxXjXsXqX5XcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcX=XeXjXxXxXxXxXxXxXxXxXxXxXxXlXlXxXxXkXjXlXjXiX-XcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXXXwXhXxXlXxXxXxXxXxXxXxXxXxXlXkXkXkXkXjXjXjXjXlXuX=XcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcX>XhXxXkXkXkXjXxXxXxXxXxXxXlXlXkXjXkXjXjXfXfXjXlXjX-XcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcX).wXjXkXjXtXaXfXfXjXfXjXfXfXfXfXdXsXsXsXsXsXsXsXfXfXqX!.cXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcX|.9XuX8X>XpXjXjXjXjXjXjXjXjXjXkXjXjXjXjXjXjXfXyX9X9XqX$XcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXF.&X0X4X].2XyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXqXyXyXqX-X=X-X%XcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcX`.<X4X/.[.&X-X-X=X:X-X4X4X4X-X-X4X-X-X-X-X-X5X-X-X%X%X%X*XQ.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXE.4XG.G. X$X%X X[.%X$Xk.j t o o t j k.%X%X%X%X%X%X%X$XQ.=XR.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXQ.;XZ.`.$X$X XU.$XH.r r p j x j p 0 6 q J.%X%X%X%X%X$XQ.&XT.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXE.'.G. X%X XF.8.. 5 j V g q @ O 9 0 i 0 o . b *X*X%X$XQ.&XL.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXI.^.`. X%XZ.`.. p b h O & n S S N * X 8 y y . *X*X%X%XQ.&XC.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXS.'..X%X{.D.V.5 x q ; S A W J J D J S ; @ y O J.*XXX%X!.&XB.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXm.OX#X%XD.`.r p p ; D W A D C W C J W K ; 7 0 r -X|.*X!.=Xn.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXv.@X&X XM.b.7 h X D J D D J D A K H ! W H X e 6 l..X X#X<Xn.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXv.2X=X`.~.z 0 e & K L J J $ w + % F U P ~ * 7 7 k +XI.#X-Xx.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXz.3X-X).).t y 9 N K J W # !.#Xa.0 n ` ) ^ Z > 0 t XXD.%X<Xx.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXz.wX4X/.{.o y O D K J D + T.%Xv i - } | ' Y X t o .XF.%X<Xz.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXx.wX-X~.{.O y O D W K A   c b i f , .... .[ X t o {.^.*X<Xt.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXx.wX-XD.+Xy 0 > N L K P = X u f i *.$.O.@.R > 0 t ].`.*X2Xr.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXj.rX-X_.+Xl 7 8 * W W Q ^ M , s =.;.>.&.%.B @ 7 z ^.{.=X1Xw.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXj.rX-X#X@XH.6 y X H W ! ) ( O.-.3.7.4.,.+.X q 7 n.A.+X=X@Xw.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXj.9X=X4X@X6Xr 0 8 ; W ~ ) ' X.:.<.6.5.,.< 7 0 r OX(.4X;XOXw.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXh.6X=X4X;X9XY.5 y > ; I _ ` o.%.>.1.-.1 > y O P.'.;X4X&X}.r.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXg.8X*X4X6X6X0X. y y 0 O 3 T [ { E B 5 q i y . @X~.9X<X.X'.g.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXd.<X*X5X0X9X0Xu.. 5 0 i 0 8 O O 8 e i e 5 . a.'.2XyX:X).}.s.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.<X%X5XrXeX0XqXqXT.t 7 0 y f f i r 7 t Y.rX+X2XyX9X+X~.2Xs.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.6X$X6XqXqXqXqXqXqXyXK.z y o 5 y x K.yXqX2XwXyXyX8X].).yXs.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.4X$X6XqXqXyXyXyXqXyXqXyXyXyXyXyXyXyXyX7X6XyXyXrX>X'.=XeXa.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.-X%X6XyXyXyXyXyXyXyXyXyXyXyXyXyXyX#XT.-X6X$X=X3XOX7X=X8X0.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.-X#X9XyXyXyXyXyXyXyXyXyXyXyXuXyX%X*XdXjXxXjX:X+XqX9X*X;X9.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.-X!.9XyXqXqX0X0XyXiXiXiXiXiXiXiXR.6XiXzXxXgX8X-XiX9X+X+X0.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXi.-X$X9XuXqXyXyXqX0XiXiXyXsXyXiXyX!.6XyXjXzXjXuX-XyX8X[.+Xp.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXi.-X!.qXuXqXuXqXyXqXiXsXsXsXsXiXiX$X5XyXjXxXlXsX6XtX2X[.6Xd.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.%X!.qXuXqXqX0XsXyXsXsXsXsXsXdXsX5X4XyXjXxXlXfXaXeX8X%X=Xd.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXp.R.$X5XuXqXuXqXyXyXsXsXsXsXsXdXiXiX0XsXjXxXxXjXgXuX6X%XW.a.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXu.H.%X%X0XyXqXyXqXiXsXsXdXsXfXfXsXfXfXfXjXxXlXlXsXqX%X:XN.9.cXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXp.!.%X%XyXiXiXsXsXsXsXsXsXsXsXsXsXsXiXfXjXjXsXyX%X:XW.a.cXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXd f.!.%X4XyXyXyXyXuXyXyXyXyXyXyXyXyXuXuXuXyXyX5X%XW.f.d cXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXi i.H.R.*X-X-X4X4X-X-X-X-X=X-X=X-X-X-X-X-X*XR.H.i.i cXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXk V i.p.p.p.p.p.p.p.p.p.d.p.p.p.p.p.p.i.b k cXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX",
"cXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcX"
};
