/* XPM */
/* $XConsortium: IEtSelec.pm /main/3 1995/07/18 17:23:02 drk $ */
static char * IEtSelec [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 5 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor1	m black	c black",
"O	s iconColor2	m white	c white",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXooooXXooXXooXXooXXooXXooooXXX..",
"  XXXooooOXooOXooOXooOXooOXooooXXX..",
"  XXXooOOOXXOOXXOOXXOOXXOOXXOooOXX..",
"  XXXooOXXXXXXXXXXXXXXXXXXXXXooOXX..",
"  XXXXOOXXXXXXXXXXXXXXXXXXXXXXOOXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXooXXXXXXXXXXXXXXXXXXXXXXooXXX..",
"  XXXooOXXXXXXXXXXXXXXXXXXXXXooOXX..",
"  XXXXOOXXXXXXXXXXXXXXXXXXXXXXOOXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXooXXXXXXXXXXXXXXXXXXXXXXooXXX..",
"  XXXooOXXXXXXXXXXXXXXXXXXXXXooOXX..",
"  XXXXOOXXXXXXXXXXXXXXXXXXXXXXOOXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXooXXXXXXXXXXXXXXXXXXXXXXooXXX..",
"  XXXooOXXXXXXXXXXXXXXXXXXXXXooOXX..",
"  XXXXOOXXXXXXXXXXXXXXXXXXXXXXOOXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXooXXXXXXXXXXXXXXXXXXXXXXooXXX..",
"  XXXooOXXXXXXXXXXXXXXXXXXXXXooOXX..",
"  XXXooooXXooXXooXXooXXooXXooooOXX..",
"  XXXooooOXooOXooOXooOXooOXooooOXX..",
"  XXXXOOOOXXOOXXOOXXOOXXOOXXOOOOXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
