/* XPM */
/* $XConsortium: Dtaexe.m.pm /main/2 1996/07/23 11:59:50 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * dashap [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 -1 -1",
/* colors */
" 	s iconColor3	m black	c red",
".	s iconGray5	m black	c #7d7d7d7d7d7d",
"X	s iconGray4	m white	c #969696969696",
"o	s iconGray2	m white	c #c8c8c8c8c8c8",
"O	s iconColor1	m black	c black",
"+	s iconGray3	m white	c #afafafafafaf",
"@	s iconGray7	m black	c #4b4b4b4b4b4b",
"#	s iconGray6	m black	c #646464646464",
/* pixels */
" . . . X X X X X X o X o o X ..O",
". . X X X X X X o o o o o o X .O",
" X X o o o X o o X X X o o o X O",
"o o o o o o X o o o X X o o o oO",
" o o o o o o o o o o . . o o o O",
"o o o o o o o o o o X . X o o oO",
" o o o o o o o o o X X X X X o O",
"o XOOOOOOOOOO.X o o o o o o o oO",
"OOOOOOOOOOOOOOOOOo o o o o o o O",
"OOOOOOOOOOOOOOOOOOO o o o o o oO",
"OOOO.     .OOOOOOOOOOo o o o o O",
"O o o o o X+..OOOOOOOOO o o o oO",
" o oXXXXXXXXXXXX@@OOOO OOXXXXXXO",
"oXXXOXOXOXOXOXOXO.@OOOO XOOOOXXO",
" O O O OOOOOOOOOOOO.@OOO XOOOOOO",
"O O OOOOOOOOOOOOOOOOO@OOO  OOOOO",
" O OOOO OOOOOOOOOOOOOO@OOOOXOOOO",
"O OOO OOOOOOOOOOOOOOOOOOOOO .OOO",
"OOO OOOOOO     OOOOOOOOOOOOOX.OO",
"OO OOOOO  OOOOO  OOOOOOO  OOOXOO",
"O OOOOO OO OO OOO OOOOO OOOOO .O",
"OOOOOO OOOO OOOOO OOOO OO OOOOXO",
"OOOOOO O OO OOOOOO OO OOO OOOO O",
"OOOOO OOOOO OOOO OOOOOOOOO OOOOO",
"OOOOO O OOO O OOOO O O OOO OOOOO",
"OOOOO OOOO OOOOOOOOOOOOOOOO OOOO",
"   OO OOOO OOOOOOO O OOOOOO OOOO",
"OO  O O OOOOOOOO OOOOO OOOOOOOOO",
"OOOOOO OO O   OOOO O OOOOOOOOOOO",
"OOOOOOOOOOOOOOOOO OOOO OOOOOO OO",
"OOOOOOOOOOOOOOOOOOOOO O # # # OO",
"OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"};
