/* XPM */
/* $XConsortium: DtCMyr.m.pm /main/2 1996/07/23 11:56:27 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtCMyr_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 9 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconGray5	m black	c #7d7d7d7d7d7d",
"X	s iconGray3	m white	c #afafafafafaf",
"o	s iconGray1	m white	c #e1e1e1e1e1e1",
"O	s iconColor2	m white	c white",
"+	s iconGray4	m white	c #969696969696",
"@	s iconColor1	m black	c black",
"#	s iconColor5	m black	c blue",
"$	s iconGray2	m white	c #c8c8c8c8c8c8",
/* pixels */
"    .                    .      ",
"   Xo.                  Xo.     ",
"OOOXo.OOOOOOOOOOOOOOOOOOXo.OOO  ",
"OOoXo.oXoOooooooooooooooXo.oX+. ",
"OoOXo.XoOoOoooooooooooooXo.Xo+. ",
"OOoO@XoO..............ooo@Xoo+. ",
"OoOoOoOoOoooooooooooooooooooo+. ",
"OOoOoOooooooooooooooooooooooo+. ",
"X.............................. ",
"OO####o.o####o.o####o.o#####o+. ",
"OoOoOoo.oooooo.oooooo.ooooooo+. ",
"OOooooo.oooooo.oooooo.ooooooo+. ",
"OoOoooo.oooooo.oooooo.ooooooo+. ",
"X.............................. ",
"Oo####o.o####o.o####o.o#####o+. ",
"Ooooooo.oooooo.oooooo.ooooooo+. ",
"Ooooooo.oooooo.oooooo.ooooooo+. ",
"Ooooooo.oooooo.oooooo.ooooooo+. ",
"Ooooooo.oooooo.oooooo.ooooooo+. ",
"X.............................. ",
"Oo####o.o####o.o####o.o#####o+. ",
"Ooooooo.oooooo.oooooo.ooooo$o+. ",
"Ooooooo.oooooo.oooooo.oooooo$+. ",
"Ooooooo.oooooo.oooooo.ooo$ooo+. ",
"Ooooooo.oooooo.oooooo.oooo$o$+. ",
"X.............................. ",
"Ooooooooooooooooooooooo$o$o$o+. ",
"Oooooooooooooooooooooooo$o$o$+. ",
"Ooooooooooooooooooooo$o$o$o$$+. ",
"Oooooooooooooooooooooo$o$o$$$+. ",
"O+++++++++++++++++++++++++++++  ",
"                                "};
