/* XPM */
/* $XConsortium: clock.pm /main/2 1996/07/23 12:26:48 drk $ */
static char * clock [] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 5 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X    s selectColor m white c #737373737373",
"o    s topShadowColor m white c #bdbdbdbdbdbd",
"O	s iconColor1	m black	c black",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"      ....................................      ",
"     ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.o     ",
"    ..XXXXXXXXXXXXXXXXXXOXXXXXXXXXXXXXXXXX.o    ",
"    .XXXXXXXXXXXXXXXXXXOOOXXXXXXXXXXXXXXXXX.o   ",
"    .XXXXXXXXXXOXXXXXXXXOXXXXXXXXOXXXXXXXXXXo   ",
"    .XXXXXXXXXX                   XXXXXXXXXXo   ",
"    .XXXXXXXXX                     XXXXXXXXXo   ",
"    .XXXXXXXX                       XXXXXXXXo   ",
"    .XXXXXXX                         XXXXXXXo   ",
"    .XXXXXX                           XXXXXXo   ",
"    .XXXXX                             XXXXXo   ",
"    .XXXO                               OXXXo   ",
"    .XXXX  O                            XXXXo   ",
"    .XXXX  OOO                          XXXXo   ",
"    .XXXX   OOO                         XXXXo   ",
"    .XXXX     OOO       O               XXXXo   ",
"    .XXXX      OOO     OO               XXXXo   ",
"    .XXXX        OO    OO               XXXXo   ",
"    .XXXX         OOO  OO               XXXXo   ",
"    .XXOX           OO OO               XOXXo   ",
"    .XOOO            OOOO               OOOXo   ",
"    .XXOX             OOO               XOXXo   ",
"    .XXXX             OOO               XXXXo   ",
"    .XXXX                               XXXXo   ",
"    .XXXX                               XXXXo   ",
"    .XXXX                               XXXXo   ",
"    .XXXX                               XXXXo   ",
"    .XXXX                               XXXXo   ",
"    .XXXX                               XXXXo   ",
"    .XXXO                               OXXXo   ",
"    .XXXXX                             XXXXXo   ",
"    .XXXXXX                           XXXXXXo   ",
"    .XXXXXXX                         XXXXXXXo   ",
"    .XXXXXXXX                       XXXXXXXXo   ",
"    .XXXXXXXXX                     XXXXXXXXXo   ",
"    .XXXXXXXXXX                   XXXXXXXXXXo   ",
"    .XXXXXXXXXXOXXXXXXXXOXXXXXXXXOXXXXXXXXXXo   ",
"    ..XXXXXXXXXXXXXXXXXOOOXXXXXXXXXXXXXXXXXoo   ",
"     o.XXXXXXXXXXXXXXXXXOXXXXXXXXXXXXXXXXXoo    ",
"      o.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoo     ",
"       ooooooooooooooooooooooooooooooooooo      ",
"                                                ",
"                                                ",
"                                                "};
