/* XPM */
/* $XConsortium: DtABspb.pm /main/3 1995/07/18 16:15:54 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * DtABspb_x_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"28 20 6 1 0 0",
/* colors */
"     s iconGray4     m white c #949494949494",
".	s iconColor1	m black	c black",
"X    s iconGray7     m black c #424242424242",
"o    s iconGray1     m white c #dededededede",
"O    s iconGray2     m white c #bdbdbdbdbdbd",
"+    s iconGray5     m black c #737373737373",
/* pixels */
"                            ",
"         .........          ",
"         .XXXoXXXo          ",
"         .XXoOoXXo          ",
"         .XXoOoXXo          ",
"         .XoOOOoXo          ",
"         .XoOOOoXo          ",
"         .oOOOOOoo          ",
"         .+++++++o          ",
"         .XXXXXXXo          ",
"         .XXXXXXXo          ",
"         .oooooooo          ",
"         .+OOOOO+o          ",
"         .X+OOO+Xo          ",
"         .X+OOO+Xo          ",
"         .XX+O+XXo          ",
"         .XX+O+XXo          ",
"         .XXX+XXXo          ",
"         .oooooooo          ",
"                            "};
