/* XPM */
/* $XConsortium: Dtblink.m.pm /main/3 1995/07/18 16:32:04 drk $ */
static char * Dtblink2_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray6     m black c #636363636363",
"+	s iconColor5	m black	c blue",
"@    s iconGray8     m black c #212121212121",
/* pixels */
"                         .......",
" XXXXXXXXXooooXXXXXXXXXXo.......",
" XXXXXXXOoOOOOoOXXXXXXXXo.......",
" XXXXXXXoOXXXXOoXXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXOOXXOOXXOOXXXXXXXo.......",
" XXXXXXXooooooooXXXXXXXXo.......",
" XXXXXXXXooXXooXXXXXXXXXo.......",
" X+XXXXXooXooXooXXXXX+XXo.......",
" XX+XXXOOXXXXXXOOXXX+XXXo.......",
" XXX+XXOoXXXXXXoOXX+XXXXo.......",
" XXXX+XXXXXXXXXXXX+XXXXXo.......",
" +++XXXXXXXXXXXXXXXX+++Xo.......",
" XXXX+XXXXXXXXXXXX+XXXXXo.......",
" XXX+XXXXXXXXXXXXXX+XXXXo.......",
" XX+XXXoOXXXXXXOoXXX+XXXo.......",
" X+XXXXOoXXXXXXoOXXXX+XXo.......",
" XXXXXXXooXooXooXXXXXXXXo.......",
" XXXXXXXoooXXoooXXXXXXXXo.......",
" XXXXXXXooooooooXXXXXXXXo.......",
" XXXXXXOoXXOOXXoOXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXO@XXXXXXoOXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXOoXXXXXXoOXXXXXXXo.......",
" XXXXXXOoOXXXXOoXXXXXXXXo.......",
" XXXXXXXOoOOOOoOXXXXXXXXo.......",
" XXXXXXXXOooooXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
