/* XPM */
/* $XConsortium: Dtdate.t.pm /main/2 1996/07/23 12:08:06 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * date [] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 7 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconGray2	m white	c #c8c8c8c8c8c8",
"X	s iconColor2	m white	c white",
"o	s iconGray8	m black	c #323232323232",
"O	s iconGray7	m black	c #4b4b4b4b4b4b",
"+	s iconGray5	m black	c #7d7d7d7d7d7d",
"@	s iconGray4	m white	c #969696969696",
/* pixels */
"                ",
"                ",
" .............. ",
" .XXXXXXXXXXo.O ",
" .X+++XXXXXXo@O ",
" .X+X+XXXXXXo@O ",
" .X+++++++XXo@O ",
" .XXXXXXXXXXo@O ",
" .X+++XXXX+Xo@O ",
" .XX+@@@+X+Xo@O ",
" .XXXXXXXXXXo@O ",
" .ooooooooooo@O ",
" ..@@@@@@@@@@@O ",
"  OOOOOOOOOOOOO ",
"                ",
"                "};
