/* XPM */
/* $XConsortium: DtCMapt.l.pm /main/3 1995/07/18 16:18:41 drk $ */
static char * DtCMapt_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 11 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray1     m white c #dededededede",
"o	s iconColor1	m black	c black",
"O	s iconColor3	m black	c red",
"+    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"#    s iconGray5     m black c #737373737373",
"$	s iconColor6	m white	c yellow",
"%    s iconGray4     m white c #949494949494",
"&    s iconGray6     m black c #636363636363",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"   ..... ............................... .....  ",
"   .XXXo .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXo .XXXo  ",
"   .XXo   .XXXXXXXXXXXXXXXXXXXXXXXXXXXo   .XXo  ",
"   .XXo   .XXXXXXXXXXXXXXXXXXXXXOoXXXXo   .XXo  ",
"   .XXo   .XXXXXXXXXXXXXXXXXXXXOOOoXXXo   .XXo  ",
"   .XXX...XXXXXXXXXXXXXXXXXXXXOOOOOoXXX...XXXo  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXX+@OOO#OoXXXXXXXXo  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXX+XX@O#O#OoXXXXXXXo  ",
"   .XXXXXXXXXXXXXXXXXXXXXX.@XX..oO#OooXXXXXXXo  ",
"   .XXXXXXXXXXXXXXXXXXXXX.$$@..++oOoo%XXXXXXXo  ",
"   .XXXXXXXXXXXXXXXXXXXX.$$.$@++@@oo%%@XXXXXXo  ",
"   .XXXXXXXXXXXXXXXXXXX.$$.$$#o@@oo%%@+XXXXXXo  ",
"   .XXXXXXXXXXXXXXXXXX.$$.$$#$#ooo%%@+XXXXXXXo  ",
"   .XXXXXXXXXXXXXXXXX.$$.$$#$#$oo%%@+XXXXXXXXo  ",
"   .XXXXooooooXXXoooo$$.$$#$#$ooooooooXooXXXXo  ",
"   .XXXXXXXXXXXXXXX.$$.$$#$#$oo%%@+XXXXXXXXXXo  ",
"   .XXXXXXXXXXXXXX.$$.$$#$#$oo%%@+XXXXXXXXXXXo  ",
"   .XXXXXXXXXXXXX.$$.$$#$#$oo%%@+XXXXXXXXXXXXo  ",
"   .XXXXooooooXX.$$.$$#$#$ooooooXXXXXXXXXXXXXo  ",
"   .XXXXXXXXXXX.$$.$$#$#$oo%%@+XXXXXXXXXXXXXXo  ",
"   .XXXXXXXXXX.$$.$$#$#$oo%%@+XXXXXXXXXXXXXXXo  ",
"   .XXXXXXXXX.$$.$$#$#$oo%%@+XXXXooooooXXXXXXo  ",
"   .XXXXXXXX.$$.$$#$#$oo%%@+XXX&&&&&&&&ooXXXXo  ",
"   .XXXXoooo$$.$$#$#$oooooooo&&&&XX.X.X%%ooXXo  ",
"   .XXXXXX.$$.$$#$#$oo%%@+XX&&&++X.XoX.X.%%oXo  ",
"   .XXXXX.$$.$$#$#$oo%%@+XX&&%+.X.X.o.X.XXX%oo  ",
"   .XXXX.$$.$$#$#$oo%%@+XXX&%X.X.X.X.X.XXoX%oo  ",
"   .XXX.$$.$$#$#$oo%%@+XXX&%X.X.oXX.X.XXoo.X%o  ",
"   .XXXX%%$$#$#$oo%%@+XXXX&%.X.oooXX.XXoooXX%o  ",
"   .XXoXXX%#$#$oo%%@+XXXX&%.X.X.oooXXXoooXX.X@o ",
"   .XXoXXX%##$oo%%@+XXXXX&%X.X.X.oooXoooXX.XX@o ",
"   .XXoXX%X%$oo%%@+XXXXXX&%.ooX.X.oXoooXX.%%X@o ",
"   .XXoX++%%oo%%@+XXXXXXX&%X.X.X.XXoooXX.X.XX@o ",
"   .Xoooooooo%%@+XXXXXXXX&%.X.X.X.oooXX.X...X@o ",
"   .Xoooo%%%%+@+XXXXXXXXX&%X.X.X.XXoXX.X...XX@o ",
"   .Xo@@@+@++@+XXXXXXXXXXX&%X.X.X.X.X.X.X.X.@o  ",
"   .XX@@XXXXXXXXXXXXXXXXXX&%.X.X.X.X.X.X...X@o  ",
"   .XXXXXXXXXXXXXXXXXXXXXXX&%.X.X.X.X.X...X@oo  ",
"   .XXXXXXXXXXXXXXXXXXXXXXX&%X.X.X.X%....X.@oo  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXX&%%.X.X.%...X@@o@o  ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXoo%%X.....@@oo@@o  ",
"   .ooooooooooooooooooooooooooooo%%%%%%oooooo   ",
"                                 oooooo         ",
"                                                ",
"                                                "};
