/* XPM */
/* $XConsortium: mstylmgr.pm /main/4 1996/10/29 15:57:12 drk $ */
static char * mstylmgr_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"470 90 19 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	c #C2C2D9D9D3D3",
"X	c #7676A9A99C9C",
"o	c #3C3C56565050",
"O	c #DFDFDFDFDFDF",
"+	c #AEAEAEAEAEAE",
"@	s iconGray8	m black	c #212121212121",
"#	s iconGray5	m black	c #737373737373",
"$	c #BEBEBEBEBEBE",
"%	s iconGray7	m black	c #424242424242",
"&	c #51515151FBFB",
"*	s iconColor8	m black	c magenta",
"=	c #646490908585",
"-	c #959595959595",
";	s iconColor6	m white	c yellow",
":	s iconGray6	m black	c #636363636363",
">	c #FAFA13134040",
",	c #3B3BFAFA3434",
"<	s iconColor1	m black	c black",
/* pixels */
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"   .............................................................................................................................................................................................................................................................................................................................................................................................................................................................................      ",
"   .............................................................................................................................................................................................................................................................................................................................................................................................................................................................................      ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo      ",
"   .XXooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooXo      ",
"   .XX........................................................................................................................................................................................................................................................................................................................................................................................................................................................................Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX.XX......XXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXX  X XX  XXX X X XXXXX X XX X X  X  X XX  X X X   XX XXX XXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXX...XXXX.Xo      ",
"   .XX.XX.XXXXoXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXX X X XXX X X   X XXXX  X  X  XXXX X X XXX   X XXXX X X X X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXX.XoXXXX.Xo      ",
"   .XX.XX.oooooXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXX X X XXXXX XX XX XXXX XX  XX XXXX X X XXX  XX  XXX XXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXX.ooXXXX.Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXX X X XXX X X   X XXXX XX  X  XXXX X X XXX  XX  XXX X X X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX   XXXXXXXXXXXXXXXXX  XXXXXXXXXXXXXXXXXXXXXXX  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XXXXXXXXXX.Xo      ",
"   .XX........................................................................................................................................................................................................................................................................................................................................................................................................................................................................Xo      ",
"   .XX........................................................................................................................................................................................................................................................................................................................................................................................................................................................................Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXX  XXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX X  XX XXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX XX X XXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXX XXXXXXX X  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    X  X X XXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXX X  XXXX    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX X  X X   XXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXX XXXXXXX XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX X  X X XXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXX  XXX   X XX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX X  X XX  XXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXX      XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX       XXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.Xo      ",
"   .XX.oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo.Xo      ",
"   .XX........................................................................................................................................................................................................................................................................................................................................................................................................................................................................Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooooooooooooooooooooooooooooooooooooooooooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOO++@##OO++@@@##OO+++@@#@XXXXXXXXXXXXXXo                                         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo                           .XXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXoooooooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO+++++++++++++++++++@#OO+++@@###OO+++@@#@XXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO$$OO$O$O$O$O$$$$$$$$$$$$$%.XXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXooo       ooXXXXXXXXXXXXXXXXXXXXX                  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO+++++++++++++++++++@OO+++@@###OO+++@@##@XXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoOOoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo$OO$$O$O$O$O$$$$$$$$$$$$$$%.XXXXXXXXXXXXXXXXXoO++++++++++++++++O++++++++++++++++++++++.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXo  $++++++++++$ ooXXXXXXXXXXXXXXXXXX @@@@@@@  @@@@@@@ @XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOO++++@O+++@@###OO++@@@##O@XXXXXXXXXXXXXXXXXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@.XXXXXXXXXXXXXXXXXXXoo                    ooXXXXXXXXXXXXXXXXXXXXXXX XXXXXo+%+$XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo$O@&&@&&@@&&@&&@@&&@&&@@ $%.XXXXXXXXXXXXXXXXXoO++++++++++++++++O++++++++++++++++++++++.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXo $++++++++***+++  XXXXXXXXXXXXXXXXXX @@===@@  @@===@@ @=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO++++++++++++++@++++@+++@@###OO+++@@###O@XXXXXXXXXXXXXXXXX@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@.XXXXXXXXXXXXXXXXXXXo oooooo$$$$$$$$$++++O .oXXXXXXXXXXXXXXXXXXXXXXXXXXXXo %++oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO$+++++++++++++++++++++- $%.XXXXXXXXXXXXXXXXXoO++++++++++++++++O++++++++++++++++++++++.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXo $++;++;++******:+++oXXXXXXXXXXXXXXXXX ==XXXXX  @@XXXXX @=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO++++++++++++++@++++@++@@##OOO++@@###OO+@XXXXXXXXXXXXXXXXXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$$+++++--OXXXXXXXXXXXXXXXXXXXXXXXXXXXXo % ++$XXXXXXXXXXXXXXXXXXXXXXXXXXXXoO$++     $$$$$$$$$$$$++- $%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O++++++++++++++++++++++XXXXXXXXXXXXXXXXXXoOOOOOOOOOOoXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXX +++;;;;+++******:+++o.XXXXXXXXXXXXXXXX =XXXXXX  @@XXXXX@@=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoOOOOOOOOOOOOO++@++++@+@@###OO+++@@###OO+@XXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@.XXXXXXXXXXXXXXXXXXo o++++++%$$$$$$$$$$++-+-%XXXXXXXXXXXXXXXXXXXXXXXXX XXo %  ++oXXXXXXXXXXXXXXXXXXXXXXXXXXXo$O&& &  &&&&&&&&&&&&&&&& +%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O++++++++++++++++++++++XXXXXXXXXXXXXXXXXoO&OO&OO&&OO#oXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXo+++;;;;+;+++****:++++@.XXXXXXXXXXXXXXXXX=XXXXXX  @@XXXXXX@=XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoO+++++++++++@++@++++@@@###OO+++@@###OO++@XXXXXXXXXXXXXXXXXo%%%%%%%%%%%%%%%%%%%%%%%%O%%%%%%%%%%OO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$$+++++--oXXXXXXXXXXXXXXXXXXXX XXXXXXXo %  ++ooooooXXXXXXXXXXXXXXXXXXXXXXoO$+$     OOOOOOOOOOOO$$- $%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O+++++++++++++++++++++.XXXXXXXXXXXXXXXXXO##OO#OO##OO#%oooooooooooooooooooXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXo $+++;;;;>++++++++++++@.XXXXXXXXXXXXXXXXXXXXXXXXX  @@XXX  @@    @@@ @XXXXXXXXXXXXXXXXXXXXXXXXoO+++++++++++@++@++++@@###OO+++@@##OOO++@@XXXXXXXXXXXXXXXXXo######O##O##O########## O%O####### OO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$$+++++--%XXXXXXXXXXXXXXXXXXXX%XX  XXXo++$   %++++@.XXXXXXXXXXXXXXXXXXXXXo$O+$     O  O  OO OOO$+- $%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O++++++++++++++++++++.XXXXXXXXXXXXXXXXXXO##OO#OO##OO#%@@@@@@@@@@@@@@@@%@@@oXXXXXXX.Xo      ",
"   .XX.XXXXXXXX $++>++;;;++++++++++++@@XXXXXXXXXXXXXXXXXXXXXXXXXX  @@XXX @@@@  @@@@ @@XXXXXXXXXXXXXXXXXXXXXXXoOOOOOOOOOO++@++@++++@###OO+++@@###OO+++@@XXXXXXXXXXXXXXXXXo######O##O##O########## O%O####### OO@.XXXXXXXXXXXXXXXXooo +oooooo $$$$$$$$$$++-+-%XXXXXXXXXXXXXXXXXXXXX%XXXX%Xo+% $$ +    -.XXXXXXXXXXXXXXXXXXXXXoO$&&     &&&&&&&&&&&&&&& +%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O++++++++++++++++++++.XXXXXXXXXXXXXXXXXXO&@@O&OO&&OO#%OO  OOOOO OOOOOO  OOoXXXXXXX.Xo      ",
"   .XX.XXXXXXXo$++>>>+++++++@@@@+++@.XXXXXXXXXXXXXXXXXXXXXXXXXXXX  @@XXX @=XX  @@=X@@@XXXXXXXXXXXXXXXXXXXXXXXoO++++++++@++@++@++++@##OO++@@@##OO+++@@#@XXXXXXXXXXXXXXXXXo#OOOOO#OO#OO#OOOOO#OOO# O%OO#OO#OO OO@.XXXXXXXXXXXXXXoo-$+ o++++++o$$$$$$$+$++----%XXXXXXXXXXXXXXXXXXXXXXXXXXXX +# ++ %+  +@.XXXXXXXXXXXXXXXXXXXXXo$O&&     &&&&&&&&&&&&&&& $%.XXXXXXXXXXXXXXXXXoO+++O++O++++++@++O++++++++++++++++++++.XXXXXXXXXXXXXXXXXXO&==O&OO&&OO#%OOOOOOOOOOOOOOOOOOO.XXXXXXXX.Xo      ",
"   .XX.XXXXXXXo++>>>>>+++++@@XXX++@.XXXooXXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXX@@XXXXXXXXXXXXXXXXXXXXXXXoO@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@XXXXXXXXXXXXXXXXXXoO##O##O##O####O###O### O%O####### OO@.XXXXXXXXXXXXXXOO-$+ o++++++o$$$$$$$$+++++--%XXXXXXXXXXXXXXXXX XX  X  XXX++%+  +% ++ @.XXXXXXXXXXXXXXXXXXXXXoO$++             OOOOO$- +%.XXXXXXXXXXXXXXXXXoO+++O++O++++++@++O++++++++++++++++++++XXXXXXXXXXXXXXXXXXXO#=XO#OO##OO#%O  O   OO#@@O @ @@#XXXXXXXXX.Xo      ",
"   .XX.XXXXXXXo++>>>>>+++++@XXXX++@.XooO$XXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXX          XXXXXXXXXXXXXXXoO+++++++++++++++++++@OO@@OO@@@OO@@OO@@OO@XXXXXXXXXXXXXXXXXXoO##O##O##O####O###O### O%O####### OO@.XXXXXXXXXXXXXX::-$+ o++++++o$$$$$$$$$$++-+-%XXXXXXXXXXXXXXXXXXXXXXXXXXXX +% ## %#  #@.XXXXXXXXXXXXXXXXXXXXXo$$&&&&&&&&&&&&&&&&&&&&&& $%.XXXXXXXXXXXXXXXXXoO+++O++O@@@@@@@++O++++++++++++++++++++XXXXXXXXXXXXXXXXXXXO&==O&OO&&OO#%O @  @@  @.@ @.@@..XXXXXXXXX.Xo      ",
"   .XX.XXXXXXXo++>>>>:+++++#OOOO++$OOO++@XXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXX @@@  @@@ @XXXXXXXXXXXXXXoO@@+O@@@@+O@@@++@@@@@OO@@OO@@@OO@@OO@@OO@XXXXXXXXXXXXXXXXXXo#OO#OO#OO#OOOO#OOOOOO# O%OO#OO### OO@.XXXXXXXXXXXXXXXX.$+ o++++++o$$$$$$$+$++----%XXXXXXXXXXXXXXXXXXXXXXXXXXXX +% ## %#  #@.XXXXXXXXXXXXXXXXXXXXXo$$&&&&&&&&&&&&&&&&&&&&&& +%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O++++++++++++++++++++XXXXXXXXXXXXXXXXXXXO&OOO&OO&&OO#%@@.@@.X..XXX.XXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXo+++>>:+++&&+++++++++++++@.XXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXX @==  @== @=XXXXXXXXXXXXXoO+++O@++++O+++++@+++@+O+@+O+@+O+@+O+++++@XXXXXXXXXXXXXXXXXXo#O##O#######O##O###### O%O####### OO@.XXXXXXXXXXXXXXXXX.o +oooooo $$$$$$$$+++++--%XXXXXXXXXXXXXXXXXXXXXXX  XXXo+%# ##%####@.XXXXXXXXXXXXXXXXXXXXXoO$+$$$$$OO$OOOO$$OO$O+$- $%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O+++++++++++++++++++.XXXXXXXXXXXXXXXXXXXO##OO#OO##OO#@@.X..XXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXX ++++++&&&&&&+++++&&,,++.XXXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXXXXXX  @=XX@=XXXXXXXXXXXXXoO+++O@++++O+++++@+++@+O+@+O+@+O+@+O+++++@XXXXXXXXXXXXXXXXXXX###################### O%######## OO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$$+++++--%XXXXXXXXXXXXXXXXXXXX XX%%XXXo+%####%####@.XXXXXXXXXXXXXXXXXXXXXo$$++$$$$$$$$$$$$$$$$+++- +%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O+++++++++++++++++++.XXXXXXXXXXXXXXXXXXXO##OO#OO##OO#@XXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXX $++++++&&&&&&+++&,,&,++.XXXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXXXXXX  @=XXX=XXXXXXXXXXXXXoO+++O@++++O+++++@+++@OO@@OO@@@OO@@OO@@OO@XXXXXXXXXXXXXXXXXXXOOOOOOOOO#OOO#OO###### O%OO###### OO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$+$++----%XXXXXXXXXXXXXXXXXXXXX%XXX %Xo+%####%@@@@..XXXXXXXXXXXXXXXXXXXXXo$$&%%&%%&&%%&%%&&%%&%%&& $%.XXXXXXXXXXXXXXXXXoO+++O++++++++++++O+++++++++++++++++++.XXXXXXXXXXXXXXXXXXXo&&OO&OO&&OO#@XXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXX$@++++&&&&&<+++&&+++@.XXXXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXXXXXX  @=XXXXXXXXXXXXXXXXXoO+++++++++++++++++++@OO@@OO@@@OO@@OO@@OO@XXXXXXXXXXXXXXXXXXX###################### O%O####### OO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$$$$++-+%%XXXXXXXXXXXXXXXXXXXXXXXXX%XXo%%##%%.XXXXXXXXXXXXXXXXXXXXXXXXXXXo$$%&&%&&%%&&%&&%%&&%&&%% $%.XXXXXXXXXXXXXXXXXoOOOO$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$.XXXXXXXXXXXXXXXXXXXXXX...........XXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXX.@+++++&&++++++++++..XXXXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXXXXXX  @=XXXXXXXXXXXXXXXXXoOOO+OOOOO+OOOO++OOOO@+O+@+O+@+O+@+O+++++@XXXXXXXXXXXXXXXXXXXo##################### O%######## OO@.XXXXXXXXXXXXXXXXXXo o++++++o$$$$$$$$+++++-%.XXXXXXXXXXXXXXXXXXXXXXXXXXXXo%%##%@XXXXXXXXXXXXXXXXXXXXXXXXXXXXo$$                       +%.XXXXXXXXXXXXXXXXXoO+++$+++++++++++++++++++++++++++++++.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXX..@@+++++++++++++@@.XXXXXXXXXXXXXXXXXXXXXXXXXXX  @@XXXXXXXX  @@XXXXXXX  @=XXXXXXXXXXXXXXXXXoO@@+O@@@@+O@@@++@@@@@OO@@OO@@@OO@@OO@@OO@XXXXXXXXXXXXXXXXXXXo                      O%         OO@.XXXXXXXXXXXXXXXXXXo +oooooo $$$$$$$+$++---%.XXXXXXXXXXXXXXXXXXXXXX XXXXXo%%#%@.XXXXXXXXXXXXXXXXXXXXXXXXXXXXo$$$$$$$$$$$+$$+$+$+$$$++$$%.XXXXXXXXXXXXXXXXXoO+++$###############################XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXX...@@@@@@@@@..XXXXXXXXXXXXXXXXXXXXXXXXXXX      XXXXXXX    @XXXXXXX  @=XXXXXXXXXXXXXXXXXoO+++O@++++O+++++@+++@OO@@OO@@@OO@@OO@@OO@XXXXXXXXXXXXXXXXXXXoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO@.XXXXXXXXXXXXXXXXXXXo@%@@@@@@@@@@@@@@@@@@%..XXXXXXXXXXXXXXXXXXXXXXX%XXXXXo+%%@XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo%%%%%%%%%%%%%%%%%%%%%%%%%%%.XXXXXXXXXXXXXXXXXoO+++$###############################XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXX..........XXXXXXXXXXXXXXXXXXXXXXXXXXXX        @XXXX      @XXXX      @XXXXXXXXXXXXXXXXoO+++O@++++O+++++@+++@+O+@+O+@+O+@+O+++++@XXXXXXXXXXXXXXXXXXXo@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@.XXXXXXXXXXXXXXXXXXXX......................XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo+%@.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo............................XXXXXXXXXXXXXXXXXoO+++$###############################XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX@@@@@@@@@XXXX@@@@@@@XXXXX@@@@@@XXXXXXXXXXXXXXXoO+++++++++++++++++++@+O+@+O+@+O+@+O+++++@XXXXXXXXXXXXXXXXXXXo.....................................XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX=========XXXX=======XXXX=======XXXXXXXXXXXXXXoO@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.........................................XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXX   XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  XXXXX XXXXXX XX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXX  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    XXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX   XXX XXX XXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX XXXXXXXXXXXX XXXXXXXX XXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXX oooXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Xo XXXX XXXXXXXX oo XXXXXXXXXXXXXXXXXXXXXXXXXXoXX XoXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXoooXXXXXXX oXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  XX oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Xo XoXXXXXXXXXXXXoXoXXXXXXXXXXXXXXXXXXXXXXXXX oo Xo XXX oXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX oooXXXXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX oX oXXXXXXXXXXX XXXXXXXX XXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXX   XooX Xo XoX o XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  X XoX XoX  o X oX oXXXXXXXXXXXXXXXXXXXXXXXXX     o XoXXoo o   o X    o o o X X o oXXXXXXXXXXXXXXXXXXXXXXXXXoXoo  X X ooooXXoo X   oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX oX  oXo  oXo o XXXXXXXXXXXXXXXXXXXXXXX  X oXo o XoXXo XoXoo ooX Xo XXXXXXXXXXXXXXXX   Xoo  Xo oXoX X X X X   o o X XXXXXXXXXXXXXXXXXXXXXXXXX   XXo   o  XoXXooXo   oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo o oXoX o oXo X oXo X XX oXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXX ooX  o oXooXo   oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo  oXo oXo oX X XX XXXXXXXXXXXXXXXXXXXXXXXXXXooo  o oXoXoX    oX oX  oX o ooo o XXoXXXXXXXXXXXXXXXXXXXXXXXXXoX   X Xo oX  oXoX X  oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX oo  oX   oXoX XXXXXXXXXXXXXXXXXXXXXXXXXo  ooXXo oXoX  ooXoX XXo oX XXXXXXXXXXXXXXXX oo Xo  oX o  o oXooo o  oX X o oXXXXXXXXXXXXXXXXXXXXXXXX ooo    oX X  oXoX    oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoX  o  o o o  XX XX  oooX XXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXX XX Xoo XXoXXo oooXXXXXXXXXXXXXXXXXXXXXXXXXXXX XX  oXX XXo oX X XX XXXXXXXXXXXXXXXXXXXXXXXXXXoXX  o XXoXoX oo oX oX  oX o ooX o XXoXXXXXXXXXXXXXXXXXXXXXXXXXoXXo XX X oXXooXoX X  oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX o X o o  oXoXo XXXXXXXXXXXXXXXXXXXXXX XX  ooXXo XXo X ooXoX XXo XX XXXXXXXXXXXXXXXX oX oo  oX oXoX oXXoX o  oX X o oXXXXXXXXXXXXXXXXXXXXXXXX oXXooo oX XXoXXoXooo oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoX  oooo o oXo X X o ooXX XXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXX XXX    XXo  oX XoXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  XX  o XXo oX X XX XXXXXXXXXXXXXXXXXXXXXXXXXXoXX  o XXoX XX X oXX X  oXX  ooX oX XoXXXXXXXXXXXXXXXXXXXXXXXXXoX  XX Xo  X   X XX   oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX o o oX XX  oX XXXXXXXXXXXXXXXXXXXXXXXX  X o  Xo XXoX X oX XX  o XX XXXXXXXXXXXXXXXX   Xoo X   o  oX XooX o  oX X o oXXXXXXXXXXXXXXXXXXXXXXXX oXX  X oX X  oX X  X oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXX o  oX  o  XX XX X oXX XXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXoXoXXoXoXXooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooXXoXXXXoXoXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXXXXoXXXXoXXXoXooXooXoXXXo XoXXXoooXXoXoooXXXXXXXXXXXXXXXXXXXXXXXXXoXXoooXoXXooXoXoooXooXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXoXoXoooXooXooXXXXXXXXXXXXXXXXXXXXXXXXooXoXoooXXXoXXoXoXooXooXXXXXXXXXXXXXXXXXXXXXXoooXoXXXoXoXoXXXoXoXXoXXoXXXXoXoXXXXXXXXXXXXXXXXXXXXXXXXXoXXXooXoXXXXoXXooXooXoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXoXXooXoXXXooXooXXoXooXoXXXoXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXooXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.Xo      ",
"   .XX.oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo.Xo      ",
"   .XX........................................................................................................................................................................................................................................................................................................................................................................................................................................................................Xo      ",
"   .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ",
"                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      "};
