/* XPM */
/* $XConsortium: semilocked.pm /main/2 1996/07/23 12:26:21 drk $ */
static char * pinmid_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"30 17 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s iconGray6	m black	c #636363636363",
"X	s iconGray1	m white	c #dededededede",
"o	s iconGray2	m white	c #bdbdbdbdbdbd",
"O	s iconColor1	m black	c black",
"+	s iconGray7	m black	c #424242424242",
"@	s iconGray4	m white	c #949494949494",
/* pixels */
"                 ....         ",
"                ..XoX.        ",
"       ....     .XoXoX.       ",
"      ..XoX. ....oXoXo.       ",
"      .XoX....oX.XoXoXoO      ",
"      .oXo.oXoXo.oXoXoXO      ",
"      .XoX.XoXoXo+oXoXoO      ",
"      .oXo.oXoXo+@+oXoXO      ",
"       .oXo+o+@+@OOXoXOO      ",
"       +X+X++@++O  OOOO       ",
"     OOO+@+@+@+O              ",
"   OOOO O+@+@+@O              ",
"  OO    O@+@+@+O              ",
"         OO+O+OO              ",
"           OOOO               ",
"                              ",
"                              "};
