/* XPM */
/* $XConsortium: DtABbip.m.pm /main/3 1995/07/18 16:11:31 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtABbip_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O	s iconColor4	m white	c green",
"+    s iconGray1     m white c #dededededede",
"@    s iconGray4     m white c #949494949494",
"#    s iconGray3     m white c #adadadadadad",
"$    s iconGray6     m black c #636363636363",
"%    s iconGray7     m black c #424242424242",
"&    s iconGray5     m black c #737373737373",
"*    s selectColor m white c #737373737373",
"=    s iconGray8     m black c #212121212121",
/* pixels */
"                                ",
".....................           ",
".XXXXXXXXXXXXXXXXXXXo           ",
".XXOXXXXXXXXXXXXXXXXo+++        ",
".XXOO.+X....@X...XXXo@@o        ",
".XXO..@#....$$.#$@XXo@@o        ",
".XXO+.@%XXXX$$+#$@XXo@@o        ",
".XXOO&&O%$$$$@$$$@XXo@@o        ",
".XXO.O#O#.+$@@@@@@XXo@@o        ",
".XXOO.O.O.+$@XXXXXXXo@@o        ",
".XXO.O.O..+$@XXXXXXXo@@o        ",
".XXOO.O@O.+$OXXXXXXXo@@o        ",
".XXO.OO@@.+$#OXXXXXXo@@o        ",
".XXOO.O@X.+$O#OXXXXXo@@o        ",
".XXO.OO@&@&ooO.OXXXXo@@o        ",
".XXOO.O@&@&oo#O.OXXXo@@o        ",
".XXO.OO@&@&ooO.O.OXXo@@o        ",
".XXOO.O@&@&oo@O.O.OXo@@o        ",
".XXO.OO@&@&oo@XO.O.Oo@@o        ",
".XXOO.O@&@&oo@XXO.O.O&@o        ",
".XXO.O.O&@&ooOOOOO.O.O&o        ",
".XXOO.O.&@&oo#O.O.O.O.O&        ",
".XXO.O.O&@&ooO.O.O.O.O.O&       ",
".XXOOOOO&@&oo#OOOOOOOOOOO&      ",
".XXX@@@@&@&oo@@@@@@@o#&#&#&     ",
".XXXXXXX&@&oo@XXXXXXo&O&O&O&    ",
".XXXXXXX&@&oo@XXXXXXo$$o***     ",
".XXXXXXX&@&oo@XXXXXXo@@o        ",
".=======&@&oo=======o@@o        ",
"   +XXXXooooo&oo$@@@@@@o        ",
"   +=======&@&oooooooooo        ",
"           ooooo                "};
