/* XPM */
/* $XConsortium: Dtview.l.pm /main/2 1996/10/29 15:53:22 drk $ */
static char * Dtview_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 8 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconColor2	m white	c white",
"X	s iconGray4	m white	c #949494949494",
"o	s iconGray5	m black	c #737373737373",
"O	s iconColor1	m black	c black",
"+	s iconGray3	m white	c #adadadadadad",
"@	s iconGray2	m white	c #bdbdbdbdbdbd",
"#	s iconGray6	m black	c #636363636363",
/* pixels */
"                                                ",
"                                                ",
" .....................    ..................... ",
" .XoXoXoXoXoXoXoXoXoXo    .XoXoXoXoXoXoXoXoXooo ",
" .oXoXoXoXoXoXoXoXoXoO    .oXoXoXoXoXoXoXoXoXoO ",
" .XoXoXoXoXoXoXoXoXoXO    .XoXoXoXoXoXoXoXoXooO ",
" .oXoXoXoXoXoXoXoXoXoO    .oXoXoXoXoXoXoXoXoXoO ",
" .XoXoXoXoXoXoXoXoXoXO    .XoXoXoXoXoXoXoXoXooO ",
" .oXoXoXoXoXoXoXoXoXoO    .oXoXoXoXoXoXoXoXoXoO ",
" .XoXoXoXoXoXoXoXoXoXO    .XoXoXoXoXoXoXoXoXooO ",
"  .+@@@@@@@@@@@@@@@@OO    .+@@@@@@@@@@@@@@@@#O  ",
"  .+o###############OO    .X#################O  ",
"  .oXoXoXoXoXoXoXoX#OO    .oXoXoXoXoXoXoXoXo#O  ",
"  .XoXoXoXoXoXoXoXo#OO    .XoXoXoXoXoXoXoXoX#O  ",
"  .oXoXoXoXoXoXoXoX#.......oXoXoXoXoXoXoXoXo#O  ",
"  .XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX#O  ",
"  .oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXo#O  ",
"  .XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX#O  ",
"  .oXoXoXoXoXoXoXoX########oXoXoXoXoXoXoXoXo#O  ",
"  .XoXoXoXoXoXoXoXooOOOOOO.XoXoXoXoXoXoXoXoX#O  ",
"  .oXoXoXoXoXoXoXoXoO    @.oXoXoXoXoXoXoXoXo#O  ",
"  .XoXoXoXoXoXoXoXooO    @.XoXoXoXoXoXoXoXoX#O  ",
"  .oXoXoXoXoXoXoXoXoO    @.oXoXoXoXoXoXoXoXo#O  ",
"  .XoXoXoXoXoXoXoXooO    @.XoXoXoXoXoXoXoXoX#O  ",
"  ..+oXoXoXoXoXoXoXoO    @.oXoXoXoXoXoXoXoX#OO  ",
"    .+oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoX#O    ",
"    .+XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXo#O    ",
"    .+oXoXoXoXoXoX##########oXoXoXoXoXoXoX#O    ",
"    .+XoXoXoXoXoXo#OOOOOOOOO.+XoXoXoXoXoXo#O    ",
"    .+oXoXoXoXoXoX#O        .+oXoXoXoXoXoX#O    ",
"    .+XoXoXoXoXoXo#O        .+XoXoXoXoXoXo#O    ",
"    .+oXoXoXoXoXoX#O        .+oXoXoXoXoXoX#O    ",
"    .+XoXoXoXoXoXo#O        .+XoXoXoXoXoXo#O    ",
"    .+oXoXoXoXoXoX#O        .+oXoXoXoXoXoX#O    ",
"    .+XoXoXoXoXoXo#O        .+XoXoXoXoXoXo#O    ",
"    .+oXoXoXoXoXoX#O         .oXoXoXoXoXoX#O    ",
"    .+XoXoXoXoXoX##O         .XoXoXoXoXoXo#O    ",
"    .+oXoXoXoXoXo##O         .oXoXoXoXoXoX#O    ",
"    ..+@@@@@@@@@@#O          .+@@@@@@@@@@#O     ",
"    ..o###########O          .o###########O     ",
"     .XoXoXoXoXoX#O          .XoXoXoXoXoX#O     ",
"     .oXoXoXoXoXo#O          .oXoXoXoXoXo#O     ",
"     .XoXoXoXoXoX#O          .XoXoXoXoXoX#O     ",
"     .oXoXoXoXoXo#O          .oXoXoXoXoXo#O     ",
"     OXoXoXoXoXoX#O          OXoXoXoXoXoX#O     ",
"     OOOOOOOOOOOOOO          OOOOOOOOOOOOOO     ",
"                                                ",
"                                                "};
