/* XPM */
/* $XConsortium: line.pm /main/5 1996/07/23 13:56:24 drk $ */
static char * IEtLine [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 4 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor1	m black	c black",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXoXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXoXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXoXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXoXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXoXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXoXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXoXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXoXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXoXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXoXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXoXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXoXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXoXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXoXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXoXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXoXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXoXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXoXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXoXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXoXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXoXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
