/* XPM */
/* $XConsortium: Dthtop.t.pm /main/3 1995/07/18 16:40:32 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dthtop_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 7 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray7     m black c #424242424242",
"O	s iconColor1	m black	c black",
"+	s iconColor6	m white	c yellow",
"@    s iconGray5     m black c #737373737373",
/* pixels */
"            ....",
" XXXXXXXXXXo....",
" OXXXXXXXXXoO...",
"  XXoXooXoXoO...",
" XXXX++++XXoO...",
" XXX++++++XoO...",
" XXX++XX++XoO...",
" OXX@@X++@XoO...",
"  XXXX++XXXoO...",
" XXXXX++XXXoO...",
" XXXXXXXXXXoO...",
" XXXXX++XXXoO...",
" OXXX@++@@XoO...",
"  XXXXXXXXXoO...",
" oooooooooooO...",
"..OOOOOOOOOOO..."};
