/* XPM */
static char * SDturlweb_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 11 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #bdbdbdbdbdbd",
"o	s iconGray8	m black	c #212121212121",
"O	s iconGray5	m black	c #737373737373",
"+	s iconGray4	m white	c #949494949494",
"@	s iconGray7	m black	c #424242424242",
"#	s iconColor5	m black	c blue",
"$	s iconGray6	m black	c #636363636363",
"%	s iconColor4	m white	c green",
"&	s iconGray3	m white	c #adadadadadad",
/* pixels */
"                                                ",
"         ...................................... ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXOoOXXXOoOoOXXXOoOoOXXXOoOXXXXXXXXXo ",
"         .XXXoXXoXXoXoXXoXXoXoXXoXXoXXXXXXXXXXo ",
"         .XXXoXooXo+XoXooXo+XoXooXo+XXXXXXXXXXo ",
"         .XXXoXooXoXXoXooXoXXoXooXoXXXXXXXXXXXo ",
"         .XXXoo+oo+XXoo+oo+XXoo+oo+XXXXXXXXXXXo ",
"         .XXXooXooXXXooXooXXXooXooXXXXXXXXXXXXo ",
"         .XXXoXXoXXXXoXXoXXXXoXXoXXXXXXXXXXXXXo ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXXXXX@XX#OX###OX####XXXXXXXXXXXXXXXo ",
"         .XXXXXX#@XXXXXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXXXXX@#@XXXXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXXXXX#@#@XXX$$$X$$$$X$$$$$XXXXXXXXXo ",
"         .XXXXXX@#@#@XXXXXXXXXXXXXXXXXXXXXXXXXo ",
"         .XXXXXX#@#@#@XXXXXXXXXXXXXXXXXXXXXXXXo ",
"      ##@#@#@#@#@#@#@#@XXXXXXXXXXXXXXXXXXXXXXXo ",
"    #@#@#@#@#@#@#@#@#@#@XX$$$$X$$X$$$XXXXXXXXXo ",
"   #@#@#@#@#@#@#@#@#@#@#@XXXXXXXXXXXXXXXXXXXXXo ",
"  #@#@#@#@#@#@#@#@#@#@#@XXXXXXXXXXXXXXXXXXXXXXo ",
"  @#@#@#@#@#@#@#@#@#@#@XX$$$X$$XXXXXXXXXXXXXXXo ",
" @#@#@#@#@+XXXXX#@#@#@XXXXXXXXXXXXXXXXXXXXXXXXo ",
" #@#@#@#@.XXXXXX@#@#@XXXXXXXXXXXXXXXXXXXXXXXXXo ",
" @#@#@#@ .XXXXXX#@#@XX$$$$XXXXXXXXXXXXXXXXXXXXo ",
" #@#@#@# .XXXXXX@#@XXXXXXXXXXXXX#####%XXXXXXXXo ",
" @#@#@#@ .XXXXXX#@XXXXXXXXXXXO%####O%O%#%XXXXXo ",
" #@#@#@# .XXXXXX@XXXXXXXXXX#O%O%O%O%O%O%#%OXXXo ",
" @#@#@#@ .XXXXXXXXXXXXXXX##+%+%+%O%O#O%O%O%O%Xo ",
"  @#@#@# .XXXXXXXXXXXXXX#%+%&%&%+%O%#%O%O#O%O%o ",
"  #@#@#@ .XXXXXXXXXXXXX%%+%&%X%&%+%O%O%#####%Oo ",
"   #@#@# .XXXXXXXXXXXX##+%&%X%X%&%O%O%O%O%%#O%o ",
"    #@#@ .XXXXXXXXXXXX#O%&%X%X%&%+%O%O%O%O%#%Oo ",
"     #@# .XXXXXXXXXXX##%+%X%X%&%+%O%O%O%O%O%#%o ",
"      #@ .XXXXXXXXXXX##O%&%X%&%+%O%O%#%O##%O%Oo ",
"       # .XXXXXXXXXX####+%&%+%+%O#%##%O%O####%o ",
"         .XXXXXXXXXX###O%+%+%+%O%#####%#######o ",
"         .XXXXXXXXXX##O#O%+%+%O%O#############o ",
"         .XXXXXXXXX###%#%O%O%O%O%##%##########o ",
"         .XXXXXXXXX####%#%O%O%###########%####o ",
"         .XXXXXXXXX########O%O%######O%O%#####o ",
"         .XXXXXXXXX########%O%#######%O%O#####o ",
"         .XXXXXXXXX######%%#%O######%O%O%O%###o ",
"         .XXXXXXXXX########%O%######O#########o ",
"         .ooooooooooooooooooooooooooooooooooooo ",
"                                                "};
