/* XPM */
/* $XConsortium: minimize.pm /main/2 1996/07/23 13:36:04 drk $ */
static char * MVIctrWmMinz_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"78 43 5 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s topShadowColor	m white	c #bdbdbdbdbdbd",
"X	c #646464646464",
"o	s background	m black	c #949494949494",
"O	s iconColor1	m black	c black",
/* pixels */
"                                                                              ",
"                                                                              ",
"                                                                              ",
"    .......................................................................   ",
"    ......................................................................X   ",
"  o  oooooooooooooooooooooooooooooooooooooooooX.oooooooooooooooooooooooooXX   ",
"    ooooooooooooooooooooooooooooooooooooooooooX.oooooooooooooooooooooooooXX   ",
"   o oooooooooooooooooooooooooooooooooooooooooX.oooooooooooooooooooooooooXX   ",
"  o o ooooooooooooooooooooooooooooooooooooooooX.oooooooooooooooooooooooooXX   ",
"   XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.XXXXXXXXXXXXXXXXXXXXXooooXX   ",
"    .................................................................ooooXX   ",
"  o  ooooooooooooooooooooX.oooooooooooooooooooX.oooooooooooooooooooX.ooooXX   ",
"    o oooooooooooooooooooX.oooooooooooooooooooX.oooooooooooooooooooX.ooooXX   ",
"   o ooooooooooooooooooooX.oooooooooooooooooooX.oooooooooooooooooooX.ooooXX   ",
"  o oooooooooooooooooooooX.oooooooooooooooooooX.ooo.............oooX.ooooXX   ",
"   o ooooooooooooooooooooX.oooooooooooooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"    o oooooooooooooooooooX.oooooooooooooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"  o  ooooooooooooooooooooX.oooooooooooooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"    oooooooooooooooooooooX.ooooooo....ooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"   o ooooooooooooooooooooX.ooooooo.ooXooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"  o o oooooooooooooooooooX.ooooooo.ooXooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"   o ooooooooooooooooooooX.ooooooo.XXXooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"    oooooooooooooooooooooX.oooooooooooooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"  o  ooooooooooooooooooooX.oooooooooooooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"    oooooooooooooooooooooX.ooooooooo oooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"   o ooooooooooooooooooooX.ooooooooo  ooooooooX.ooo.oooooooooooXoooX.ooooXX   ",
"  o o oooooooooooooooooooX.ooooooooo O oooooooX.ooo.XXXXXXXXXXXXoooX.ooooXX   ",
"   o ooooooooooooooooooooX.ooooooooo OO ooooooX.oooooooooooooooooooX.ooooXX   ",
"    oooooooooooooooooooooX.ooooooooo OOO oooooX.oooooooooooooooooooX.ooooXX   ",
"     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX OOOO XXXXX.XXXXXXXXXXXXXXXXXXXX.ooooXX   ",
"    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX OOOOO XXXXXXXXXXXXXXXXXXXXXXXXX.XXXXXX   ",
"    ................................ OOOOOO .............................OX   ",
"     ............................... OOOOOOO ......................O.ooooXX   ",
"   ooooooooooooooooooooooooooooooooo OOOOOOOO ooooooooooooooooooooOO.ooooXX   ",
"    oooooooooooooooooooooooooooooooo OOOOO    ooooooooooooooooooooOO.ooooXX   ",
"   o ooooooooooooooooooooooooooooooo OO OO oooooooooooooooooooooooOO.ooooXX   ",
"   ooooooooooooooooooooooooooooooooo O o OO ooooooooooooooooooooooOO.ooooXX   ",
"    oooooooooooooooooooooooooooooooo  oo OO ooooooooooooooooooooooOO.o o X    ",
"   oo ooooooo ooooooooooooooooooooooooooo OO oooooooooooooooooooooOO. o o O   ",
"     o ooo ooo oo oo o oo o oo o oo ooooo OO ooo o o ooo oo oo oo OO.o o O    ",
"    o o o o  o o o oo oo oo o o oo o  o oo  oo oo o oo oo oo o o o O o  o     ",
"                                                                              ",
"                                                                              "};
