/* XPM */
/* $XConsortium: color.pm /main/2 1996/07/23 13:41:47 drk $ */
static char * ColorOL [] = {
/* width height ncolors cpp [x_hot y_hot] */
"64 37 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o    s iconGray1     m white c #dededededede",
"O    s iconGray3     m white c #adadadadadad",
"+    s iconGray5     m black c #737373737373",
"@	s iconColor3	m black	c red",
"#	s iconColor6	m white	c yellow",
"$    s iconGray8     m black c #212121212121",
"%    s topShadowColor m white c #bdbdbdbdbdbd",
"&	s iconColor4	m white	c green",
"*	s iconColor5	m black	c blue",
"=	s iconColor8	m black	c magenta",
/* pixels */
"                                                                ",
"                                                                ",
"                                                                ",
"                          ............                          ",
"                      .....XXoXoooooo....                       ",
"                    ...XoXooXoXoXXoXooXo...                     ",
"                  ...XoXoXOOOOOOOOOOOoXooo...                   ",
"                ...XXooOOOOOOOOOOOOOOOOOooXo..                  ",
"               ..oXoXOOOOOOOOOOOO++++++OOOOoX..                 ",
"              ..ooOOOOOOO@OOOOOO+######+OOOOXXX.                ",
"             ..oXOOOOO@@@@@@@OO+########$OOOOO+%                ",
"            ..XoOOOO@@@@@@@@@$+#######$$$OOOO+$%                ",
"           ..ooOOOO@@@@@@@@@$$+######$$OOOOO+$%                 ",
"          ..ooOOOOOOO@@@@@@$$OOO$##$$$OOOO+$$%                  ",
"          .XoOOOOOOOOO@@@@@$OOOO$$$$OOOO++$$%                   ",
"         ..oOOOOOOOOOOO$$$$$OOOOOOOOOOO$$$%%                    ",
"         .XoOOOOO+++OOOOOOOOO$$$$$+OOO+$%%                      ",
"         .oOOOO++o&o+OOOOOOO$$    oOO$$%    ....                ",
"         .oOOO+o&o&o&+OOOOOO$     oOO+$%  ..ooX%                ",
"         .oOO+&o&o&o&o$OOOOO$     oOO+o...XoXOO%                ",
"         .oOO+&o&o&o&$$OOOOO+oooooOOOOXooooOOO$%                ",
"         .oOOO+o&o&o$$OOOOOOOOOOOOOO***OOOOOO+%                 ",
"         .XXOOO$$$$$$OOOOOO=OOOOOOO*****$OOO+$%                 ",
"          .oOOOOOOOOOO========OOOO******$OOO$%                  ",
"          .XXOOOOOOOOO=========OO******$OOO+$%                  ",
"           .XXOOOOOOOOOO=======$O*****$OOO$$%                   ",
"             X$$+OOOOOOO$$==$$$$OO$$$OOO$$$%%                   ",
"              %%$$++OOOOOO$$$OOOOOOOOOO$$+%%                    ",
"               %%%$$$+OOOOOOOOOOOOOO$$$++%%                     ",
"                 %%%%$$$+++++++++$+$$++%%%                      ",
"                    %%%%$$$$$$$$+$+++%%%                        ",
"                       %%%%%%%%%%%%%%%                          ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                ",
"                                                                "};
