/* XPM */
/* $XConsortium: Dttrsh.t.pm /main/3 1995/07/18 16:50:05 drk $ */
static char * Fptrsh_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray5     m black c #737373737373",
"O    s iconGray2     m white c #bdbdbdbdbdbd",
"+    s bottomShadowColor m black c #636363636363",
"@    s iconGray3     m white c #adadadadadad",
"#    s iconGray7     m black c #424242424242",
"$    s iconGray4     m white c #949494949494",
"%    s iconGray8     m black c #212121212121",
"&	s iconColor1	m black	c black",
"*    s iconGray6     m black c #636363636363",
/* pixels */
"  .XXXXXXXXXo   ",
"  O.XXXXXXXXX+  ",
"  oO..........  ",
"  Oo.OOOOOOOOo  ",
"  @X##########  ",
"  $@XOOOOOOOOo  ",
"  @$O$$$$$$$$#  ",
"  $@O$$$$$$$$#  ",
"  @$O$$$$$$$$#  ",
"  $@O$$$$$$$$#  ",
"  @$O$$$$$$$$#  ",
"  $@O$$$$$$$$#  ",
"  @$O$$$$$$$$#  ",
"  %@O$$$$$$$$#  ",
"   &O$$XXXXo$#  ",
"    &**&&&&***  "};
