/* XPM */
/* $XConsortium: FpupY.m.pm /main/3 1995/07/18 17:08:16 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Fupon [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 8 4 1 0 0",
/* colors */
"     s background    m black c #949494949494",
".    s bottomShadowColor m black c #636363636363",
"X	s iconColor6	m white	c yellow",
"o    s topShadowColor m white c #bdbdbdbdbdbd",
/* pixels */
"                                ",
"               .                ",
"              .Xo               ",
"             .XXXo              ",
"            .XXXXXo             ",
"           .XXXXXXXo            ",
"          .oooooooooo           ",
"                                "};
