/* XPM */
/* $XConsortium: DtABbil.l.pm /main/2 1996/07/23 11:52:27 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtABbil_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 12 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconGray8	m black	c #323232323232",
"X	s iconGray1	m white	c #e1e1e1e1e1e1",
"o	s iconGray2	m white	c #c8c8c8c8c8c8",
"O	s iconColor2	m white	c white",
"+	s iconColor1	m black	c black",
"@	s iconGray5	m black	c #7d7d7d7d7d7d",
"#	s iconGray3	m white	c #afafafafafaf",
"$	s iconGray4	m white	c #969696969696",
"%	s iconColor7	m white	c cyan",
"&	s iconGray6	m black	c #646464646464",
"*	s iconGray7	m black	c #4b4b4b4b4b4b",
/* pixels */
"                                                ",
"                                                ",
"      ............................              ",
"      .XXXXXXXXXXXXXXXXXXXXXXXXXoO+             ",
"      .XXXXXXXXXXXXXXXXXXXXXXXXXoOX+            ",
"      .XXXXXoooXXooooooXX@@@@XXXoOXX+           ",
"      .XXXXoOoo@XoOXOO#.XoOO@XXXoOOXX+          ",
"      .XXXXoOOo@#oXOXO#++oOO@XXXoOOOXX+         ",
"      .XXXXoOo#@##OXO##++oOo@XXXoOOOOOO.        ",
"      .XXXXoo##@+o#O#$#+$ooo@XXXoo#####.        ",
"      .XXXXX@@@+X++++++##@@@@XXXXXooooo.        ",
"      .XXXXXXO%o+X$$$$##o###XXXXXXXXXXX.        ",
"      .XXXXXXOo%o+$Oo$#oXoooXXXXXXXXXXX.        ",
"      .XXXXXXO%o%o$Oo$#XXXXXXXXXXXXXXXX.        ",
"      .XXXXXXOo%o%$Oo$#XXXXXXXXXXXXXXXX.        ",
"      .XXXXXXO%o%o$Oo$#XXXXXXXXXXXXXXXX.        ",
"      .XXXXXXOo%+%$OX$#XXXXXXXXXXXXXXXX.        ",
"      .XXXXXXO%o++$OX$+XXXXXXXXXXXXXXXX.        ",
"      .XXXXXXOo%+X$OX$$+XXXXXXXXXXXXXXX.        ",
"      .XXXXXXO%o+X$OX$%$+XXXXXXXXXXXXXX.        ",
"      .XXXXXXOo%+++++++%$+XXXXXXXXXXXXX.        ",
"      .XXXXXXO%o+$$$++++%$+XXXXXXXXXXXX.        ",
"      .XXXXXXOo%++$+++@+$%o+XXXXXXXXXXX.        ",
"      .XXXXXXO%o+$$$++++%$%o+XXXXXXXXXX.        ",
"      .XXXXXXOo%++$+++@+$%o%o+XXXXXXXXX.        ",
"      .XXXXXXO%%+$$$+++++$%o%o+XXXXXXXX.        ",
"      .XXXXXXO%o++$+++@+#+o%o%o+XXXXXXX.        ",
"      .XXXXXXOo%+$$$++++#o+o%o%o+XXXXXX.        ",
"      .XXXXXXO%o++$+++@+#oX+o%o%o+XXXXX.        ",
"      .XXXXXXOo%+$$$+++++OOOOo%o%o+XXXX.        ",
"      .XXXXXXO%o++$+++@+$%$%o%o%o%o+XXX.        ",
"      .XXXXXXOo%+$$$++++%$%o%o%o%o%o+XX.        ",
"      .XXXXXXO%o++$+++@+$%$%o%o%o%o%o+X.        ",
"      .XXXXXXO&&+$$$++++&&&&&&&&&&&&&&&.        ",
"      .XXXXXXXXX++$+++@+###############.        ",
"      .XXXXXXXXX+$$$++++#oXXXXXXXXXXXXX.        ",
"      .XXXXXXXXX++$+++@+#oXXXXXXXXXXXXX.        ",
"      ..........+$$$+*++................        ",
"                ++$+++@+                        ",
"                +$$$++++                        ",
"                ++$+++@+                        ",
"                +$$$++++                        ",
"                ++++++++                        ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                "};
