/* XPM */
/* $XConsortium: Dtterm.m.pm /main/3 1995/07/18 16:49:22 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

/* Designed by the User Interaction Design Group, Hewlett-Packard */
static char *terminal32[]={
/* width height ncolors cpp [x_hot y_hot] */
"32 32 21 1 0 0",
/* colors */
"  c none m none s none",
"$    s topShadowColor m white c #bdbdbdbdbdbd",
"&    s background    m black c #949494949494",
"(    s selectColor m white c #737373737373",
"*    s bottomShadowColor m black c #636363636363",
". s iconColor1 c black     m black",
"B s iconColor2 c white     m white",
"4 s iconColor3 c red       m black",
"6 s iconColor4 c green     m white",
"8 s iconColor5 c blue      m black",
"2 s iconColor6 c yellow    m white",
": s iconColor7 c cyan      m white",
"0 s iconColor8 c magenta   m black",
"<    s iconGray1     m white c #dededededede",
">    s iconGray2     m white c #bdbdbdbdbdbd",
"@    s iconGray3     m white c #adadadadadad",
"D    s iconGray4     m white c #949494949494",
"F    s iconGray5     m black c #737373737373",
"H    s iconGray6     m black c #636363636363",
"J    s iconGray7     m black c #424242424242",
"L    s iconGray8     m black c #212121212121",
/* pixels */
"                                ",
"                                ",
"                                ",
"       <<<<<<<<<<<<<<<<<        ",
"      BBBBBBBBBBBBBBBBBBBL      ",
"     B>>>>>>>>>>>>>>>>>>>>L     ",
"     B>HHHHHHHHHHHHHHHHHH>L     ",
"     B>HLLLLLLLLLLLLLLLLB>L     ",
"     B>HLJJJJJJJJJJJJJJLB>L     ",
"     B>HLJ<J<J<J<JJJJJJLB>L     ",
"     B>HLJJJJJJJJJJJJJJLB>L     ",
"     B>HLJD<J<JD<J<JJJJLB>L     ",
"     B>HLJJJJJJJJJJJJJJLB>L     ",
"     B>HLJ<D<J<J<DJJJJJLB>L     ",
"     B>HLJJJJJJJJJJJJJJLB>L     ",
"     B>HLJJJJJJJJJJJJJJLB>L     ",
"     B>HLJJJJJJJJJJJJJJLB>L     ",
"     B>HLLLLLLLLLLLLLLLLB>L     ",
"     B>HBBBBBBBBBBBBBBBBB>L     ",
"     B>>>>>>>>>>>>>>>>>>>>L     ",
"      LLLLLLLLLLLLLLLLLLLL      ",
"         LLHHHHHHHHHHLL         ",
"         LLLFFFFFFFFLLL         ",
"    FFFFFFFFFFFFFFFFFFFFFFFFL   ",
"   BBBFBFBFBFBFBFBFBFBBFBFBFBL  ",
"  BBBFBFBFBFBFBFBFBFBFBBFBFBBBL ",
" BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBL",
" DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDL",
" LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL",
"                                ",
"                                ",
"                                "
};
