/* XPM */
/* $XConsortium: DtABdrw.pm /main/3 1995/07/18 17:08:56 drk $ */
static char * DtABdrw_x_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 32 13 1 0 0",
/* colors */
"     s iconGray1     m white c #dededededede",
".	s iconColor1	m black	c black",
"X    s iconGray4     m white c #949494949494",
"o    s iconGray3     m white c #adadadadadad",
"O    s iconGray6     m black c #636363636363",
"+	s iconColor6	m white	c yellow",
"@    s iconGray2     m white c #bdbdbdbdbdbd",
"#    s iconGray3     m white c #adadadadadad",
"$    s iconGray5     m black c #737373737373",
"%	s iconColor5	m black	c blue",
"&    s iconGray4     m white c #949494949494",
"*	s iconColor3	m black	c red",
"=    s iconGray1     m white c #dededededede",
/* pixels */
"                                               .",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.",
" X.........................................XXXX.",
" X.ooooooooooooooooooooooooooooooooooooooo XOOX.",
" X.oooooooooo.............oooooooooooooooo XOOX.",
" X.oooooooooo.+++++++++++.oooooooooooooooo XOOX.",
" X.oooooooooo.+++++++++++.oooooooooooooooo X@@X.",
" X.oooooooooo.+++++++++++.o#oooooooooooooo X@XX.",
" X.oooooooooo.+++++++++++.oooooooooooooooo X@XX.",
" X.oooooooooo.+++++++++++.oooooooooooooooo X@XX.",
" X.oooooo.......+++++++++.ooo.oooooooooooo X@XX.",
" X.ooooo.$%&%&%$.++++++++.oo.@.ooooooooooo X@XX.",
" X.oooo.$%@%&%o%$.+++++++.o.@*@.oooooooooo X@XX.",
" X.ooo.$%@%=%@%o%$.++++++..@*@*@.ooooooooo X@XX.",
" X.ooo.%&%=%=%o%$%.++++++.@*@*@*@.oooooooo X@XX.",
" X.ooo.$%@%=%@%o%$.+++++.@*@*@*@*@.ooooooo X@XX.",
" X.ooo.%&%@%@%o%$%.++++.@*@*@*@*@*@.oooooo XOOX.",
" X.ooo.$%o%o%o%&%$.+++.@*@*@*@*@*@*@.ooooo XOOX.",
" X.ooo.%$%&%&%&%&%.++.@*@*@*@*@*@*@*@.oooo XOOX.",
" X.ooo.$%o%o%&%$%$.+.@*@*@*@*@*@*@*@*@.ooo XOOX.",
" X.oooo.$%$%$%$%$.+.....................oo XOOX.",
" X.ooooo.$%$%$%$.++++++++.oooooooooooooooo XOOX.",
" X.oooooo.......+++++++++.oooooooooooooooo XOOX.",
" X.oooooooooo.+++++++++++.oooooooooooooooo XOOX.",
" X.oooooooooo.............oooooooooooooooo XOOX.",
" X.ooooooooooooooooooooooooooooooooooooooo XOOX.",
" X.                                        XOOX.",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.",
" XOOOOOOOOOOO@@@@@@@@@@@@@@@@@@@@OOOOOOOOOOXXXX.",
" XOOOOOOOOOOO@XXXXXXXXXXXXXXXXXXXOOOOOOOOOOXXXX.",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.",
" ..............................................."};
