/* XPM */
/* $XConsortium: DtABbrw.t.pm /main/2 1996/07/23 11:53:57 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * DtABbrw_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 11 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconGray2	m white	c #c8c8c8c8c8c8",
"o	s iconColor4	m white	c green",
"O	s iconColor1	m black	c black",
"+	s iconColor5	m black	c blue",
"@	s iconColor7	m white	c cyan",
"#	s iconGray1	m white	c #e1e1e1e1e1e1",
"$	s iconGray6	m black	c #646464646464",
"%	s iconGray5	m black	c #7d7d7d7d7d7d",
"&	s iconGray4	m white	c #969696969696",
/* pixels */
"                ",
"...........     ",
".XoXXXXXXXO     ",
".Xoo....XXO     ",
".Xo.+@@@.XO     ",
".X.+@@@@@.O     ",
".X.+@@@@@.O     ",
".X.#@@.@@.O     ",
".Xo.+@@@.$O     ",
".Xoo%...oOO     ",
".XooXXXXOOO     ",
".XoooooooO&O    ",
".XooooooooO&O   ",
".XXXXXXXXXOO&O  ",
".OOOOOOOOOO O&O ",
"             OO "};
