/* XPM */
/* $XConsortium: mminicon.pm /main/5 1996/10/29 15:55:23 drk $ */
static char * mminicon_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"50 180 29 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	c #B3B3CECED9D9",
"X	c #55559292AAAA",
"o	c #2A2A49495555",
"O	c #4B4B4B4B4B4B",
"+	s iconColor5	m black	c blue",
"@	c #C8C8C8C8C8C8",
"#	s iconColor3	m black	c red",
"$	s iconColor8	m black	c magenta",
"%	s iconColor4	m white	c green",
"&	s iconColor7	m white	c cyan",
"*	c #E1E1E1E1E1E1",
"=	c #AFAFAFAFAFAF",
"-	c #323232323232",
";	s iconColor6	m white	c yellow",
":	c #48487C7C9191",
">	c #646464646464",
",	c #E0E0E0E0E0E0",
"<	c #AEAEAEAEAEAE",
"1	c #F9F9F9F9F9F9",
"2	c #C7C7C7C7C7C7",
"3	c #FFFF0000ABAB",
"4	s iconColor1	m black	c black",
"5	c #FFFF00000202",
"6	c #959595959595",
"7	c #7D7D7D7D7D7D",
"8	c #04040000FFFF",
"9	c #0909FFFF0101",
"0	c #969696969696",
/* pixels */
"                                                  ",
" ............................................     ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..Xo......................................XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXX OXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXX  + OXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXX ++++ OXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXX  +++   @OXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXX +  @@@@@@@OXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXX   @@@@@@@@@OXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXX @@@@@@@@@@@OXXXXXXXXo.XX     ",
" ..Xo.XXoooooooooo  @@@@@@@@@@@@@XXXXXXXXo.XX     ",
" ..Xo.XXoooooooo   @@@@@@@@@@@@@@XXXXXXXXo.XX     ",
" ..Xo.XXoo ##### $$$$$ %%%%% &&&&@XXXXXXXo.XX     ",
" ..Xo.XXo ##### $$$$$ %%%%% &&&&&&XXXXXXXo.XX     ",
" ..Xo.XXo****************************XXXXo.XX     ",
" ..Xo.XXo*==========================-XXXXo.XX     ",
" ..Xo.XXo*==========================-XXXXo.XX     ",
" ..Xo.XXo*======== ;#;#;;##; =======-:XXXo.XX     ",
" ..Xo.XXo*======== #;#;##;;# =======-::XXo.XX     ",
" ..Xo.XXo*======== ;#;#;;##; =======-::XXo.XX     ",
" ..Xo.XXo*======== --------- =======-o:XXo.XX     ",
" ..Xo.XXo*======== ->>>>>>>> =======-ooXXo.XX     ",
" ..Xo.XXo*========           =======-ooXXo.XX     ",
" ..Xo.XXo*=========>>>>>>>>>>=======-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XXo*==========================-ooXXo.XX     ",
" ..Xo.XX.*==========================-ooXXo.XX     ",
" ..Xo.XXX*==========================-ooXXo.XX     ",
" ..Xo.XXX*==========================-ooXXo.XX     ",
" ..Xo.XXX*---------------------------ooXXo.XX     ",
" ..Xo.XXXXXXX:oooooooooooooooooooooooooXXo.XX     ",
" ..Xo.XXXXXXXX:ooooooooooooooooooooooooXXo.XX     ",
" ..Xo.XXXXXXXX:::::::::::::::::::::::::XXo.XX     ",
" ..Xo.oooooooooooooooooooooooooooooooooooo.XX     ",
" ..Xo......................................XX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXX XXXX XXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXX XXXX XXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXX XX  XX  XX XXXX XXXXXXXXX XX  XXXXXX     ",
" ..XXXXX XX  X   XX XXXX XXXX    X XX  XXXXXX     ",
" ..XXXXX XX   X  XX XXXX XXXXXXXXX XX  XXXXXX     ",
" ..XXXXX    XX    XX  XX   XX          XXXXXX     ",
" ..XXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..oooooooooooooooooooooooooooooooooooooooooo     ",
"                                                  ",
"                                                  ",
"                                                  ",
"                                                  ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..Xo......................................XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXoooooooooooooooooooooooooooXXXXo.XX     ",
" ..Xo.XXXXo,<<<<<<<<<<<<==========*O.XXXXo.XX     ",
" ..Xo.XXXXo,<<<<<<<<<<<<======* 11111*@XXo.XX     ",
" ..Xo.XXXXo,<<<<<<<<<O*<===112222$$3O221:o.XX     ",
" ..Xo.XXXXo,<<<<<<<<<O*<==1@2;;;;33$O224:o.XX     ",
" ..Xo.XXXXo,<<<<<<<<<O*<==@22;;;52OO2224:o.XX     ",
" ..Xo.X     O<<,OOOO<O*<1@222;55264422@:Xo.XX     ",
" ..Xo.XOOOO@ O<<<<<<<O*<12552222247@2@4XXo.XX     ",
" ..Xo.XXXXo77O<<<<<<<O*<125541888222222O:o.XX     ",
" ..Xo.XXXXo @OOOOOOOOO*O124428888289892O:o.XX     ",
" ..Xo.XXXXo777@@@@@@@@@@>@@@@+++82989@@4:o.XX     ",
" ..Xo.XX*,,,,,,**000000000-4@@@@228O2@-:Xo.XX     ",
" ..Xo.XX@@@@@@@@@006666600044=@@@22@7-:XXo.XX     ",
" ..Xo.X**<>*===<>=O>001111111117777OX:XXXo.XX     ",
" ..Xo.X**=>*====>=O>001144144114000O.XXXXo.XX     ",
" ..Xo.X**<>*<<=<>=O>001477147714700O.XXXXo.XX     ",
" ..Xo.X*77=77777@=O>004400140044700O.XXXXo.XX     ",
" ..Xo.X*@@@@@@@@@<O>000700140007700O.XXXXo.XX     ",
" ..Xo.X********,*<O-OOOOOO14O441144O.XXXXo.XX     ",
" ..Xo.X**********<Oo......14.4.11.4..XXXXo.XX     ",
" ..Xo.X*22@2@2@2@<OoXXXXXX14:::11:::XXXXXo.XX     ",
" ..Xo.X*@@<@<@<@<6OoXXXXXX14:XX11:11111XXo.XX     ",
" ..Xo.X*<<6<6<6<67OoXXXXXX14:XX11:44144XXo.XX     ",
" ..Xo.X*0666666660OoXXXX11111XX11:XX14:XXo.XX     ",
" ..Xo.X*0666666670OoXXXX44444:1114XX14:XXo.XX     ",
" ..Xo.X*7777777777OoXXXXXXXXXXX:::XX444XXo.XX     ",
" ..Xo.XX777777777-ooXXXXXXXXXXXXXXXXX::XXo.XX     ",
" ..Xo.XXXooooooooo::XXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXX::::::::::XXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.oooooooooooooooooooooooooooooooooooo.XX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" .ooooooooooooooooooooooooooooooooooooooooooo     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXX   XXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXX   X  XXXXXXXXXX XXXXXXXXXXXXXXX     ",
" ..XXXXXXXXX  X     X     XXX XXX   XXXXXXXXX     ",
" ..XXXXXXXXX  XXX  XXX XX XXX XXXXXX XXXXXXXX     ",
" ..XXXXXXXXX X  X  XXXX  XXXX XXXXXXXXXXXXXXX     ",
" ..XXXXXXXXX X  X  X XX XXXXX XXX XX XXXXXXXX     ",
" ..XXXXXXXXX   XXX  XXXXXXX     X   XXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXX   XXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..oooooooooooooooooooooooooooooooooooooooooo     ",
" .ooooooooooooooooooooooooooooooooooooooooooo     ",
"                                                  ",
"                                                  ",
"                                                  ",
" ............................................     ",
" ............................................     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XoooooooooooooooooooooooooooooooooooooooXX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo.XX     ",
" ..Xo.XXXooooooooooooooooooooooooXXXXXXXXo.XX     ",
" ..Xo.XXX                       .XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *****=*>**=***=******-.XXXXXXXXo.XX     ",
" ..Xo.XXX *****->>*->=->=>*****-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *****=**=***==*******-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX *********************-.XXXXXXXXo.XX     ",
" ..Xo.XXX ****>=****-*7********-.XXXXXXXXo.XX     ",
" ..Xo.XXX ****=>=-*-=-7********-.XXXXXXXXo.XX     ",
" ..Xo.XXX ***********O44==*****-.XXXXXXXXo.XX     ",
" ..Xo.XXX ***********O=4;;=****-.XXXXXXXXo.XX     ",
" ..Xo.XXX ***********O>=*;@=***-.XXXXXXXXo.XX     ",
" ..Xo.XXX ************>>**;@=**-.XXXXXXXXo.XX     ",
" ..Xo.XXX ************OO=*;;@**-.XXXXXXXXo.XX     ",
" ..Xo.XXX ************@=OO=**;@=.XXXXXXXXo.XX     ",
" ..Xo.XXX *************@=O>=*;;@=XXXXXXXXo.XX     ",
" ..Xo.XXX **************==>>=*;;@XXXXXXXXo.XX     ",
" ..Xo.XXX **************@=OO>**;;=XXXXXXXo.XX     ",
" ..Xo.XXX ***************@=OO=**;@XXXXXXXo.XX     ",
" ..Xo.XXX *****************@=OO>=*;@=XXXXo.XX     ",
" ..Xo.XXX ******************@=OO>*00=@XXXo.XX     ",
" ..Xo.XXX *******************==O>=**OO0XXo.XX     ",
" ..Xo.XXX *******************@=-O>*O*OOXXo.XX     ",
" ..Xo.XXX ********************@-XO>>O**XXo.XX     ",
" ..Xo.XXX........................:OO>0$OXo.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXX::oOOO::o.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXX::OOO::o.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXX:::::::o.XX     ",
" ..Xo.XXXXXXXXXXXXXXXXXXXXXXXXXXXXX:::::Xo.XX     ",
" ..Xo.oooooooooooooooooooooooooooooooooooo.XX     ",
" ..Xo......................................XX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXX  XXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXX X  XX XX    XXXXXX     X    X    XXXX     ",
" ..XXXX X         XX XXXXXX  XXXX  XXX XXXXXX     ",
" ..XXXX   X  X    XX XXXXXX  XXXX  XXX XXXXXX     ",
" ..XXXX X X  X    XX XXXXXX  XXXX  XXX XXXXXX     ",
" ..XXXX XX   X    XX XXX XX  XX X   XX XX XXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ",
" ..oooooooooooooooooooooooooooooooooooooooooo     ",
" .ooooooooooooooooooooooooooooooooooooooooooo     ",
"                                                  ",
"                                                  ",
"                                                  "};
