/* XPM */
/* $XConsortium: Fppenpd.l.pm /main/3 1995/07/18 17:00:46 drk $ */
static char * Fppenpd_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 16 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X	s iconColor2	m white	c white",
"o    s topShadowColor m white c #bdbdbdbdbdbd",
"O    s iconGray1     m white c #dededededede",
"+    s iconGray8     m black c #212121212121",
"@    s iconGray3     m white c #adadadadadad",
"#    s iconGray6     m black c #636363636363",
"$    s iconGray5     m black c #737373737373",
"%    s iconGray7     m black c #424242424242",
"&	s iconColor1	m black	c black",
"*	s iconColor6	m white	c yellow",
"=    s iconGray2     m white c #bdbdbdbdbdbd",
"-    s iconGray4     m white c #949494949494",
";	s iconColor8	m black	c magenta",
":    s selectColor m white c #737373737373",
/* pixels */
"                                                ",
"                                                ",
"     ..............................             ",
"     .XXXXXXXXXXXXXXXXXXXXXXXXXXXXo             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOOO@O@O#OOOO@OOO#@OOOOOOOO+o             ",
"     .XOO+#O+##O++O#@+##@#OOOOOOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOO@OO@OO@OOOOO@@OOOOOOOOOO+o             ",
"     .XOO#+++OO#OO+OO+@#+OO#++OOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOOO+o             ",
"     .XOO#@#@OOOO+O+O$OOOOOOOOOOO+o             ",
"     .XOO+@@#@+O+@$@+$OOOOOOOOOOO+o             ",
"     .XOOOOOOOOOOOO%+$$@OOOOOOOOO+o             ",
"     .XOOOOOOOOOOOOO%&&&@@OOOOOOO+o             ",
"     .XOOOOOOOOOOOOO%&&&@@@OOOOOO+o             ",
"     .XOOOOOOOOOOOOO%@&O**=@OOOOO+o             ",
"     .XOOOOOOOOOOOOO%#@@O**=@OOOO+o             ",
"     .XOOOOOOOOOOOOOO##@OO**=@OOO+o             ",
"     .XOOOOOOOOOOOOOO%%#@OO**=@OO+o             ",
"     .XOOOOOOOOOOOOOO@%%#@OO**=@O+o             ",
"     .XOOOOOOOOOOOOOO@@%##@OO**=@+o             ",
"     .XOOOOOOOOOOOOOO=@@%%#@OO**=@o             ",
"     .XOOOOOOOOOOOOOOO=@@%%#@OO**=@             ",
"     .XOOOOOOOOOOOOOOOO=@@%%#@OO**=@            ",
"     .XOOOOOOOOOOOOOOOOO=@@%%#@OO**=@           ",
"     .XOOOOOOOOOOOOOOOOOO=@@%%#@OO**=@          ",
"     .XOOOOOOOOOOOOOOOOOOO=@@%##@OO**=@         ",
"     .XOOOOOOOOOOOOOOOOOOOO=@@%%#@OO**=@        ",
"     .XOOOOOOOOOOOOOOOOOOOOO=@@%%#@OO--@=       ",
"     .XOOOOOOOOOOOOOOOOOOOOOO=@@%##@-OO%%-      ",
"     .XOOOOOOOOOOOOOOOOOOOOOOO=@+%##@O%O%%=     ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOO=+ %%%##%OO;%    ",
"     .XOOOOOOOOOOOOOOOOOOOOOOOOO+ ::%%#-O;-%    ",
"     .X++++++++++++++++++++++++++ ::%%%-;-;%    ",
"     .oooooooooooooooooooooooooooo:::%%#-;%%%   ",
"                                   :::.%%%%.::  ",
"                                    :::%%%%:::  ",
"                                     :::::::::  ",
"                                      :::::::   ",
"                                        : :     ",
"                                                ",
"                                                "};
