/* XPM */
/* $XConsortium: Dtaexfl.t.pm /main/2 1996/07/23 12:02:41 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtaexfl_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 11 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s background	m black	c #969696969696",
"X	s iconGray2	m white	c #c8c8c8c8c8c8",
"o	s iconColor1	m black	c black",
"O	s iconGray6	m black	c #646464646464",
"+	s iconGray7	m black	c #4b4b4b4b4b4b",
"@	s iconColor6	m white	c yellow",
"#	s iconGray1	m white	c #e1e1e1e1e1e1",
"$	s iconColor5	m black	c blue",
"%	s iconGray5	m black	c #7d7d7d7d7d7d",
"&	s iconGray4	m white	c #969696969696",
/* pixels */
"            ....",
" XXXXXXXXXXo....",
" XOOoo+oXoXo....",
" XXXXXXXXXXo....",
" XOOX+oo+oXo....",
" XXXXXXXXXXo....",
" XOX+X+oXoXo....",
" XXXXXXXXXXo....",
" XOOo+oo+oXo....",
" XXXXXXXXXXo....",
" X              ",
" X @#++$$$$$#%#o",
" X ooooooooooooo",
" XX&&&&&&&&&....",
" XXXXXXXXXXo....",
" ooooooooooo...."};
