/* XPM */
/* $XConsortium: DtBkdrp.pm /main/3 1995/07/18 16:17:22 drk $ */
static char * DtBkdrp_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"60 37 6 1 0 0",
/* colors */
"     s bottomShadowColor m black c #636363636363",
".    s iconGray1     m white c #dededededede",
"X    s topShadowColor m white c #bdbdbdbdbdbd",
"o    s iconGray3     m white c #adadadadadad",
"O    s iconGray8     m black c #212121212121",
"+    s iconGray5     m black c #737373737373",
/* pixels */
"                                                            ",
" ..........................................................X",
" .ooooooooooooooooooooooooooooO+++...ooooOOO++++...ooooOOOOX",
" ..........................oooO++...ooooOOO++++...ooooOOO+OX",
" .ooooooooooooooooooooooooOoooO+...ooooOOO++++...ooooOOO++OX",
" .ooooooooooooooooooooooooOoooO...ooooOOO++++...ooooOOO+++OX",
" .ooooooooooooooooooooooooOoooO..ooooOOO++++...ooooOOO++++OX",
" ......................oooOoooO.ooooOOO++++...ooooOOO++++.OX",
" .ooooooooooooooooooooOoooOoooOooooOOO++++...ooooOOO++++..OX",
" .ooooooooooooooooooooOoooOoooOoooOOO++++...ooooOOO++++...OX",
" .ooooooooooooooooooooOoooOoooOooOOO++++...ooooOOO++++...oOX",
" ..................oooOoooOoooOoOOO++++...ooooOOO++++...ooOX",
" .ooooooooooooooooOoooOoooOoooOOOO++++...ooooOOO++++...oooOX",
" .ooooooooooooooooOoooOoooOoooOOO++++...ooooOOO++++...ooooOX",
" .ooooooooooooooooOoooOoooOoooOO++++...ooooOOO++++...ooooOOX",
" ..............oooOoooOoooOoooO++++...ooooOOO++++...ooooOOOX",
" .ooooooooooooOoooOoooOoooOoooO+++...ooooOOO++++...ooooOO+OX",
" .ooooooooooooOoooOoooOoooOoooO++...ooooOOO++++...ooooOO++OX",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
" .ooooooooooooooooooooooooooooO...OOO...OOO...OOO...OOO...OX",
" ....oo......oo......oo......oOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .OOOoo.OOOOOoo.OOOOOoo.OOOOOoO...OOO...OOO...OOO...OOO...OX",
" .ooooo.Ooooooo.Ooooooo.OoooooOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .ooooo.Ooooooo.Ooooooo.OoooooO...OOO...OOO...OOO...OOO...OX",
" .ooooo.Ooooooo.Ooooooo.OoooooOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .ooooo.Ooooooo.Ooooooo.OoooooO...OOO...OOO...OOO...OOO...OX",
" .ooooooooooooooooooooooooooooOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .ooooooooooooooooooooooooooooO...OOO...OOO...OOO...OOO...OX",
" ....oo......oo......oo......oOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .OOOoo.OOOOOoo.OOOOOoo.OOOOOoO...OOO...OOO...OOO...OOO...OX",
" .ooooo.Ooooooo.Ooooooo.OoooooOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .ooooo.Ooooooo.Ooooooo.OoooooO...OOO...OOO...OOO...OOO...OX",
" .ooooo.Ooooooo.Ooooooo.OoooooOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .ooooo.Ooooooo.Ooooooo.OoooooO...OOO...OOO...OOO...OOo...OX",
" .ooooooooooooooooooooooooooooOo.ooOoo.ooOoo.ooOoo.ooOoo.oOX",
" .OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"};
