/* XPM */
/* $XConsortium: backdrop.pm /main/5 1996/07/23 14:06:32 drk $ */
static char * Backdrop [] = {
/* width height ncolors cpp [x_hot y_hot] */
"64 37 7 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s bottomShadowColor	m black	c #646464646464",
"X	s iconGray1	m white	c #e1e1e1e1e1e1",
"o	s topShadowColor	m white	c #c8c8c8c8c8c8",
"O	s iconGray3	m white	c #afafafafafaf",
"+	s iconGray8	m black	c #323232323232",
"@	s iconGray5	m black	c #7d7d7d7d7d7d",
/* pixels */
"  ............................................................  ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOOOOOO+@@@XXXOOOO+++@@@@XXXOOOO++++o  ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXOOO+@@XXXOOOO+++@@@@XXXOOOO+++@+o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOO+OOO+@XXXOOOO+++@@@@XXXOOOO+++@@+o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOO+OOO+XXXOOOO+++@@@@XXXOOOO+++@@@+o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOO+OOO+XXOOOO+++@@@@XXXOOOO+++@@@@+o  ",
"  .XXXXXXXXXXXXXXXXXXXXXXOOO+OOO+XOOOO+++@@@@XXXOOOO+++@@@@X+o  ",
"  .XOOOOOOOOOOOOOOOOOOOO+OOO+OOO+OOOO+++@@@@XXXOOOO+++@@@@XX+o  ",
"  .XOOOOOOOOOOOOOOOOOOOO+OOO+OOO+OOO+++@@@@XXXOOOO+++@@@@XXX+o  ",
"  .XOOOOOOOOOOOOOOOOOOOO+OOO+OOO+OO+++@@@@XXXOOOO+++@@@@XXXO+o  ",
"  .XXXXXXXXXXXXXXXXXXOOO+OOO+OOO+O+++@@@@XXXOOOO+++@@@@XXXOO+o  ",
"  .XOOOOOOOOOOOOOOOO+OOO+OOO+OOO++++@@@@XXXOOOO+++@@@@XXXOOO+o  ",
"  .XOOOOOOOOOOOOOOOO+OOO+OOO+OOO+++@@@@XXXOOOO+++@@@@XXXOOOO+o  ",
"  .XOOOOOOOOOOOOOOOO+OOO+OOO+OOO++@@@@XXXOOOO+++@@@@XXXOOOO++o  ",
"  .XXXXXXXXXXXXXXOOO+OOO+OOO+OOO+@@@@XXXOOOO+++@@@@XXXOOOO+++o  ",
"  .XOOOOOOOOOOOO+OOO+OOO+OOO+OOO+@@@XXXOOOO+++@@@@XXXOOOO++@+o  ",
"  .XOOOOOOOOOOOO+OOO+OOO+OOO+OOO+@@XXXOOOO+++@@@@XXXOOOO++@@+o  ",
"  .X+++++++++++++++++++++++++++++++++++++++++++++++++++++++++o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOOOOOO+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XXXXOOXXXXXXOOXXXXXXOOXXXXXXO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .X+++OOX+++++OOX+++++OOX+++++O+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOOOOOO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOOOOOO+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XXXXOOXXXXXXOOXXXXXXOOXXXXXXO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .X+++OOX+++++OOX+++++OOX+++++O+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+XXX+++XXX+++XXX+++XXX+++XXX+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .XOOOOOX+OOOOOOX+OOOOOOX+OOOOO+XXX+++XXX+++XXX+++XXX++OXXX+o  ",
"  .XOOOOOOOOOOOOOOOOOOOOOOOOOOOO+OXOO+OOXOO+OOXOO+OOXOO+OOXO+o  ",
"  .X+++++++++++++++++++++++++++++++++++++++++++++++++++++++++o  ",
"  .ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo  "};
