/* XPM */
/* $XConsortium: Dtinfo.m.pm /main/3 1996/07/23 12:14:15 drk $ */
static char * Dtinfo_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 11 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconGray6	m black	c #636363636363",
"o	s iconColor5	m black	c blue",
"O	s iconGray1	m white	c #dededededede",
"+	s iconGray7	m black	c #424242424242",
"@	s iconGray2	m white	c #bdbdbdbdbdbd",
"#	s iconGray4	m white	c #949494949494",
"$	s iconGray5	m black	c #737373737373",
"%	s iconGray8	m black	c #212121212121",
"&	s iconGray3	m white	c #adadadadadad",
/* pixels */
"           ........             ",
"         ..XoXoXoXoOO           ",
"        .oXoXoXoXoXoXO          ",
"       .oXoXoX..oXoXoXO         ",
"      .oXoXoX....oXoXoX+        ",
"     .oXoXoXo....XoXoXoX+       ",
"     .XoXoXoXo..ooXoXoXo+       ",
"    .XoXoXoXoXoXoXoXoXoXo+      ",
"  .@.oXoXoXoX...XoXoXoXoX+#.$   ",
" O.@.XoXoXoX.....XoXoXoXo+#O++  ",
"@..@.oXoXoX......oXoXoXoX+#O+$% ",
"@O.@.XoXoXoXo....XoXoXoXo+#O+$% ",
"@..@.oXoXoXoX....oXoXoXoX+#O+$% ",
"@O.@.XoXoXoXo....XoXoXoXo+#O+$% ",
"@..O&.XoXoXoX....oXoXoXo+#OO+$% ",
"@O.O&.oXoXoXo......XoXoX+#OO+$% ",
"@..OO&.oXoXoX.....XoXoX+#OOO+$% ",
"@O.OOX&.oXoXoX...XoXoX+#XXOO+$% ",
"@..OOOO&+oXoXoXoXoXoX+#OOOOO+$% ",
"@O.OOXXO&+oXoXoXoXo++#XXXXOO+$% ",
"@..OOOOOO&+++++++++##OOOOOOO+$% ",
"@O.OOXXOXX#########XOXXXXXOO+$% ",
"@..OOOOOOOOOOO@#@OOOOOOOOOOO+$% ",
"@O.OOXXOXXXXXO@#@OXXOXXXXXOO+$% ",
"@..OOOOOOOOOOO@#@OOOOOOOOOOO+$% ",
"@O.OOXXOXXXXXO@#@OXXOXXXXXOO+$% ",
"@..OOOOOOOOOOO@#@OOOOOOOOOOO+$% ",
"@O.OOOOOOOOOOO@#@OOOOOOOOOOO+$% ",
"@.$%%%%%%%%%%%@#@++++++++++++$% ",
"@$$$$$$$$$$$$$%#%$$$$$$$$$$$$$% ",
"$%%%%%%%%%%%%%$%$%%%%%%%%%%%%%% ",
"              %%%               "};
