/* XPM */
/* $XConsortium: ellipse.pm /main/5 1996/07/23 13:55:05 drk $ */
static char * IEtEllip [] = {
/* width height ncolors cpp [x_hot y_hot] */
"36 36 4 1 0 0",
/* colors */
"     s iconGray2     m white c #bdbdbdbdbdbd",
".    s iconGray4     m white c #949494949494",
"X    s iconGray3     m white c #adadadadadad",
"o	s iconColor1	m black	c black",
/* pixels */
"                                    ",
"                                   .",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXooooooooXXXXXXXXXXXX..",
"  XXXXXXXXXoooXXXXXXXXoooXXXXXXXXX..",
"  XXXXXXXooXXXXXXXXXXXXXXooXXXXXXX..",
"  XXXXXXoXXXXXXXXXXXXXXXXXXoXXXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXoXXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXoXXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXoXXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXoXXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXoXXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXoXXXXXXXXXXXXXXXXXXXXXXXXXXoXX..",
"  XXXoXXXXXXXXXXXXXXXXXXXXXXXXoXXX..",
"  XXXXoXXXXXXXXXXXXXXXXXXXXXXoXXXX..",
"  XXXXXoXXXXXXXXXXXXXXXXXXXXoXXXXX..",
"  XXXXXXoXXXXXXXXXXXXXXXXXXoXXXXXX..",
"  XXXXXXXooXXXXXXXXXXXXXXooXXXXXXX..",
"  XXXXXXXXXoooXXXXXXXXoooXXXXXXXXX..",
"  XXXXXXXXXXXXooooooooXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX..",
"  ..................................",
" ..................................."};
