/* XPM */
/* $XConsortium: Dtpenpd.m.pm /main/3 1995/07/18 16:46:57 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * penpad [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 13 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X    s iconGray1     m white c #dededededede",
"o    s iconGray8     m black c #212121212121",
"O	s iconColor1	m black	c black",
"+    s iconGray6     m black c #636363636363",
"@    s iconGray5     m black c #737373737373",
"#    s iconGray7     m black c #424242424242",
"$    s iconGray3     m white c #adadadadadad",
"%	s iconColor6	m white	c yellow",
"&    s iconGray2     m white c #bdbdbdbdbdbd",
"*    s iconGray4     m white c #949494949494",
"=    s selectColor m white c #737373737373",
/* pixels */
"  ......................        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XXOXO+XOX+O+XXXXXXXXo        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XX+OOX+XoXO+OX+OXXXXo        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XXXXXXXXXXXXXXXXXXXXo        ",
"  .XXOX+OXO@O@XXXXXXXXXo        ",
"  .XXXXXXXXX#O@$XXXXXXXo        ",
"  .XXXXXXXXX#$..$$XXXXXo        ",
"  .XXXXXXXXXX#.X%$$XXXXo        ",
"  .XXXXXXXXXX#+$X%$$XXXo        ",
"  .XXXXXXXXXXX#+$X%$$XXo        ",
"  .XXXXXXXXXXX$#+$X%$$Xo        ",
"  .XXXXXXXXXXX$$#+$X%$$o        ",
"  .XXXXXXXXXXXX$$#+$X%$&        ",
"  .XXXXXXXXXXXXX$$#+$X%$&       ",
"  .XXXXXXXXXXXXXX$$#+$X%$&      ",
"  .XXXXXXXXXXXXXXX$$#+$X%$&     ",
"  .XXXXXXXXXXXXXXXX$$#+$X%$&    ",
"  .XXXXXXXXXXXXXXXXX$$#+$X%$&   ",
"  .XXXXXXXXXXXXXXXXXX$$#+$X##&  ",
"  .XXXXXXXXXXXXXXXXXXX$o##+XX*# ",
"  .XXXXXXXXXXXXXXXXXXXXo=##*X*# ",
"  .ooooooooooooooooooooo==#**##=",
"                         ==###==",
"                          ======",
"                           ==== ",
"                            ==  "};
