/* XPM */
/* $XConsortium: Dtdetachi.m.pm /main/2 1996/07/23 12:09:07 drk $ */
static char * Dtdetachi_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 7 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray2	m white	c #bdbdbdbdbdbd",
"X	s iconGray5	m black	c #737373737373",
"o	s iconColor5	m black	c blue",
"O	s iconGray4	m white	c #949494949494",
"+	s iconGray6	m black	c #636363636363",
"@	s iconGray3	m white	c #adadadadadad",
/* pixels */
"           .XoX                 ",
"           .oXo                 ",
"           .XoX                 ",
"           .oXo...              ",
"           .XoXOOO.             ",
"          .XoXOOOOO.            ",
"         ..oXoOOOOOO.           ",
"       ..XoXoOOOOOOOO.          ",
"      .oXoXoXOOOOOOOO+          ",
"      .XoXoXOOOO++++++..        ",
"        .oXOOOO+      .O+       ",
"        .XoOOO+       .OO+      ",
"       .XoOOO+        .OOO+     ",
"      .XoXOO+        .OOOOO+    ",
"      .oXO@+        .OOOOOO+    ",
"     .oXoOX        .OOOOOOO+    ",
"     .XoOX        .OOOOOOOo+    ",
"    .XoXOX       .OOOOOOXoXoXo+ ",
"    .oXOOX      .OOOOOOXoXoXoX+ ",
"   .oXOOOX     .OOOOOoXoXo+++++ ",
"   .XoOOOOX   .OOOOXoXoX+++     ",
"  .XoOOOOOOX .OOOOXoXo+++       ",
"  .oXOOOOOOO.OOOoXo+oX+         ",
" .oXOOOOOOOOOOOoX++.Xo+         ",
" .XoOOXOOOOOOXo++  .oX+         ",
" .o.XXOOOOOoXo+    .+++         ",
"  .X.XOOOOoX++                  ",
"  .X.XOOXoX+                    ",
"  .@X.oXo++                     ",
"   ..oX++                       ",
"     ++                         ",
"                                "};
