/* XPM */
/* $XConsortium: DtABdfl.pm /main/3 1995/07/18 17:08:48 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * DtABdfl_x_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"28 20 7 1 0 0",
/* colors */
"     s iconGray1     m white c #dededededede",
".    s iconGray6     m black c #636363636363",
"X    s iconGray7     m black c #424242424242",
"o    s iconGray4     m white c #949494949494",
"O    s iconGray2     m white c #bdbdbdbdbdbd",
"+	s iconColor4	m white	c green",
"@    s iconGray5     m black c #737373737373",
/* pixels */
"                            ",
" ..........................X",
" ..........................X",
" ooooooooooooooooooooooooooX",
" oOOOOOOOOOOOOOOOOOOOOOOOOoX",
" oOOOOOOOOO+++++OOOOOOOOOOoX",
" oOOOOOOOO+++++++OOOOOOOOOoX",
" oOOOOOOO+++@@@+++OOOOOOOOoX",
" oOOOOOOO++@@OO@++@OOOOOOOoX",
" oOOOOOOOO@@OOOO++@OOOOOOOoX",
" oOOOOOOOOOOOOO+++@OOOOOOOoX",
" oOOOOOOOOOO+++++@@OOOOOOOoX",
" oOOOOOOOOOO+++@@@OOOOOOOOoX",
" oOOOOOOOOOO++@@OOOOOOOOOOoX",
" oOOOOOOOOOO++@OOOOOOOOOOOoX",
" oOOOOOOOOOO++@OOOOOOOOOOOoX",
" oOOOOOOOOOOO@@OOOOOOOOOOOoX",
" oOOOOOOOOOO++OOOOOOOOOOOOoX",
" ooooooooooo++@ooooooooooooX",
" XXXXXXXXXXXXXXXXXXXXXXXXXXX"};
