/* XPM */
/* $XConsortium: Dtuuncd.m.pm /main/3 1995/07/18 16:53:31 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtuuncd_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray7     m black c #424242424242",
"+    s iconGray5     m black c #737373737373",
"@    s iconGray6     m black c #636363636363",
"#    s iconGray4     m white c #949494949494",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXOOXXOOXOOXXOOXXXXXXXo.......",
" XXXOOX+OO+OO+XOO++++XXXo.......",
" XXXOOXXOOXOOXXOOXXXXXXXo.......",
" XXXOO@XOO+OO++OO++++#XXo.......",
" XXXOOXXOOXOOXXOOXXXXXXXo.......",
" XXXOO++OO+OO++OO+++XXXXo.......",
" XXXXOOOOXXXOOOOXXXXXXXXo.......",
" XXX#+X+++X@X@++X#@X+XXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX#+X+++X@X@++X#@@++XXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX++X+++++X++++X++XXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX#@X@X@#+X@X++XXX@#XXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX+++X+++++X++++X++#XXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX##@X@X@#+X@X++XXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX++@X++X@#XXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX@#++X++++XXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
