/* XPM */
/* $XConsortium: Dtbmarki.m.pm /main/2 1996/07/23 12:05:53 drk $ */
static char * Dtbmarki_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 8 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray2	m white	c #bdbdbdbdbdbd",
"X	s iconGray3	m white	c #adadadadadad",
"o	s iconGray5	m black	c #737373737373",
"O	s iconGray6	m black	c #636363636363",
"+	s iconColor3	m black	c red",
"@	s iconGray4	m white	c #949494949494",
"#	s iconGray1	m white	c #dededededede",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
" ....................           ",
" .XoXXXXXXXXXXXXXXXXO           ",
" .XoXXXXXXXXXXXXXXXXOO          ",
" .XoXXXXXXXXXXXXXXXXOOO         ",
" .XoXXXXXXXXXXXXXXXXOOO         ",
" .XoXXOOOXOOXOXXOXXXOOO         ",
" .XoXXXXXXXXXXXXXXXXOOO         ",
" .XoXXXXXXXXXXXXXXXXO.......... ",
" .XoXXOXXooXXOXOOXXXO+o+o+..o+O ",
" .XoXXXXXooXXXXXXXXXOo+o+o..OoO ",
" .XoXXXXXXXXXXXXXXXXO+o+o+o.O+O ",
" .XoXXXXXooXXXXXXXXXOo+o+o+.OoO ",
" .XoXXXXoooXXXXXXXXXO+o+o+o.O+O ",
" .XoXXXXXooXXXXXXXXXOo+o+o+.OoO ",
" .XoXXXXXooXXXXXXXXXO+o+o+o.O+O ",
" .XoXXXXXooXXXXXXXXXOOOOOOO.OOO ",
" .XoXXXXXoooXXXXXXXXOOO    .O   ",
" .XoXXXXXXXXXXXXXXXXOOO    .O   ",
" .XoXXXXXXXXXXXXXXXXOOO    .O   ",
" .XoXXXXOOOOXXXXXXXXOOO    .O   ",
" .XoXXXXXXXXXXXXXXXXOOO   ..O   ",
" .XoXOOOOOXOOOOOXXXXOOO  .@..O  ",
" .XoXXXXXXXXXXXXXXXXOOO  @#@.@O ",
" .XoXXXXXXXXXXXXXXXXOOO  .O#O#O ",
" .XoXXXXXXXXXXXXXXXXOOO  @#@#@O ",
" .OOOOOOOOOOOOOOOOOOOOO  .O#O#O ",
" .OOOOOOOOOOOOOOOOOOOOO  @#@#@O ",
"  .OOOOOOOOOOOOOOOOOOOO   O#OOO "};
