/* XPM */
/* $XConsortium: wsswitch.pm /main/5 1996/07/23 13:53:56 drk $ */
static char * fpswitch_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"105 44 6 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s bottomShadowColor	m black	c #636363636363",
"X	s topShadowColor	m white	c #bdbdbdbdbdbd",
"o	s iconColor5	m black	c blue",
"O	s iconColor2	m white	c white",
"+	s iconColor1	m black	c black",
/* pixels */
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         ",
"  ..............................................                                                         ",
"  .............................................X     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    ",
"  ..oooooooooooooooooooooooooooooooooooooooooooX     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    ",
"  ..oooooooooooooooooooooooooooooooooooooooooooX     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  ..ooooOOOooooooooooooooooooooooooooooooooooooX     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  ..oooO++OooooooooooooooooooooooooooooooooooooX     XoooOOOOoooooooooooooooooooooooooooooooooooooo.X    ",
"  ..oooOoooOoOOOooOOOooooooooooooooooooooooooooX     XooooO+ooooooooooooooooooooooooooooooooooooooo.X    ",
"  ..oooOoooOoO+O+OOoO+oooooooooooooooooooooooooX     XooooO+oOoOOoO+O+Ooooooooooooooooooooooooooooo.X    ",
"  ..oooOoooOoOoO+OO+++oooooooooooooooooooooooooX     XooooO+oO+OO+OoOoO+ooooooooooooooooooooooooooo.X    ",
"  ..oooOooO+oOoO+OOoOooooooooooooooooooooooooooX     XooooO+oOO++OOoOoO+ooooooooooooooooooooooooooo.X    ",
"  ..oooo+++oo+oo+oo++ooooooooooooooooooooooooooX     XooooO+ooOooO+oOOO+ooooooooooooooooooooooooooo.X    ",
"  ..oooooooooooooooooooooooooooooooooooooooooooX     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  ..oooooooooooooooooooooooooooooooooooooooooooX     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  ..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     X..............................................X    ",
"                                                     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    ",
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         ",
"  .XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     ................................................    ",
"  .Xooooooooooooooooooooooooooooooooooooooooooo.     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    ",
"  .Xooooooooooooooooooooooooooooooooooooooooooo.     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  .Xooooooooooooooooooooooooooooooooooooooooooo.     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  .XoooOOOoO+oooooooooooooooooooooooooooooooooo.     XoooOOOOoooooooooooooooooooooooooooooooooooooo.X    ",
"  .XooooOooO+oooooooooooooooooooooooooooooooooo.     XoooO+++oooooooooooooooooooooooooooooooooooooo.X    ",
"  .XooooOooOO+OoOo+O++OoO++Oooooooooooooooooooo.     XoooO+oooOOOooOoOoOOOooooooooooooooooooooooooo.X    ",
"  .XooooOooO+oOoOooOOOOoOOOOooooooooooooooooooo.     XoooO+++oOooOoOoO+OO+ooooooooooooooooooooooooo.X    ",
"  .XooooOooO+oOoOooO++OoOooOooooooooooooooooooo.     XoooO+oooOooOoOoO+OOoooooooooooooooooooooooooo.X    ",
"  .XooooOooO+oOoOoooOO+oOOO+ooooooooooooooooooo.     XoooO+oooOooOoOoO+OOoooooooooooooooooooooooooo.X    ",
"  .Xooooooooooooooooooooooooooooooooooooooooooo.     Xoooo+oooo+++oo+o+o+oooooooooooooooooooooooooo.X    ",
"  .Xooooooooooooooooooooooooooooooooooooooooooo.     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  .Xooooooooooooooooooooooooooooooooooooooooooo.     Xooooooooooooooooooooooooooooooooooooooooooooo.X    ",
"  .X............................................     X..............................................X    ",
"                                                     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX    ",
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         ",
"                                                                                                         "};
