/* XPM */
/* $XConsortium: Dtgraphmap.l.pm /main/2 1996/10/29 15:51:54 drk $ */
static char * Dtgraphmap1_l_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"48 48 5 1 0 0",
/* colors */
" 	s background	m black	c #949494949494",
".	s iconGray1	m white	c #dededededede",
"X	s iconGray5	m black	c #737373737373",
"o	s iconGray8	m black	c #212121212121",
"O	s iconGray7	m black	c #424242424242",
/* pixels */
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                    ..........  ",
"                                    .XXXXXXXXo  ",
"                                    .XXXXXXXXo  ",
"                              OOOOOO.XXXXXXXXo  ",
"                              O     .XXXXXXXXo  ",
"                              O     .XXXXXXXXo  ",
"                              O     oooooooooo  ",
"                 ..........   O                 ",
"                 .XXXXXXXXo   O                 ",
"                 .XXXXXXXXo   O     ..........  ",
"              OOO.XXXXXXXXoOOOO     .XXXXXXXXo  ",
"              O  .XXXXXXXXo   O     .XXXXXXXXo  ",
"              O  .XXXXXXXXo   O     .XXXXXXXXo  ",
"              O  oooooooooo   OOOOOO.XXXXXXXXo  ",
"              O                     .XXXXXXXXo  ",
"              O                     oooooooooo  ",
"  ..........  O                                 ",
"  .XXXXXXXXo  O                                 ",
"  .XXXXXXXXo  O                                 ",
"  .XXXXXXXXoOOO                                 ",
"  .XXXXXXXXo  O                                 ",
"  .XXXXXXXXo  O                                 ",
"  oooooooooo  O                     ..........  ",
"              O                     .XXXXXXXXo  ",
"              O                     .XXXXXXXXo  ",
"              O  ..........   OOOOOO.XXXXXXXXo  ",
"              O  .XXXXXXXXo   O     .XXXXXXXXo  ",
"              O  .XXXXXXXXo   O     .XXXXXXXXo  ",
"              OOO.XXXXXXXXo   O     oooooooooo  ",
"                 .XXXXXXXXoOOOO                 ",
"                 .XXXXXXXXo   O                 ",
"                 oooooooooo   O     ..........  ",
"                              O     .XXXXXXXXo  ",
"                              O     .XXXXXXXXo  ",
"                              OOOOOO.XXXXXXXXo  ",
"                                    .XXXXXXXXo  ",
"                                    .XXXXXXXXo  ",
"                                    oooooooooo  ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                                                "};
