/* XPM */
/* $XConsortium: Fpdropz.m.pm /main/3 1995/07/18 17:12:43 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * Fdropzn [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s none	m none	c none",
".    s bottomShadowColor m black c #636363636363",
"X    s selectColor m white c #737373737373",
"o    s background    m black c #949494949494",
"O    s topShadowColor m white c #bdbdbdbdbdbd",
/* pixels */
"                                ",
"                                ",
"                                ",
"                                ",
"................................",
".XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
".oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
".Xo..........................XoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.oXoXoXoXoXoXoXoXoXoXoXoXOXoO",
".oX.XoXoXoXoXoXoXoXoXoXoXoXoOoXO",
".Xo.OOOOOOOOOOOOOOOOOOOOOOOOOXoO",
".oXoXoXoXoXoXoXoXoXoXoXoXoXoXoXO",
".XoXoXoXoXoXoXoXoXoXoXoXoXoXoXoO",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO",
"                                ",
"                                ",
"                                ",
"                                ",
"                                "};
