/* XPM */
/* $XConsortium: DtCMday.m.pm /main/2 1996/07/23 11:55:06 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/

static char * day-view_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 10 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconGray2	m white	c #c8c8c8c8c8c8",
"X	s iconGray1	m white	c #e1e1e1e1e1e1",
"o	s iconGray4	m white	c #969696969696",
"O	s iconColor2	m white	c white",
"+	s iconGray3	m white	c #afafafafafaf",
"@	s iconGray6	m black	c #646464646464",
"#	s iconGray5	m black	c #7d7d7d7d7d7d",
"$	s iconColor5	m black	c blue",
"%	s iconColor3	m black	c red",
/* pixels */
"    .                    .      ",
"   .Xo                  .Xo     ",
"OOO.XoOOOOOOOOOOOOOOOOOO.XoOOo  ",
"OOX.XoX+XOXOXOXXXXXXXXXX.XoX+o@ ",
"OXO.+o+XOXOXOXXXXXXXXXXX.+o+Xo@ ",
"OOXO#XXO$$$$$$$$$$$$$$XXX#XXXo@ ",
"OXOXOXOXOXOXXXXXXXXXXXXXXXXXXo@ ",
"OOXOXOXOXOXXXXXXXXXXXXXXXXXXXo@ ",
"OXOXOXOXOXXXXX+++XX+++XX+++XXo@ ",
"OOXOXOXOXXXXXX+++XX+++XX+++XXo@ ",
"OXOXOXOXXXXXXX+++XX+++XX+++XXo@ ",
"OOXOXOXXXXXXXXXXXXXXXXXXXXXXXo@ ",
"OXOXOXXXXXXXXXXXXXXXXXXXXXXXXo@ ",
"OOXO+++XX+++XX+++XX+++XX+++XXo@ ",
"OXOX+++XX+++XX+++XX+++XX+++XXo@ ",
"OOXX+++XX+++XX+++XX+++XX+++XXo@ ",
"OXXXXXXXXXXXXXXXXXXXXXXXXXXXXo@ ",
"OXXXXXXXXXXXXXXXXXXXXXXXXXXXXo@ ",
"OXXX+++XX+++XX%%%XX+++XX+++XXo@ ",
"OXXX+++XX+++XX%O%XX+++XX+++XXo@ ",
"OXXX+++XX+++XX%%%XX+++XX+++X+o@ ",
"OXXXXXXXXXXXXXXXXXXXXXXXXXX+Xo@ ",
"OXXXXXXXXXXXXXXXXXXXXXXXXX+X+o@ ",
"OXXX+++XX+++XX+++XX+++XXooo+.o@ ",
"OXXX+++XX+++XX+++XX+++XXooo.+o@ ",
"OXXX+++XX+++XX+++XX+++X+ooo+oo@ ",
"OXXXXXXXXXXXXXXXXXXXXX+X+.#o+o@ ",
"OXXXXXXXXXXXXXXXXXXXX+X+.OOOX#@ ",
"OXXX+++XX+++XX+++XXX+X+.+OOX#o@ ",
"OXXX+++XX+++XX+++XX+X+.+oOX#o.@ ",
"OXXX+++XX+++XX+++X+X+.+o+X#o..@ ",
"Ooooooooooooooooooooooooo#o...  "};
