/* XPM */
/* $XConsortium: Dtaudio.m.pm /main/3 1995/07/18 16:29:46 drk $ */
static char * Dtaudio_m_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 10 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray1     m white c #dededededede",
"+    s iconGray4     m white c #949494949494",
"@    s iconGray6     m black c #636363636363",
"#    s iconGray3     m white c #adadadadadad",
"$    s iconGray7     m black c #424242424242",
"%    s iconGray5     m black c #737373737373",
/* pixels */
"                         .......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXX XXXXXOOXXXXXXXXXXXXo.......",
" XXXX XXXX O+XXXXXXXXXXXo.......",
" XXXXX XXX  +XXXXXXXXXXXo.......",
" XXXXXX XX  @+XXXXXXXXXXo.......",
" XXXXXXXXX  @X+XXXXXXXXXo.......",
" X OXXXXXXO @OX+XXXXXXXXo.......",
" XXX OXXXX O@OOX+XXXXXXXo.......",
" XXXXX OXXOO@XOOX+    XXo.......",
" XXXXXXXXXXO@XXXX+OOO+XXo.......",
" XXXXXXXXXXX@#X#X+#X#@XXo.......",
" X O O OXX##@++++@+++@XXo.......",
" XXXXXXXXX##@++@+@+++@XXo.......",
" XXXXXXXXX##@@@@$$$$$@XXo.......",
" XXXXX OXX##@@@$@@@%@@XXo.......",
" XXX OXXXX+%@@$@+@@@@@XXo.......",
" X OXXXXXX@+@$@+@XXXXXXXo.......",
" XXXXXXXXX@@@@+@XXXXXXXXo.......",
" XXXXXX XX@@@+@XXXXXXXXXo.......",
" XXXXX XXX@@#@XXXXXXXXXXo.......",
" XXXX XXXX@@@XXXXXXXXXXXo.......",
" XXX XXXXX++XXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" XXXXXXXXXXXXXXXXXXXXXXXo.......",
" oooooooooooooooooooooooo......."};
