/* XPM */
static char *sound_juicer_m[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c #555555",
".  c #7D7D7E",
"X  c #AE561C",
"o  c #B26025",
"O  c #B3632B",
"+  c #B86929",
"@  c #B86E37",
"#  c #B26B39",
"$  c #BA6F39",
"%  c #BB723C",
"&  c #CB7C28",
"*  c #A4704E",
"=  c #B77C52",
"-  c #B87B51",
";  c #867972",
":  c #B97F62",
">  c #E69015",
",  c #D28223",
"<  c #D78D35",
"1  c #EA9A24",
"2  c #EBA236",
"3  c #FCA639",
"4  c #FCAD3D",
"5  c #F2A533",
"6  c #8D847B",
"7  c #9D867A",
"8  c #AF836D",
"9  c #B2826B",
"0  c #B88A68",
"q  c #BC8764",
"w  c #AB8775",
"e  c #A28576",
"r  c #B58D75",
"t  c #B29471",
"y  c #CB8A54",
"u  c #E78C55",
"i  c #EA955D",
"p  c #EAA344",
"a  c #FCAC42",
"s  c #FAAF4B",
"d  c #FCB144",
"f  c #F7B14E",
"g  c #FCB24B",
"h  c #EEAE5D",
"j  c #EFB35E",
"k  c #FCB453",
"l  c #F7B45C",
"z  c #FAB65A",
"x  c #FCB95C",
"c  c #F5B251",
"v  c #C5936F",
"b  c #DC9767",
"n  c #D59B67",
"m  c #EC9D63",
"M  c #E59F6A",
"N  c #D3A77B",
"B  c #EDA166",
"V  c #EBA36B",
"C  c #E7AD67",
"Z  c #F0A76D",
"A  c #FCB761",
"S  c #FCBD64",
"D  c #F8BC6C",
"F  c #F4B561",
"G  c #E5A772",
"H  c #ECAD75",
"J  c #E6AE78",
"K  c #F1AD72",
"L  c #E7B373",
"P  c #E1B27A",
"I  c #E7B778",
"U  c #F5BE73",
"Y  c #F5B67A",
"T  c #F3BE79",
"R  c #FDC26B",
"E  c #FCC575",
"W  c #FCC47C",
"Q  c #F4C27E",
"!  c #848484",
"~  c #878788",
"^  c #8A898A",
"/  c #948781",
"(  c #908980",
")  c #908C8B",
"_  c #929292",
"`  c #979799",
"'  c #969899",
"]  c #989A9B",
"[  c #BFA385",
"{  c #B4A39A",
"}  c #B9B699",
"|  c #BDBC9E",
" . c #9FA1A3",
".. c #A4A4A5",
"X. c #AFAAA6",
"o. c #A2A6A8",
"O. c #AAABAD",
"+. c #A4A8AB",
"@. c #B6A7A1",
"#. c #AFB0A4",
"$. c #B6B7A3",
"%. c #BCBCA3",
"&. c #B6BAAF",
"*. c #BBBDAD",
"=. c #B3B3A9",
"-. c #A7A9B5",
";. c #AAABBD",
":. c #A6A8BC",
">. c #B4AFBE",
",. c #ADB0B6",
"<. c #B9BEB5",
"1. c #BBBEBB",
"2. c #B6BBB9",
"3. c #C8AF8D",
"4. c #C5A690",
"5. c #CBAE91",
"6. c #D8B490",
"7. c #D2B39E",
"8. c #EBB783",
"9. c #F7BE81",
"0. c #E4BD90",
"q. c #C3BFA6",
"w. c #D3BBA7",
"e. c #C7BDB3",
"r. c #C9BAB4",
"t. c #BEC1AB",
"y. c #BDC0B0",
"u. c #BCC0BC",
"i. c #EBC08F",
"p. c #F5C684",
"a. c #F8C285",
"s. c #FECC84",
"d. c #FAC788",
"f. c #F6C98F",
"g. c #FBCB8B",
"h. c #F4C68B",
"j. c #ECC696",
"k. c #ECC69B",
"l. c #EBC99C",
"z. c #F4CA93",
"x. c #FBCE90",
"c. c #F1CF9D",
"v. c #FED394",
"b. c #F7D09F",
"n. c #FDD59D",
"m. c #FED99D",
"M. c #C0C0A5",
"N. c #C3C2AC",
"B. c #C3C3B4",
"V. c #C5C4BB",
"C. c #C3C8BE",
"Z. c #D7C3B6",
"A. c #DBC5B4",
"S. c #D1C5BE",
"D. c #D9C6B8",
"F. c #E2C5A7",
"G. c #E6CFA1",
"H. c #EDCFAE",
"J. c #EAD1AE",
"K. c #FCD6A0",
"L. c #FEDBA3",
"P. c #FDDBAA",
"I. c #ECCFB1",
"U. c #E2CCBA",
"Y. c #EDD2B6",
"T. c #F5D6B1",
"R. c #FCDEB3",
"E. c #F6DEBC",
"W. c #FEE1B4",
"Q. c #FDE1BB",
"!. c #ADADC2",
"~. c #B6BBC7",
"^. c #BABDC2",
"/. c #BDBDCC",
"(. c #B6B5C6",
"). c #BFBED5",
"_. c #C7BDC3",
"`. c #C0BCC8",
"'. c #C0BCD0",
"]. c #BDC2C3",
"[. c #BCC3CB",
"{. c #BDC4D1",
"}. c #BFC8D4",
"|. c #C0C5C7",
" X c #CAC5C4",
".X c #C5CAC3",
"XX c #C3C9CF",
"oX c #CACBCC",
"OX c #CBC8C4",
"+X c #D8CAC5",
"@X c #CDD2CF",
"#X c #D1D2C0",
"$X c #DED2C7",
"%X c #D7D7CE",
"&X c #D9D0CB",
"*X c #C3C6D3",
"=X c #C4CAD3",
"-X c #CBCCD5",
";X c #C9C7DB",
":X c #CDCBDC",
">X c #D0CED6",
",X c #D3CFDE",
"<X c #CDD2D4",
"1X c #CFD4DC",
"2X c #D0D1D6",
"3X c #D2D4DA",
"4X c #D6D9D9",
"5X c #DBDCDC",
"6X c #EEDBC5",
"7X c #E1D6CE",
"8X c #E3DADC",
"9X c #F6E1C4",
"0X c #FEE9C7",
"qX c #F6E2C9",
"wX c #FEE7C9",
"eX c #FEEACC",
"rX c #E7E7D7",
"tX c #EEE1D2",
"yX c #E1E1DE",
"uX c #E9E2DC",
"iX c #F5E6D3",
"pX c #F6E8D7",
"aX c #F8EBD5",
"sX c #FFF1DD",
"dX c #CDCDE2",
"fX c #D4CEE3",
"gX c #D3D4E3",
"hX c #D4DAE4",
"jX c #DCDDE3",
"kX c #D5D5EA",
"lX c #D3DAE9",
"zX c #DADBEF",
"xX c #D7D9F1",
"cX c #DADEF1",
"vX c #E4DFE9",
"bX c #DFE3EF",
"nX c #DDE0F2",
"mX c #E3E3E2",
"MX c #ECE4E2",
"NX c #EAEAE7",
"BX c #E5E7E8",
"VX c #EBEAE9",
"CX c #F3EBE7",
"ZX c #F8EDE1",
"AX c #F6EEE8",
"SX c #FEF5E7",
"DX c #F6F1EB",
"FX c #E4E5F5",
"GX c #EAEBF6",
"HX c #F3F2F5",
"JX c #FDFAF4",
"KX c #F3F3F9",
"LX c #F9F7F9",
"PX c #FFFDF9",
"IX c #FBF6F2",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXG Z m m B B i m V H UXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXJ Z Z Y d.v.m.P.W.K.d.T B m H UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXG Z p.v.n.P.sXJXsX0XJXSXK.v.d.Z b UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXB Y R.0XeX0XJXW a 3 4 a R P.m.n.E.4.: UXUXUXUXUXUX",
"UXUXUXUXUXUXm a.eXR.x d g PXk 4 4 4 4 4 g n.x.9XHXr.9 UXUXUXUXUX",
"UXUXUXUXUXm 9.eXn.4 4 4 4 SXx.4 4 4 4 4 S P.4 d g.AXr.8 UXUXUXUX",
"UXUXUXUXM Y W.0Xd g a 3 3 P.Q.4 4 4 d d R.x 4 4 a E DX{ w UXUXUX",
"UXUXUXG B v.eXE 3 4 4 4 3 z wXg g s k f.P.k k z S S E.VX7 UXUXUX",
"UXUXUXm p.L.eXx 3 4 a 4 a a Q.S l h H tXT T T a.U h.c.VXV.7 UXUX",
"UXUXUXi v.L.x.eXv.g d k k z n.f.P N I.6X0.k.k.k.i.l.J.uXVX/ UXUX",
"UXUXM K v.R 4 g n.Q.W k A D j.6X7.w.CXZ.Z.Z.A.D.+X$X7XyXVXX.UXUX",
"UXUXi a.s.d 4 4 4 x P.W.T P 5.&X6 OXjXfX/.!.(.>X3X3X4XyXBXOX) UX",
"UXUXu v.R 4 4 4 4 4 d p.iXuX6 UXUX..! (.).!.;.*X-X2X3X4XyX5X) UX",
"UXUXu v.x 4 4 4 4 4 f C 6.B.X.UXUXUX` ` dX!.!./.*X>X1X4X5XmX~ UX",
"UXUXi v.R 4 4 4 4 d j 8.G.( UXUXUXUXUX6 >X:.:.(.*X=X<X4X4XBX! UX",
"UXUXi v.s.d 4 4 4 f L F.MXjX_ UXUXUXUX_ %XO.-.~.{.{.=X<X4XyX! UX",
"UXUXi v.m.g 4 z g.9XtX&X;X/.. UXUXUX; V.#X#.O.^.[.{.XX-X3X<X^ UX",
"UXUXB h.m.Q.0XQ.b.k.7. X;XkX`._ ! * 0 rXB.$.=.].^.[.{.=X1X].) UX",
"UXUXG 8.eXqXf z T j.U.:X:X:XfX+X$ X 3.N.N.%.*.y.].[.[.}.1Xo.UXUX",
"UXUXUXv JXiXg D h.H.7XkXdX:X^.O & + t } | t.t.y.u.].[.}.1X^ UXUX",
"UXUXUX8 S.LXx D f.Y.8XxXkXgXr y z., # } | t.M.*.u.u.[.=X,.^ UXUX",
"UXUXUXUXe LXP.Q z.Y.vXcXzXhX@ < > 2 % [ q.| %.*.u.u.{.}.~ UXUXUX",
"UXUXUXUXw @.IXK.T.tXFXcXnXgXO 6X1 5 C # N.*.*.*.&.~.XX] ^ UXUXUX",
"UXUXUXUXUX7 OXLXpXMXGXFXcXgXo ZXE 4 z.O V.y.y.&.2.[.+.^ UXUXUXUX",
"UXUXUXUXUXUX/ OXLXKXGXFXnXgXq n p F n - C.y.y.u.u.o.~ UXUXUXUXUX",
"UXUXUXUXUXUXUX) O.HXKXGXnXlX>Xq o o - B..XC..X].] ~ UXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX^ ^ oXHXGXbXlXhX1X1X@X@X@X@XO.~ ! UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUX^ ^ O.-X4XlXlX1XoXu. .~ ! UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUX  . ^ ! ! ! ! .   UXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
