/* XPM */
/* $XConsortium: mdticon.pm /main/5 1996/10/29 15:54:31 drk $ */
static char * mdticon_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"90 165 18 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	c #B3B3CECED9D9",
"X	s iconColor1	m black	c black",
"o	c #2A2A49495555",
"O	c #55559292AAAA",
"+	s iconColor5	m black	c blue",
"@	c #323232323232",
"#	c #7D7D7D7D7D7D",
"$	c #C8C8C8C8C8C8",
"%	c #E1E1E1E1E1E1",
"&	c #646464646464",
"*	c #4B4B4B4B4B4B",
"=	c #AFAFAFAFAFAF",
"-	s iconColor6	m white	c yellow",
";	c #969696969696",
":	c #48487C7C9191",
">	s iconColor7	m white	c cyan",
",	s iconColor3	m black	c red",
/* pixels */
"                                                                                          ",
"....................................X                                                     ",
"...................................oX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoX                                                     ",
"..OOOOOOOOOOOOOOOOO  ++++++++@@OOOOoX                                                     ",
"..OOOO              ++++++++++@@OOOoX                                                     ",
"..OOOO##########################@OOoX                                                     ",
"..OO                          @#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO $$$$$$$$$$$$$$$$$$$$$$$$#@#@OOoX                                                     ",
"..OO #########################@@@OOoX                                                     ",
"..OOO@@@@@@@@@@@@@@@@@@@@@@@@@@@OOOoX                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOO  OOOOOOOOOOOOOOOoo                                                     ",
"..OOOO  OOOOOOOOO OOOOOOOOOOOOOOOOOoo                                                     ",
"..OOO OOOOO  OOO   OOO  OOOOOOOOOOOoo                                                     ",
"..OOO OOOOOOO OOO OOO OO OOOOOOOOOOoo                                                     ",
"..OOOO OOOO   OOO OOO    OOOOOOOOOOoo                                                     ",
"..OOOOO OO OO OOO OOO OOOOOOOOOOOOOoo                                                     ",
"..OOOOO OO O  OOO OOO OOOOOOOOOOOOOoo                                                     ",
"..OOO  OOOO O OOO OOOO   OOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
".oooooooooooooooooooooooooooooooooooo                                                     ",
"ooooooooooooooooooooooooooooooooooooo                                                     ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"....................................o                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOO                    OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%X%X&%X%&X&%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%&XX%&%@%X&%&X%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%X%&X%X#X#%%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%*X#%%%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%*= ==%%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%* -==%%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%*&%-==%%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%*=%-==%%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%=&=%-==%@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%=*&=%-==@OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%=*&=%-=$OOOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%==*&=%-=$OOOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%==*&=%-=$OOOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%==*&=%-=OOOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%==*&=%-$OOOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%==*&=%*$OOOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%=@**&%;*OOOoo                                                     ",
"..OOOO%%%%%%%%%%%%%%%%%%%@:**%;*OOOoo                                                     ",
"..OOOO@@@@@@@@@@@@@@@@@@@@::*;**:OOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOO::**::OOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOO:::::OOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOO:::OOOooOOOOOOOOO                                            ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOO::OOOOo..........                                            ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO..........o                                            ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                            ",
"..OOOOOOOOOOOOOO OOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                            ",
"..OOO  OOOOOOOOO OOOOOOOOOOO OOOOOOOOOO OOOOoo                                            ",
"..OOO O OOO  OOO OOOOOOOOOO   OO OOO O   OOOoo                                            ",
"..OOO O OO OO OO   OOOOOOOOO OOOO O OOO OOOOoo                                            ",
"..OOO  OOO OO OO O OOOOOOOOO OOOOO OOOO OOOOoo                                            ",
"..OOO  OOO OO OO O OOOOOOOOO OOOOO OOOO OOOOoo                                            ",
"..OOO O OO OO OO O OOO OOOOO OOOO O OOO OOOOoo                                            ",
"..OOO O OOO  OOO  OOOO OOOOOO OO OOO OOO OOOoo                                            ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                            ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                            ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                            ",
".ooooooooooooooooooooooooooooooooooooooooooooo                                            ",
"oooooooooooooooooooooooooooooooooooooooooooooo                                            ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"....................................o                                                     ",
"...................................oo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo                                                     ",
"..OOO +++++++++++++++++++++++++XOOOoo                                                     ",
"..OOO +++++++++++++++++++++++++XOOOoo                                                     ",
"..OO     ++++++++++++++++++     XOOoo                                                     ",
"..OO ;;;; ++++++++++++++++ ;;;;;XOOoo                                                     ",
"..OO ;;;;; ++++++++++X+++ ;;;;;;XOOoo                                                     ",
"..OO ;;;;;;         X;*  ;;;;;;;XOOoo                                                     ",
"..OO ;;; %;;;;;;;;;X-%=*;;;;;;;;XOOoo                                                     ",
"..OO ;;$X %;;;;;;;X%&-%=*;;;;;;;XOOoo                                                     ",
"..OO ;;X$X %;;;;;;@&;&-%=*;;;;;;XOOoo                                                     ",
"..OO ;;XX$X %;;;;;*@&;&-%=*;;;;;XOOoo                                                     ",
"..OO ;;&XX$XX;;;;;;*@&;&-%=*;;;;XOOoo                                                     ",
"..OO ;;;;&&X;* ;;;;*&%$&=&-%=;;;XOOoo                                                     ",
"..OO ;;;;;;&X;* ;;*&%$#@&=&-%*;;XOOoo                                                     ",
"..OO ;;;;;;;&X;* ;&%$#@**&;&-*;;XOOoo                                                     ",
"..OO ;;;;;;;;&X;*+%$#@*;**&%X;;;XOOoo                                                     ",
"..OO ;;;;;;;;;&X+>&+@*;;;*@X*;;;XOOoo                                                     ",
"..OO ;;;;;;;;;;+>=+@*;;;;;**;;;;XOOoo                                                     ",
"..OO ;;;;;;;;;+>+#@*&;;;;;;;;;;;XOOoo                                                     ",
"..OO ;;;;;;;;+>=#+*@&&@;;;;;;;;;XOOoo                                                     ",
"..OO ;;;;;;;+>+#+@@#,-%@;;;;;;;;XOOoo                                                     ",
"..OO ;;;;;;+>=#+@*@,-,-%@;;;;;;;XOOoo                                                     ",
"..OO ;;;;;+>+#+@*;@*,-,-%@;;;;;;XOOoo                                                     ",
"..OO ;;;;+>=#+@*;;&@*,-,-%@;;;;;XOOoo                                                     ",
"..OO ;;++=#+@*;;;;;;&@*,-,-@&;;;XOOoo                                                     ",
"..OO ;;++++@*;;;;;;;;&@*,-,@&;;;XOOoo                                                     ",
"..OO ;;@@@@*;;;;;;;;;;&@*@@&&;;;XOOoo                                                     ",
"..OO ;;;***;;;;;;;;;;;;&&&&;;;;;XOOoo                                                     ",
"..OO ;;;;;;;;;;;;;;;;;;;;;;;;;;;XOOooOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO           ",
"..OOXXXXXXXXXXXXXXXXXXXXXXXXXXXXXOOo...........................................           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO...........................................o           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo           ",
"..OOOOOOOOOOOOOOOOOOO OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO   OOOOOOOOOoo           ",
"..OOO  OOOOOOOOOOOOOO OOOOOO OOOOOOOOOOOOOOOOOOOO    OOOOOOOOOOOOOO OOOOOOOOOoo           ",
"..OOO OO O OO OO OOOO O OOOO OOO OO OO   OOOOOOOOOO OO OO OO OOOOOO OOO OOOOOoo           ",
"..OOO OO O    OO  OOO  OOOOO OOO OO OO O OOOOOOOOOO OO OO OO OOOOOO OOO  OOOOoo           ",
"..OOO OO O OOOOOOO OO O OOOO OOO OO OO O OOOOOOOOOO OO OO OO OOOOOO OOOOO  OOoo           ",
"..OOO O OO OOOOOOO OO OO OOO OOO OO OO O OOOOOOOOOO OO OO OO OOOOOO OOOOOO OOoo           ",
"..OOO  OOOO   OO  OOO OOO OOO OOO  OOO  OOOOOOOOOOO OOO  OOOO  OOOO OOO   OOOoo           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO OOO      OOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo           ",
"..OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOoo           ",
".oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo           ",
"ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo           ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          ",
"                                                                                          "};
