/* XPM */
/* $XConsortium: Dtmime.t.pm /main/3 1995/07/18 16:45:31 drk $ */
/*********************************************************************
*  (c) Copyright 1993, 1994 Hewlett-Packard Company	
*  (c) Copyright 1993, 1994 International Business Machines Corp.
*  (c) Copyright 1993, 1994 Sun Microsystems, Inc.
*  (c) Copyright 1993, 1994 Unix System Labs, Inc., a subsidiary of
*      Novell, Inc.
**********************************************************************/
static char * Dtmime_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 12 1 0 0",
/* colors */
" 	s iconColor2	m white	c white",
".	s none	m none	c none",
"X    s iconGray2     m white c #bdbdbdbdbdbd",
"o	s iconColor1	m black	c black",
"O    s iconGray6     m black c #636363636363",
"+    s iconGray5     m black c #737373737373",
"@    s iconGray4     m white c #949494949494",
"#	s iconColor3	m black	c red",
"$	s iconColor6	m white	c yellow",
"%	s iconColor7	m white	c cyan",
"&	s iconColor5	m black	c blue",
"*    s iconGray8     m black c #212121212121",
/* pixels */
"             ...",
" XXXXXXXXXXXo...",
" XOoOOXooooXo...",
" XXXXXXXXXXXo...",
" XOOooOXoXXXo...",
" XXXXXXXXXXXo...",
" XOXOX+@O+oXo...",
" XXXXX OO+oXo...",
" XooXX#O$%oXo...",
" XXXXX&OO oXo...",
" XoooXoooooXo...",
" XXXXXX&XXXXo...",
" XXX#*X&$XXXo...",
" XXOOOOOOOOXo...",
" XXXXXXXXXXXo...",
" oooooooooooo..."};
