/* XPM */
/* $XConsortium: Dtagen.m.pm /main/3 1995/07/18 16:27:23 drk $ */
static char * Dtagen [] = {
/* width height ncolors cpp [x_hot y_hot] */
"32 32 5 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconColor1	m black	c black",
"o	s iconColor5	m black	c blue",
"O    s iconGray4     m white c #949494949494",
/* pixels */
" .............................X ",
" .oOoOoOoOoOoOoOoOoOoOoOoOoOoOX ",
" .OoOoOoOoOoOoOoOoOoOoOoOoOoOoX ",
"......oOoOoOoOoOoOoOoOoOoO.....X",
".OOOOO.oOoOoOoOoOoOoOoOoO.OOOOOX",
".OOOOOO.oOoOoOoOoOoOoOoO.OOOOOOX",
".OOOOOOO................OOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX",
"XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"};
