/* XPM */
/* $XConsortium: wsswitch.pm /main/2 1996/07/23 12:56:47 drk $ */
static char * fpswitch_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"105 44 6 1 0 0",
/* colors */
" 	c #55559292AAAA",
".	s background	m black	c #969696969696",
"X	c #2A2A36365353",
"o	c #B1B1BCBCD8D8",
"O	c #55556D6DAAAA",
"+	s iconColor2	m white	c white",
/* pixels */
"                                                                                   ......................",
".........................................................................................................",
"...                                             .... .....    ...........................................",
"..                                                .....                      ...........              ...",
"..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX                                                      ...",
"..XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo     oooooooooooooooooooooooooooooooooooooooooooooooo....",
"..XXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo     oooooooooooooooooooooooooooooooooooooooooooooooo....",
"..XXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOOO+++OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOO+XX+OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOO++++OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOO+OOO+O+++OO+++OOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOO+XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOO+OOO+O+X+X++O+XOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOO+XO+O++O+X+X+OOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOO+OOO+O+O+X++XXXOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOO+XO+X++X+O+O+XOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOO+OO+XO+O+X++O+OOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOO+XO++XX++O+O+XOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOOOXXXOOXOOXOOXXOOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOO+XOO+OO+XO+++XOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOo     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XXoooooooooooooooooooooooooooooooooooooooooooo     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..Xooooooooooooooooooooooooooooooooooooooooooooo     oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo....",
"..                                                   oooooooooooooooooooooooooooooooooooooooooooooooo....",
"..                                                                                                   ....",
"..                                                                                                   ....",
"..                                                                                                   ....",
"..                                                                                                   ....",
"..Xooooooooooooooooooooooooooooooooooooooooooooo     XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX....",
"..XoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oooooooooooooooooooooooooooooooooooooooooooooooo....",
"..XoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOX+XX+XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOO++++OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOO+OO+XOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOO+XXXOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOO+OO++X+O+OX+XX+O+XX+OOOOOOOOOOOOOOOOOOOX     oOOO+XOOO+++OO+O+O+++OOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOO+OO+XO+O+OO++++O++++OOOOOOOOOOOOOOOOOOOX     oOOO+XXXO+OO+O+O+X++XOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOO+OO+XO+O+OO+XO+O+OO+OOOOOOOOOOOOOOOOOOOX     oOOO+XOOO+OO+O+O+X++OOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOO+OO+XO+O+OOO++XO+++XOOOOOOOOOOOOOOOOOOOX     oOOO+XOOO+OO+O+O+X++OOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOOOXOOOOXXXOOXOXOXOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOX     oOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOXo....",
"..XoXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX     oXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXo....",
"..           ..            ......................    oooooooooooooooooooooooooooooooooooooooooooooooo....",
".........................................................................................................",
".........................................................................................................",
". .......................................................................................................",
"  .......................................................................................................",
" ........................................................................................................"};
