/* XPM */
static char *brasero_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 218 2 ",
"   c #545454",
".  c #696969",
"X  c #6F6F70",
"o  c #747474",
"O  c #7C7C7C",
"+  c #EADB5F",
"@  c #F1E057",
"#  c #F8E654",
"$  c #FCEA56",
"%  c #F4E359",
"&  c #DCD26F",
"*  c #D2C877",
"=  c #D4CA79",
"-  c #DAD173",
";  c #E2D566",
":  c #EADB60",
">  c #E3D76A",
",  c #EADE71",
"<  c #FCEB60",
"1  c #FAEB6C",
"2  c #FDEE75",
"3  c #FDEF7F",
"4  c #7E7E80",
"5  c #848484",
"6  c #888787",
"7  c #878788",
"8  c #8A8A8A",
"9  c #908F8F",
"0  c #929292",
"q  c #949698",
"w  c #9B9C9D",
"e  c #A3A39D",
"r  c #A9A69B",
"t  c #AEAB9D",
"y  c #B3AF9B",
"u  c #B6B295",
"i  c #BDB993",
"p  c #B5B49B",
"a  c #B9B79D",
"s  c #B7B89E",
"d  c #BCBA9B",
"f  c #9D9CA5",
"g  c #9F9EA8",
"h  c #9EA0A2",
"j  c #A5A4A5",
"k  c #A8A7A7",
"l  c #ABABA6",
"z  c #A6A3AB",
"x  c #A8A7AA",
"c  c #ABABAC",
"v  c #B5AFA3",
"b  c #B2ADAB",
"n  c #B4B4A4",
"m  c #BAB7A5",
"M  c #B6B8A6",
"N  c #BBBBA4",
"B  c #B2B2AD",
"V  c #B9B5AA",
"C  c #B5B9AB",
"Z  c #BCBBAC",
"A  c #A5A5B5",
"S  c #A9A6B2",
"D  c #A7A8B5",
"F  c #ACAAB4",
"G  c #A5A6BB",
"H  c #AAA5B8",
"J  c #A6A9BD",
"K  c #ACAABD",
"L  c #B1ADB3",
"P  c #B1ADB9",
"I  c #B4B4B4",
"U  c #B8B6B5",
"Y  c #B5BAB4",
"T  c #BBBCB3",
"R  c #B4B3BB",
"E  c #BAB6BD",
"W  c #B5BABA",
"Q  c #BBBCBB",
"!  c #C4BE86",
"~  c #C3BD8B",
"^  c #C2BE9B",
"/  c #C2BFA4",
"(  c #C0BFAD",
")  c #C2BEB5",
"_  c #BFC0AD",
"`  c #BDC2BB",
"'  c #CAC385",
"]  c #CEC883",
"[  c #C7C38A",
"{  c #C9C38C",
"}  c #D3CC83",
"|  c #C5C293",
" . c #C3C39D",
".. c #D2CE97",
"X. c #D0CB9D",
"o. c #E6DB85",
"O. c #E8DE8E",
"+. c #FDEF81",
"@. c #FDF08A",
"#. c #F0E690",
"$. c #F6EC95",
"%. c #FDF294",
"&. c #FDF39F",
"*. c #C2C3A4",
"=. c #C3C2AC",
"-. c #CDCBAD",
";. c #C3C1B3",
":. c #C2C2BC",
">. c #CBCAB8",
",. c #D3D0BF",
"<. c #EDE5A1",
"1. c #F8EFAA",
"2. c #FDF3A0",
"3. c #FEF4A9",
"4. c #E7E2BA",
"5. c #E8E5BF",
"6. c #F0E9B5",
"7. c #FEF6B3",
"8. c #FEF7BC",
"9. c #ADADC4",
"0. c #B2AFC2",
"q. c #ADB2C3",
"w. c #B3B3C4",
"e. c #B8B4C3",
"r. c #B6BDC2",
"t. c #BBBCC4",
"y. c #B2B4C8",
"u. c #B9B7C9",
"i. c #BBBCCC",
"p. c #B7B8D1",
"a. c #C1BFC3",
"s. c #C2BECB",
"d. c #C2BFD1",
"f. c #B7C0C3",
"g. c #BDC2C4",
"h. c #B7C1CB",
"j. c #BBC3CC",
"k. c #BCC3D1",
"l. c #C4C3C3",
"z. c #C8C7C7",
"x. c #C5CAC5",
"c. c #CBCBC5",
"v. c #C4C4CB",
"b. c #C9C5CC",
"n. c #C3C9CE",
"m. c #CCCCCC",
"M. c #D1CECE",
"N. c #CFD1CE",
"B. c #D0D1C7",
"V. c #D3D2CC",
"C. c #DCDBCF",
"Z. c #C4C4D2",
"A. c #CAC6D4",
"S. c #C5CBD2",
"D. c #CBCCD4",
"F. c #C4C3DA",
"G. c #C9C5D9",
"H. c #C6CCDA",
"J. c #CDCCDB",
"K. c #D2CDD2",
"L. c #D1CDD9",
"P. c #CDD2D5",
"I. c #CED3DC",
"U. c #D4D4D3",
"Y. c #D9D5D6",
"T. c #D4D8D7",
"R. c #DADAD5",
"E. c #D4D3DB",
"W. c #D9D6DB",
"Q. c #D6D9DC",
"!. c #DCDCDC",
"~. c #E1DEDF",
"^. c #DEE0DC",
"/. c #E6E3C7",
"(. c #FEF7C2",
"). c #FEF8C8",
"_. c #E1E1DE",
"`. c #F0EEDA",
"'. c #FBF7D1",
"]. c #FEF9D2",
"[. c #FEFBDD",
"{. c #CBCCE2",
"}. c #CED2E2",
"|. c #D3D4E4",
" X c #DCD6E2",
".X c #D5DAE4",
"XX c #DCDAE4",
"oX c #D4D5EA",
"OX c #D6DBE9",
"+X c #DCDDEA",
"@X c #E2DDE5",
"#X c #E4DFE8",
"$X c #DCE1EB",
"%X c #E4E3E3",
"&X c #E8E5E6",
"*X c #E7E8E7",
"=X c #E9E9E5",
"-X c #E5E3EA",
";X c #EAE6EA",
":X c #E7E9EA",
">X c #EDEBEB",
",X c #F1EFEE",
"<X c #FBF8E6",
"1X c #F2F2EE",
"2X c #FFFDED",
"3X c #E2E5F0",
"4X c #E8E7F0",
"5X c #E7EBF2",
"6X c #ECECF4",
"7X c #F1EFF2",
"8X c #F4F3F3",
"9X c #F8F7F6",
"0X c #F7F8F7",
"qX c #FBFAF5",
"wX c #F5F4F9",
"eX c #F8F7F9",
"rX c #FEFDFD",
"tX c None",
/* pixels */
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX5 6 5 5 5 5 5 6 5 tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX5 5 l z.R.~.&X,X=X%X!.N.B 5 6 tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtX5 B U.=X_.R.R.R.R.R.Y.~.~.%X>X8X!.U 5 tXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtX5 k !.!.U.c.c.m.V.M.M.M.U.R.Y.!.@X&X>X8X>Xb 5 tXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtX5 0 N.B.;.N Z ;.l.c.m.m.M.M.U.Y.Y.Y.~.&X&X>X>X8X@Xq 6 tXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtX5 h V.=.i [ ' { | Z :.b.m.M.K.V.K.Y.Y.@X&X&X&X;X&X,X7Xk 6 tXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtX5 I R.m i = ; + ; * | m a.b.K.M.M.K.K.Y.@X&X&X&X;X;X,X,X1X) 5 tXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtX5 I @XC i * % 3 &.+.% * ^ ) b.b.b.K.K.K.Y.@X&X@X#X;X;X;X;X>X8X) 6 tXtXtXtXtXtXtX",
"tXtXtXtXtXtXtX5 j %Xl.M ! ; +.2XrXqX+.; ' ) s.b.b.b.K.K.Y.@X@X@X#X;X;X>X,X;X,X1Xk 5 tXtXtXtXtXtX",
"tXtXtXtXtXtXtX0 %XN.:.N ' : 8.rXrXeX1.: ' V b.b.b.M.K.K. X@X@X#X#X;X;X;X;X,X;X,X1X0 tXtXtXtXtXtX",
"tXtXtXtXtXtX5 !.Q.x.l.M ! <.rXrXrX2X+.; ~ V b.b.b.b.A.K. X@X@X@X#X#X;X;X;X>X>X>X7X^.5 tXtXtXtXtX",
"tXtXtXtXtXtXc :XN.m.l.C -.rXrX(.2.+.@ = ^ V b.e.e.e.s.A. X X@X@X#X#X#X;X;X>X>X>X%X,Xl tXtXtXtXtX",
"tXtXtXtXtX5 %XR.N.m.x.:.qXrX4.; + ; = ~ t H E E P P P s.A. X X@X@X#X#X&X;X;X%X_.%X%X%X5 tXtXtXtX",
"tXtXtXtXtXI :XR.N.z.:.=XrX=Xi ! ! ~ u e k P E E H P P A.A.K.W. X@X#X#X;X@X X~.@X_.%X>XB tXtXtXtX",
"tXtXtXtX5 ^.^.T.N.c.N.rXrXU C V v e e j x S R ) K H K A.G.L.L.L. X@X@XW.W.W.!.@X_._.&XR.5 tXtXtX",
"tXtXtXtX5 1X^.R.V.x.,XrXY.Q a.l.U x k j k S E z.u.e.u.G.d.G.J.G.|.L.J.L.E.W.W.!.~.%X%X=X5 tXtXtX",
"tXtXtXtXB 7X_.^.V.c.rXrX` l.l.t.F x k k l L w 8 5 8 g G.{.G.d.d.R Z.J.D.L.E.W.!.!._._.>Xl tXtXtX",
"tXtXtX5 U.:X^.R.N.!.rX%Xl.v.v.R L S k b l 5 5 tXtXtX5 5 s.{.y.0.q.w.A.H.D.E.T.W.!.!._.=Xz.5 tXtX",
"tXtXtX8 ^.>X%XR.B.>XrXT.l.b.v.P F H c I 5 tXtXtXtXtXtXtX5 d.9.H 9.K Z.A.A.P.D.T.R.!.^.%XU.6 tXtX",
"tXtXtX6 *X>X=X^.N.8XrXb.v.A.v.9.K 9.0.w 5 tXtXtXtXtXtXtX5 z d.G J K i.S.A.D.L.T.E.!.^._.^.6 tXtX",
"tXtXtX5 1X>X=X!.N.rXrXv.b.A.v.u.t.t.v.8 tXtXtXtXtXtXtXtXtX9 G.G G J y.k.S.H.D.P.T.T.R.^.%X5 tXtX",
"tXtXtX5 9X1X=X!.N.rXrXv.A.J.b.v.b.c.C.5 tXtXtXtXtXtXtXtXtX5 L.A G G q.k.k.n.D.D.I.T.Q.XX:X5 tXtX",
"tXtXtX5 8X1X>X_.N.rXrXb.A.H.Z.u.u.u.A.8 tXtXtXtXtXtXtXtXtX9 U.x D J q.j.j.k.n.S.D.T.Q.Q._.5 tXtX",
"tXtXtX8 >X1X>X=XU.8XrXU.D.J.Z.y.9.9.p.g 5 tXtXtXtXtXtXtX5 b B.l x D r.h.i.h.j.n.S.P.T.Q.T.6 tXtX",
"tXtXtX7 _.0X1X_.R.7XrX!.D.L.J.w.y.9.9.G.5 tXtXtXtXtXtXtX8 ^.;.n l c r.f.g.h.h.n.P.P.I.Q.D.5 tXtX",
"tXtXtX6 T.qX<X=X!.%XrX>Xm.J.I.i.y.p.F.}.v.5 5 tXtXtX5 8 R.C._ M n b f.f.t.` h.j.n.S.P.Q.g.6 tXtX",
"tXtXtXtXB 0X9X,X%XT.rXrXm.L.L.}.G.{.F.G. XE.S 9 5 0 b _.C.>.=.N s _ Y ` ` ` f.h.j.S.P..Xj tXtXtX",
"tXtXtXtX5 qX0X1X%XR.8XrX%XL.oX+XoX{.{.{.G.J.b.K.R.C.V.=.N =.*._ s _ _ W _ ` f.h.j.H.H.Q.5 tXtXtX",
"tXtXtXtX8 _.0X1X,X^.!.rXeXI.|.oXoX{.{.{.J.s.L L l b m p a N N N _ _ _ Y  .` f.h.k.k.H.g.6 tXtXtX",
"tXtXtXtXtXY qX0X8X:XXX7XrX7XL.oXoXoXoXJ.L.e.L L b b V y u i d *.*._ M [  ._ ` h.h.k.I.j tXtXtXtX",
"tXtXtXtXtX5 1X9X8X7X-X!.rXrX:XJ.oXoXoX|.L.R P I b b V v u ^ / N d M [ }  .Y f.h.h.k.S.5 tXtXtXtX",
"tXtXtXtXtXtXB rX9X8X>X-XXXrXrX-XJ.}.oX.X|.b.v.) Q ) ) ) ) / ^ a y = & ] C Y r.r.h.H.w tXtXtXtXtX",
"tXtXtXtXtXtX5 *XrX9X7X4XXX%XrXrX>XH.G.E.A.b.v.b.z.l.) ) =.( M p ; + - d Y ` ` f.j.h.5 tXtXtXtXtX",
"tXtXtXtXtXtXtX0 8XeX8X7X5XXXXXrX2X<X!.S.j.v.l.l.l.a.) ) Z N } % # ; p C Y W W j.j.9 tXtXtXtXtXtX",
"tXtXtXtXtXtXtX6 k eXeXwX7X4XXX.X,X<X[.]./.,.>.:.) ) =.X.o.1 < $ > s B C Y W ` k.q 5 tXtXtXtXtXtX",
"tXtXtXtXtXtXtXtX6 E eXwX8X6X4X+XE.W.`.].).(.7.3.&.%.@.+.2 1 ,  .C C C B W W j.h 5 tXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtX6 Q eXwXwX7X4X3XOXI.S.V.5.6.1.&.$.#.O..._ C _ Y _ C Y W f.h 5 tXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtX5 j 7XwXwX6X5X3X.XI.H.S.j.g.a.) g.` :.:.:.;.` ` W ` r.9 5 tXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtX6 0 -X8XwX6X5X$XOXoX}.I.H.S.S.x.x.x.x.x.:.:.g.x.W 7 5 tXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtX5 x :XwX6X3X$XOXoX}.I.I.P.P.P.m.m.x.x.m.g.q 5 tXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXo 5 B T.5X5X3X$XOX.XI.I.T.I.P.P.P.Q w 5 o tXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX. 5 5 j g.P.I..X$XQ.S.g.Y w 5 4 . tXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX  X O 4 5 4 5 4 O X   tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX",
"tXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtX"
};
