/* XPM */
/* $XConsortium: Dtaprnt.t.pm /main/2 1996/07/23 12:04:29 drk $ */
static char * Dtaprnt_t_pm[] = {
/* width height ncolors cpp [x_hot y_hot] */
"16 16 5 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor2	m white	c white",
"X	s iconColor1	m black	c black",
"o	s iconColor5	m black	c blue",
"O	s iconGray4	m white	c #969696969696",
/* pixels */
"                ",
"                ",
" .............X ",
" .ooooooooooooX ",
" .ooooooooooooX ",
"....oooooooo...X",
".OO.oooooooo.OOX",
".OO..........OOX",
".OOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOX",
".OOOOOOOOOOOOOOX",
"XXXXXXXXXXXXXXXX"};
