/* XPM */
/* $XConsortium: warnicon.pm /main/3 1996/06/20 18:14:03 rws $ */
static char * warnicon [] = {
/* width height ncolors cpp [x_hot y_hot] */
"31 31 4 1 0 0",
/* colors */
" 	s none	m none	c none",
".	s iconColor1	m black	c black",
"X	s iconColor3	m black	c red",
"o	s iconColor6	m white	c yellow",
/* pixels */
"             .....       X     ",
"            .ooooo.     XXX    ",
"           .ooXXXoo.    XXXX   ",
"          .ooXXXXXoo. XXXXXXX  ",
"          .oXXXXXXXo. XXXXXXX  ",
"         .ooXXXXXXXooXXXXXXX   ",
"        .ooXXXXXXXXXoXXXXXX    ",
"        .oXXXXXXXXXoXXXXX      ",
"       .ooXXXXXXXXoooXX        ",
"      .ooXXXXXXXXoooooXXX      ",
"      .oXXXXXXXXooooooXoX      ",
"     .ooXXXXXXXooooooXXoo.     ",
"    .ooXXXXXXXooooooXXXXoo.    ",
"    .oXXXXXXXooooooXXXXXXo.    ",
"   .ooXXXXXXooooooXXXXXXXoo.   ",
"  .ooXXXXXXXXXoooXXXXXXXXXoo.  ",
"  .oXXXXXXXXXXooooXXXXXXXXXo.  ",
" .ooXXXXXXXXXooooooXXXXXXXXoo. ",
".ooXXXXXXXXXoooooXXXXXXXXXXXo. ",
".ooXXXXXXXXoooooXXXXXXXXXXXXoo.",
".oXXXXXXXXooooXXXXXXXXXXXXXXXo.",
".oXXXXXXXXoooXXXXXXXXXXXXXXXXo.",
".oXXXXXXXoooXXXXXXXXXXXXXXXXXo.",
".ooXXXXXoooooXXXXXXXXXXXXXXXoo.",
"..oXXXXooooXXXXXXXXXXXXXXXXXo. ",
" .oooooooXXXXXXXXXXXXXXXXXooo. ",
"  ..oXXXooooooooooooooooooo..  ",
"   XXXX....................    ",
"  XXX                          ",
" XX                            ",
" X                             "};
