/* XPM */
static char *eom_l[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c #41433F",
".  c #3D4B5B",
"X  c #364A63",
"o  c #354D6B",
"O  c #3B557A",
"+  c #424441",
"@  c #474945",
"#  c #494B45",
"$  c #4B4D4A",
"%  c #4E514C",
"&  c #51514B",
"*  c #545347",
"=  c #424B53",
"-  c #555754",
";  c #5B5D5A",
":  c #585A57",
">  c #4F575F",
",  c #5F615D",
"<  c #60625F",
"1  c #4C5E75",
"2  c #4C5868",
"3  c #4C617D",
"4  c #556476",
"5  c #5A766C",
"6  c #636461",
"7  c #686B68",
"8  c #6E716D",
"9  c #6B7E61",
"0  c #73796A",
"q  c #69737A",
"w  c #747572",
"e  c #7B7C7A",
"r  c #777A77",
"t  c #915B03",
"y  c #8F5902",
"u  c #9B6209",
"i  c #8C6014",
"p  c #A76A09",
"a  c #B4740D",
"s  c #A26E1B",
"d  c #B6661A",
"f  c #BD7B10",
"g  c #987738",
"h  c #9B6833",
"j  c #B46A27",
"k  c #A86E37",
"l  c #B97B33",
"z  c #A7722C",
"x  c #C17E12",
"c  c #CD7816",
"v  c #C46B17",
"b  c #C77523",
"n  c #9A7658",
"m  c #877E73",
"M  c #A47E63",
"N  c #7A8857",
"B  c #7B9553",
"V  c #60806A",
"C  c #7A8366",
"Z  c #6E857A",
"A  c #7C8579",
"S  c #BC8A38",
"D  c #CB8218",
"F  c #E28918",
"G  c #C48625",
"H  c #D78B24",
"J  c #DA9128",
"K  c #C18E3E",
"L  c #C9933D",
"P  c #DF9B3A",
"I  c #E99D25",
"U  c #F5AB29",
"Y  c #EEBE3E",
"T  c #F5B12E",
"R  c #FCC33A",
"E  c #919149",
"W  c #8CA351",
"Q  c #93AA55",
"!  c #9AB24F",
"~  c #BFAE4D",
"^  c #A5BB59",
"/  c #A4BB57",
"(  c #9B8A6A",
")  c #82847C",
"_  c #8B8A7F",
"`  c #938879",
"'  c #929C7A",
"]  c #909E6B",
"[  c #BE9B68",
"{  c #9BA76A",
"}  c #9FB06D",
"|  c #9CA979",
" . c #A5B861",
".. c #A7B377",
"X. c #CB9A4A",
"o. c #E3AE61",
"O. c #ADC164",
"+. c #ADC16C",
"@. c #B3C56A",
"#. c #AEC070",
"$. c #BACB74",
"%. c #B9CA79",
"&. c #FDD045",
"*. c #244A82",
"=. c #2F5482",
"-. c #5A6D86",
";. c #5F7489",
":. c #657482",
">. c #6B7A89",
",. c #7A7889",
"<. c #7F7E91",
"1. c #66728F",
"2. c #8E7D87",
"3. c #877C8A",
"4. c #75848D",
"5. c #788396",
"6. c #798BA3",
"7. c #858581",
"8. c #8B8383",
"9. c #878883",
"0. c #898A84",
"q. c #8B8D8A",
"w. c #89878E",
"e. c #94848B",
"r. c #9A8B8E",
"t. c #958686",
"y. c #8D9385",
"u. c #8F908C",
"i. c #91948C",
"p. c #949A8B",
"a. c #999987",
"s. c #858D95",
"d. c #9C8E94",
"f. c #968D91",
"g. c #8B939D",
"h. c #949492",
"j. c #9A9B95",
"k. c #9B9D9B",
"l. c #91949C",
"z. c #AB9789",
"x. c #A5999A",
"c. c #9BA18D",
"v. c #9DA294",
"b. c #9FA09A",
"n. c #AAA889",
"m. c #A7B285",
"M. c #B4BA87",
"N. c #A4A49B",
"B. c #A5A99D",
"V. c #A3A994",
"C. c #ADB397",
"Z. c #B4BA9A",
"A. c #818EA4",
"S. c #8893A5",
"D. c #919CA9",
"F. c #899CB5",
"G. c #A99BA0",
"H. c #9DA4AB",
"J. c #9BA1A6",
"K. c #8FA2BD",
"L. c #95A7BE",
"P. c #9BAABD",
"I. c #97A3B3",
"U. c #A3A4A2",
"Y. c #A9ABA5",
"T. c #ADAEAB",
"R. c #AAA5A8",
"E. c #B4AAAC",
"W. c #ADB0A8",
"Q. c #B1B3AD",
"!. c #B4B9AE",
"~. c #A7ADB4",
"^. c #B3AAB2",
"/. c #AAB1B9",
"(. c #B4B5B2",
"). c #BAB3B6",
"_. c #B7BAB3",
"`. c #B9BBB4",
"'. c #BCB5BB",
"]. c #BDBDBA",
"[. c #B3B8BC",
"{. c #CEB18F",
"}. c #C9AC8F",
"|. c #D6BBA4",
" X c #C2BABD",
".X c #CDBEA8",
"XX c #BCCC82",
"oX c #BBC88F",
"OX c #BDC697",
"+X c #BEC1B9",
"@X c #C7D58D",
"#X c #C4C69A",
"$X c #D1DC9E",
"%X c #D5CC98",
"&X c #D5E095",
"*X c #C9CCA8",
"=X c #D2DBA7",
"-X c #C1C3BD",
";X c #D7C7B5",
":X c #DBC2AC",
">X c #EDCFA8",
",X c #F1D6AD",
"<X c #DEE5AF",
"1X c #E5EBAC",
"2X c #E2EAB5",
"3X c #EBF1BB",
"4X c #9DACC3",
"5X c #95A8C3",
"6X c #A5B3C8",
"7X c #AAB7CA",
"8X c #B3BDCC",
"9X c #B4BBC3",
"0X c #A8ADC0",
"qX c #C4BDC4",
"wX c #B8C2CD",
"eX c #BBC4D3",
"rX c #BAC6D7",
"tX c #C5C6C2",
"yX c #C9CAC6",
"uX c #CBCCCB",
"iX c #C9C4C5",
"pX c #D1CACE",
"aX c #D2D2CF",
"sX c #C4CEDC",
"dX c #C9CDD2",
"fX c #D4CED2",
"gX c #CCD3DB",
"hX c #CDD1D5",
"jX c #D4D5D4",
"kX c #D9D9D6",
"lX c #DCDDDB",
"zX c #D6D7DA",
"xX c #E1DDDF",
"cX c #DEE0DE",
"vX c #E6ECC4",
"bX c #EDF2C3",
"nX c #EFF3C9",
"mX c #E1E2DE",
"MX c #EBE4D9",
"NX c #C8D2E1",
"BX c #DBDEE2",
"VX c #D5DBE0",
"CX c #E2DEE0",
"ZX c #DEE1E3",
"AX c #E6E6E4",
"SX c #E9E9E6",
"DX c #ECECEA",
"FX c #E8E7E5",
"GX c #F0EEEF",
"HX c #F0F0EF",
"JX c #F4F4F3",
"KX c #F9F8F7",
"LX c #F6F8FA",
"PX c #FCFCFC",
"IX c #F6F7FA",
"UX c None",
/* pixels */
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX0.9.) 0.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX0.0.u.].AXKXKXaX0.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX9.0.0.Q.kXJXPXKXKXHXDXIXj.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUX9.0.9.(.lXJXPXKXJXHXDXDXDXSXDXKXyX9.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUX0.) Y.kXHXPXKXKXHXDXDXDXDXDXDXDXDXDXHXSX0.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX0.9.h.uXDXPXPXKXJXHXDXDXDXDXHXDXDXDXDXDXDXDXDXKX9.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUX0.u.0.(.lXKXPXPXJXHXDXHXDXDXDXHXDXDXDXDXDXDXDXDXDXSXDXKXY.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UX0.k.aXHXPXPXKXJXHXDXDXHXDXDXDXDXDXDXDXDXDXDXDXSXSXaX!.v.aXJXpX9.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"0.lXPXKXJXHXDXDXHXHXDXDXDXDXHXDXDXDXDXDXDXDXkX+XV.y.c...c._.HXDX0.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"0.PXHXHXHXDXDXHXDXDXDXDXDXDXDXDXDXDXkX].N.y.c.M.oX$X@XXX#.p.SXLX0.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"9.PXHXDXDXHXDXHXDXDXDXHXDXDXMX-XY.p.p.m.OX=X$X@X%.@.@.O.XX_ mXLX(.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"0.SXKXDXDXHXDXDXHXDXSXyXQ.p.i.V.OX*XE.x.x.M.$.$.@.@.O./ #.' -XHXjX9.UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXtXKXDXDXDXDXaX!.v.y.v.Z.T.E.R.#Xe.zXGXfXe...a.2.t.{ / O.{ B.DXGXe UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXi.PXDXyXW.i.i.C.*XvX3XR.qXPXfX3.G.PXPXPXd.2.)._.w * # @ # % A ].9.UXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UX0.IXHXV.Z.2XnXbX3X1X1Xr.xXPXPX'.R.PXPXPX2.e & e T.aXcXAXcXaXY.e % & UXUXUXUXUXUXUXUXUXUXUXUXUX",
"UX9.lXKX`.Z.vX1X%Xf.2.e.t.G.PXKX>Xo.P J z & h.lXuXH.4.Z V Z 4.I.uXkXu.# UXUXUXUXUXUXUXUXUXUXUXUX",
"UXUX(.LXaXv.bX1Xd.pXKXxX Xr.|.J I U T g , fX-Xm d.0XsXBX-.1.5 1.F.F.+XtX; UXUXUXUXUXUXUXUXUXUXUX",
"UXUX0.PXDXy.vX1Xr.fXPXPXPX,XF U R &.E 8 lXV.( ;XMXqXrX7X0X<.Z 4 5X5X-.D.yX6 + UXUXUXUXUXUXUXUXUX",
"UXUX0.HXHXB.*X1X#X2.E.xXJXJ I R &.~ ; kXz.n.MX{.k h sXNX8X<.A q I.6X6.O 5.].- UXUXUXUXUXUXUXUXUX",
"UXUX) aXKX-XC.2X&XM.2.2.t.D I T R * pXG.n.DX[ l j z w.3.,.C B 9 g.8X4X1 UXs.Y.@ UXUXUXUXUXUXUXUX",
"UXUXUXY.KXlXp.2XM.2.iXFXPXH F U g u.-X( MX[ l b j j qX^.e.8.W N >.wXwX1 UXUXk.w + UXUXUXUXUXUXUX",
"UXUXUX9.KXDXp.=Xd.CXPXPXPX>Xc F & jX` .X}.l b v d :XIXIXKXqX8.W 7 dXsX>.O UX-.U.@ UXUXUXUXUXUXUX",
"UXUXUX0.SXHXW.Z.G.iXGXCX X2.|.h r ].n :Xj j j j }.3.).CXDX'._ W 9 9XgXI.1 UXUXh.6 UXUXUXUXUXUXUX",
"UXUXUXUXtXJXtXn.#Xe.2.2.e.kXPX7.N.h.x.z.n n .XHXLXqX2.e.2.a.W ! N k.VXwX,.4XUXq r + UXUXUXUXUXUX",
"UXUXUXUXj.KXmXy.$X$.@.e.lXPXPX6 '.A.sXsXrX,.'.LXPXLXd.Q W E 0 8 A T.zXgX/.wXUX4 )   UXUXUXUXUXUX",
"UXUXUXUX9.HXDXc.oX%.O.e. XHXpX@ wX6.NXrXwXw.f.).qXk.r w ) U.tXZXAXZXZXBXdX9XUXO 7.+ UXUXUXUXUXUX",
"UXUXUXUX0.lXGXQ...%.^  .t.t.` @ `.1.eX7XS.) C r r 8.(.lXAXAXAXAXZXZXAXDXhX~.UX=.e + UXUXUXUXUXUX",
"UXUXUXUXUX`.JXuXc.XX^ / ! / ^ # Q.:.S.:.q s.wXZXDXDXDXSXDXDXDXDXDXDXAXZXzXD.UXO w + UXUXUXUXUXUX",
"UXUXUXUXUXu.KXAXy.XXO.+.+.} ] % k.:.F.P.wXZXDXDXDXDXDXDXDXDXDXAXDXFXZXVXgX4.UX2 7 + UXUXUXUXUXUX",
"UXUXUXUXUX0.DXSXv.} | ' y.y.Y.8 7.w.L.6XNXAXSXDXSXSXDXSXSXDXDXAXFXFXZXVX/.;.UX> - + UXUXUXUXUXUX",
"UXUXUXUXUX9.aXHX_.y.V.-XkXAXAXT.< q.F.4XZXZXAXAXSXSXAXDXSXDXDXSXFXgX[.g.5.UXUX; $ UXUXUXUXUXUXUX",
"UXUXUXUXUXUXY.JXAXAXSXAXAXSXSXlX$ y.5.L.rXBXBXZXZXAXDXDXDXcXuXH.q.s.g.A.UXUXX - + UXUXUXUXUXUXUX",
"UXUXUXUXUXUX9.HXFXFXAXAXSXAXSXAXq.6 e F.L.sXVXBXAXBXdX(.k.k.H./.UXUXUXUXUX*.% @ + UXUXUXUXUXUXUX",
"UXUXUXUXUXUX0.AXDXFXSXAXAXSXFXAXlX% w q K.5X8X9XH.J.J.~.UXUXUXUXUXUXUXUXUX= $ + UXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXtXDXAXAXAXAXSXSXDXHX(.$ 8 4 1 3 5.P.6XUXUXUXUXUXUXUXUXUXUX. $ @ UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXj.JXSXSXDXHXJXMXyXN.) ; $ 6 > UXUXUXUXUXUXUXUXUXUXUXUXUX= $ @ ; UXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUX9.yXHXSXaXQ.0.0.9.UXUXUX  @ : - o UXUXUXUXUXUXUXUXUXX $ $ + ; i s u UXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUX0.9.9.0.UXUXUXUXUXUXUXUXUX+ # % $ = X o *.o X = $ $ @ + UXUXu G X.s t UXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX  + @ @ $ $ $ $ $ @ @ + + UXUXUXt x G X.z t UXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX+ + + + + + + UXUXUXUXUXUXt u f D X.S t UXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt p D x L S t UXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXy a x f L K t UX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt a D x L K t ",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt a x x G t ",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt a f p y ",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXt t y UX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX",
"UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX"
};
